From 660136cc1acdf4f157d93ac6dd7418593c8ae2f6 Mon Sep 17 00:00:00 2001
From: Vignesh C <vignesh21@gmail.com>
Date: Mon, 29 May 2023 16:32:30 +0530
Subject: [PATCH] ObjTree Removal for multiple commands.

1. create table
2. alter table
3. drop table
4. create sequence
5. alter sequence
6. alter object owner to
7. alter object set schema
8. alter object rename
---
 src/backend/commands/ddldeparse.c             | 3689 +++++++++--------
 src/backend/replication/logical/ddltrigger.c  |    5 +-
 src/include/tcop/ddldeparse.h                 |    4 +-
 .../expected/alter_table.out                  |  294 +-
 .../expected/constraints.out                  |  284 +-
 .../expected/create_index.out                 |    4 +-
 .../expected/create_rule.out                  |   16 +-
 .../expected/create_table.out                 |  300 +-
 .../sql/alter_table.sql                       |   11 +-
 .../t/001_compare_dumped_results.pl           |    2 +
 .../test_ddl_deparse_regress.c                |    6 +-
 11 files changed, 2321 insertions(+), 2294 deletions(-)

diff --git a/src/backend/commands/ddldeparse.c b/src/backend/commands/ddldeparse.c
index 52e2e2216d..71da9502d9 100644
--- a/src/backend/commands/ddldeparse.c
+++ b/src/backend/commands/ddldeparse.c
@@ -20,13 +20,12 @@
  * etc) looking only at the parse node.
  *
  * Deparse object tree is created by using:
- * 	a) new_objtree("know contents") where the complete tree content is known or
- *     the initial tree content is known.
- * 	b) new_objtree("") for the syntax where the object tree will be derived
- *     based on some conditional checks.
- * 	c) new_objtree_VA where the complete tree can be derived using some fixed
- *     content or by using the initial tree content along with some variable
- *     arguments.
+ * 	new_jsonb_VA where the key-value pairs composing an jsonb object can be
+ * 	derived using the passed variable arguments. In order to successfully
+ *  construct one key:value pair, a set of three arguments consisting of a name
+ * 	(string), type (from the jbvType enum) and value must be supplied. It can
+ *  take multiple such sets and construct multiple key-value pairs and append
+ *  those to output parse-state.
  *
  * IDENTIFICATION
  *	  src/backend/commands/ddldeparse.c
@@ -67,53 +66,6 @@
 /* Estimated length of the generated jsonb string */
 #define JSONB_ESTIMATED_LEN 128
 
-/*
- * Before they are turned into JSONB representation, each command is
- * represented as an object tree, using the structs below.
- */
-typedef enum
-{
-	ObjTypeNull,
-	ObjTypeBool,
-	ObjTypeString,
-	ObjTypeArray,
-	ObjTypeInteger,
-	ObjTypeObject
-} ObjType;
-
-/*
- * Represent the command as an object tree.
- */
-typedef struct ObjTree
-{
-	slist_head	params;			/* Object tree parameters */
-	int			numParams;		/* Number of parameters in the object tree */
-	StringInfo	fmtinfo;		/* Format string of the ObjTree */
-	bool		present;		/* Indicates if boolean value should be stored */
-} ObjTree;
-
-/*
- * An element of an object tree (ObjTree).
- */
-typedef struct ObjElem
-{
-	char	   *name;			/* Name of object element */
-	ObjType		objtype;		/* Object type */
-
-	union
-	{
-		bool		boolean;
-		char	   *string;
-		int64		integer;
-		float8		flt;
-		ObjTree    *object;
-		List	   *array;
-	}			value;			/* Store the object value based on the object
-								 * type */
-	slist_node	node;			/* Used in converting back to ObjElem
-								 * structure */
-} ObjElem;
-
 /*
  * Reduce some unnecessary strings from the output json when verbose
  * and "present" member is false. This means these strings won't be merged into
@@ -121,50 +73,11 @@ typedef struct ObjElem
  */
 bool		verbose = true;
 
-static void append_format_string(ObjTree *tree, char *sub_fmt);
-static void append_array_object(ObjTree *tree, char *sub_fmt, List *array);
-static void append_bool_object(ObjTree *tree, char *sub_fmt, bool value);
-static void append_object_object(ObjTree *tree, char *sub_fmt, ObjTree *value);
-static char *append_object_to_format_string(ObjTree *tree, char *sub_fmt);
-static void append_premade_object(ObjTree *tree, ObjElem *elem);
-static void append_string_object(ObjTree *tree, char *sub_fmt, char *object_name,
-								 char *value);
-static ObjElem *new_object(ObjType type, char *name);
-static ObjTree *new_objtree_for_qualname_id(Oid classId, Oid objectId);
-static ObjElem *new_object_object(ObjTree *value);
-static ObjTree *new_objtree_VA(char *fmt, int numobjs, ...);
-static JsonbValue *objtree_to_jsonb_rec(ObjTree *tree, JsonbParseState *state, char *owner);
-static char *RelationGetColumnDefault(Relation rel, AttrNumber attno,
-									  List *dpcontext, Node **expr);
-
-static ObjTree *deparse_ColumnDef(Relation relation, List *dpcontext, bool composite,
-								  ColumnDef *coldef, bool is_alter, Node **expr);
-static ObjTree *deparse_ColumnIdentity(Oid seqrelid, char identity, bool alter_table);
-static ObjTree *deparse_ColumnSetOptions(AlterTableCmd *subcmd);
-
-static ObjTree *deparse_DefElem(DefElem *elem, bool is_reset);
-static ObjTree *deparse_OnCommitClause(OnCommitAction option);
-static ObjTree *deparse_RelSetOptions(AlterTableCmd *subcmd);
-
-static inline ObjElem *deparse_Seq_Cache(Form_pg_sequence seqdata, bool alter_table);
-static inline ObjElem *deparse_Seq_Cycle(Form_pg_sequence seqdata, bool alter_table);
-static inline ObjElem *deparse_Seq_IncrementBy(Form_pg_sequence seqdata, bool alter_table);
-static inline ObjElem *deparse_Seq_Minvalue(Form_pg_sequence seqdata, bool alter_table);
-static inline ObjElem *deparse_Seq_Maxvalue(Form_pg_sequence seqdata, bool alter_table);
-static inline ObjElem *deparse_Seq_Restart(int64 last_value);
-static inline ObjElem *deparse_Seq_Startwith(Form_pg_sequence seqdata, bool alter_table);
-static inline ObjElem *deparse_Seq_As(Form_pg_sequence seqdata);
-
-static List *deparse_InhRelations(Oid objectId);
-static List *deparse_TableElements(Relation relation, List *tableElements, List *dpcontext,
-								   bool typed, bool composite);
-static void mark_function_volatile(ddl_deparse_context *context, Node *expr);
-
 /*
  * Mark the func_volatile flag for an expression in the command.
  */
 static void
-mark_function_volatile(ddl_deparse_context *context, Node *expr)
+mark_function_volatile(ddl_deparse_context * context, Node *expr)
 {
 	if (context->func_volatile == PROVOLATILE_VOLATILE)
 		return;
@@ -181,276 +94,266 @@ mark_function_volatile(ddl_deparse_context *context, Node *expr)
 }
 
 /*
- * Append present as false to a tree.
- * If sub_fmt is passed and verbose mode is ON,
- * append sub_fmt as well to tree.
- *
- * Example:
- * in non-verbose mode, element will be like:
- * "collation": {"fmt": "COLLATE", "present": false}
- * in verbose mode:
- * "collation": {"fmt": "COLLATE %{name}D", "present": false}
+ * Return the string representation of the given RELPERSISTENCE value.
  */
-static void
-append_not_present(ObjTree *tree, char *sub_fmt)
+static char *
+get_persistence_str(char persistence)
 {
-	if (verbose && sub_fmt)
+	switch (persistence)
 	{
-		append_format_string(tree, sub_fmt);
+		case RELPERSISTENCE_TEMP:
+			return "TEMPORARY";
+		case RELPERSISTENCE_UNLOGGED:
+			return "UNLOGGED";
+		case RELPERSISTENCE_PERMANENT:
+			return "";
+		default:
+			elog(ERROR, "unexpected persistence marking %c", persistence);
+			return "";			/* make compiler happy */
 	}
-
-	append_bool_object(tree, "present", false);
 }
 
 /*
- * Append an array parameter to a tree.
+ * Obtain the deparsed default value for the given column of the given table.
+ *
+ * Caller must have set a correct deparse context and must ensure that the
+ * passed attribute has a default value.
  */
-static void
-append_array_object(ObjTree *tree, char *sub_fmt, List *array)
+static char *
+RelationGetColumnDefault(Relation rel, AttrNumber attno, List *dpcontext,
+						 Node **expr)
 {
-	ObjElem    *param;
-	char	   *object_name;
-
-	Assert(sub_fmt);
-
-	if (list_length(array) == 0)
-		return;
-
-	if (!verbose)
-	{
-		ListCell   *lc;
-
-		/* Remove elements where present flag is false */
-		foreach(lc, array)
-		{
-			ObjElem    *elem = (ObjElem *) lfirst(lc);
-
-			Assert(elem->objtype == ObjTypeObject ||
-				   elem->objtype == ObjTypeString);
-
-			if (!elem->value.object->present &&
-				elem->objtype == ObjTypeObject)
-				array = foreach_delete_current(array, lc);
-		}
+	Node	   *defval;
+	char	   *defstr;
 
-	}
+	defval = build_column_default(rel, attno);
+	Assert(defval != NULL);
 
-	/* Check for empty list after removing elements */
-	if (list_length(array) == 0)
-		return;
+	defstr = deparse_expression(defval, dpcontext, false, false);
 
-	object_name = append_object_to_format_string(tree, sub_fmt);
+	/* Collect the expression for later replication safety checks */
+	if (expr)
+		*expr = defval;
 
-	param = new_object(ObjTypeArray, object_name);
-	param->value.array = array;
-	append_premade_object(tree, param);
+	return defstr;
 }
 
 /*
- * Append a boolean parameter to a tree.
+ * Obtain the deparsed partition bound expression for the given table.
  */
-static void
-append_bool_object(ObjTree *tree, char *sub_fmt, bool value)
+static char *
+RelationGetPartitionBound(Oid relid)
 {
-	ObjElem    *param;
-	char	   *object_name = sub_fmt;
+	Datum		deparsed;
+	Datum		boundDatum;
+	bool		isnull;
+	HeapTuple	tuple;
 
-	Assert(sub_fmt);
+	tuple = SearchSysCache1(RELOID, relid);
+	if (!HeapTupleIsValid(tuple))
+		elog(ERROR, "cache lookup failed for relation with OID %u", relid);
 
-	/*
-	 * Check if the format string is 'present' and if yes, store the boolean
-	 * value
-	 */
-	if (strcmp(sub_fmt, "present") == 0)
-		tree->present = value;
-	else
-		object_name = append_object_to_format_string(tree, sub_fmt);
+	boundDatum = SysCacheGetAttr(RELOID, tuple,
+								 Anum_pg_class_relpartbound,
+								 &isnull);
+
+	deparsed = DirectFunctionCall2(pg_get_expr,
+								   CStringGetTextDatum(TextDatumGetCString(boundDatum)),
+								   relid);
+
+	ReleaseSysCache(tuple);
 
-	param = new_object(ObjTypeBool, object_name);
-	param->value.boolean = value;
-	append_premade_object(tree, param);
+	return TextDatumGetCString(deparsed);
 }
 
 /*
- * Append the input format string to the ObjTree.
+ * Insert JsonbValue key to the output parse state.
  */
 static void
-append_format_string(ObjTree *tree, char *sub_fmt)
+insert_jsonb_key(JsonbParseState *state, char *name)
 {
-	int			len;
-	char	   *fmt;
-
-	Assert(sub_fmt);
-
-	if (tree->fmtinfo == NULL)
-		return;
-
-	fmt = tree->fmtinfo->data;
-	len = tree->fmtinfo->len;
-
-	/* Add a separator if necessary */
-	if (len > 0 && fmt[len - 1] != ' ')
-		appendStringInfoSpaces(tree->fmtinfo, 1);
+	JsonbValue	key;
 
-	appendStringInfoString(tree->fmtinfo, sub_fmt);
+	/* Push the key */
+	key.type = jbvString;
+	key.val.string.val = name;
+	key.val.string.len = strlen(name);
+	pushJsonbValue(&state, WJB_KEY, &key);
 }
 
 /*
- * Append an object parameter to a tree.
+ * Insert the format string to the output parse state.
  */
 static void
-append_object_object(ObjTree *tree, char *sub_fmt, ObjTree *value)
+fmt_to_jsonb_element(JsonbParseState *state, char *fmtStr)
 {
-	ObjElem    *param;
-	char	   *object_name;
-
-	Assert(sub_fmt);
+	JsonbValue	val;
 
-	if (!verbose && !value->present)
-		return;
+	Assert(fmtStr);
 
-	object_name = append_object_to_format_string(tree, sub_fmt);
+	/* Push the key first */
+	insert_jsonb_key(state, "fmt");
 
-	param = new_object(ObjTypeObject, object_name);
-	param->value.object = value;
-	append_premade_object(tree, param);
+	/* Push the value now */
+	val.type = jbvString;
+	val.val.string.val = pstrdup(fmtStr);
+	val.val.string.len = strlen(fmtStr);
+	pushJsonbValue(&state, WJB_VALUE, &val);
 }
 
 /*
- * Return the object name which is extracted from the input "*%{name[:.]}*"
- * style string. And append the input format string to the ObjTree.
+ * Append new jsonb key:value pair to the output parse state -- varargs version.
+ *
+ * The "fmt" argument is used to append as a "fmt" element in current object.
+ * The "skipObject" argument indicates if we want to skip object creation
+ * considering it will be taken care by the caller.
+ * The "numobjs" argument indicates the number of extra elements to append;
+ * for each one, a name (string), type (from the jbvType enum) and value must
+ * be supplied.  The value must match the type given; for instance, jbvBool
+ * requires an * bool, jbvString requires a char * and so no,
+ * Each element type  must match the conversion specifier given in the format
+ * string, as described in ddl_deparse_expand_command.
+ *
+ * Note we don't have the luxury of sprintf-like compiler warnings for
+ * malformed argument lists.
  */
-static char *
-append_object_to_format_string(ObjTree *tree, char *sub_fmt)
+static JsonbValue *
+new_jsonb_VA(JsonbParseState *state, char *fmt, bool skipObject, int numobjs,...)
 {
-	StringInfoData object_name;
-	const char *end_ptr, *start_ptr;
+	va_list		args;
+	int			i;
+	JsonbValue	val;
+	JsonbValue *value = NULL;
 
-	Assert(tree->fmtinfo);
+	/* Set up the toplevel object if not instructed otherwise */
+	if (!skipObject)
+		pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+	/* Set up the "fmt" */
+	if (fmt)
+		fmt_to_jsonb_element(state, fmt);
 
-	initStringInfo(&object_name);
 
-	start_ptr = strchr(sub_fmt, '{');
-	end_ptr = strchr(sub_fmt, ':');
-	if (end_ptr == NULL)
-		end_ptr = strchr(sub_fmt, '}');
+	/* And process the given varargs */
+	va_start(args, numobjs);
 
-	if (start_ptr != NULL && end_ptr != NULL)
+	for (i = 0; i < numobjs; i++)
 	{
-		appendBinaryStringInfo(&object_name, start_ptr + 1,
-								end_ptr - start_ptr - 1);
-	}
+		char	   *name;
+		enum jbvType type;
 
-	if (object_name.len == 0)
-		elog(ERROR, "object name not found");
+		name = va_arg(args, char *);
+		type = va_arg(args, enum jbvType);
 
-	append_format_string(tree, sub_fmt);
+		/* Push the key first */
+		insert_jsonb_key(state, name);
 
-	return object_name.data;
-}
+		/*
+		 * For all param types other than jbvNull, there must be a value in
+		 * the varargs. Fetch it and add the fully formed subobject into the
+		 * main object.
+		 */
+		switch (type)
+		{
+			case jbvNull:
+				/* Null params don't have a value (obviously) */
+				val.type = jbvNull;
+				pushJsonbValue(&state, WJB_VALUE, &val);
+				break;
 
-/*
- * Append a preallocated parameter to a tree.
- */
-static inline void
-append_premade_object(ObjTree *tree, ObjElem *elem)
-{
-	slist_push_head(&tree->params, &elem->node);
-	tree->numParams++;
-}
+			case jbvBool:
+				/* Push the bool value */
+				val.type = jbvBool;
+				val.val.boolean = va_arg(args, int);
+				pushJsonbValue(&state, WJB_VALUE, &val);
+				break;
 
-/*
- * Append a string parameter to a tree.
- */
-static void
-append_string_object(ObjTree *tree, char *sub_fmt, char *object_name,
-					 char *value)
-{
-	ObjElem    *param;
+			case jbvString:
+				/* Push the string value */
+				val.type = jbvString;
+				val.val.string.val = pstrdup(va_arg(args, char *));
+				val.val.string.len = strlen(val.val.string.val);
+				pushJsonbValue(&state, WJB_VALUE, &val);
+				break;
 
-	Assert(sub_fmt);
+			case jbvNumeric:
+				/* Push the numeric value */
+				val.type = jbvNumeric;
+				val.val.numeric = (Numeric) DatumGetNumeric(DirectFunctionCall1(int8_numeric,
+																				va_arg(args, int)));
 
-	if (!verbose && (value == NULL || value[0] == '\0'))
-		return;
+				pushJsonbValue(&state, WJB_VALUE, &val);
+				break;
 
-	append_format_string(tree, sub_fmt);
-	param = new_object(ObjTypeString, object_name);
-	param->value.string = value;
-	append_premade_object(tree, param);
-}
+			default:
+				elog(ERROR, "unrecognized jbvType %d", type);
+		}
 
-/*
- * Return the string representation of the given RELPERSISTENCE value.
- */
-static char *
-get_persistence_str(char persistence)
-{
-	switch (persistence)
-	{
-		case RELPERSISTENCE_TEMP:
-			return "TEMPORARY";
-		case RELPERSISTENCE_UNLOGGED:
-			return "UNLOGGED";
-		case RELPERSISTENCE_PERMANENT:
-			return "";
-		default:
-			elog(ERROR, "unexpected persistence marking %c", persistence);
-			return "";			/* make compiler happy */
 	}
+
+	va_end(args);
+
+	if (!skipObject)
+		value = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+
+	return value;
 }
 
 /*
- * Allocate a new parameter.
+ * Insert new object with present:false as key-value pair
+ * to the output parse state.
  */
-static ObjElem *
-new_object(ObjType type, char *name)
+static void
+insert_not_present_obj(JsonbParseState *state, char *fmt)
 {
-	ObjElem    *param;
 
-	param = palloc0(sizeof(ObjElem));
-	param->name = name;
-	param->objtype = type;
-
-	return param;
+	new_jsonb_VA(state, fmt, false, 1,
+				 "present", jbvBool, false);
 }
 
 /*
- * Allocate a new object parameter.
+ * Process the role string into the output parse state.
  */
-static ObjElem *
-new_object_object(ObjTree *value)
+static void
+role_to_jsonb_element(JsonbParseState *state, char *owner)
 {
-	ObjElem    *param;
-
-	param = new_object(ObjTypeObject, NULL);
-	param->value.object = value;
+	if (owner == NULL)
+		return;
 
-	return param;
+	new_jsonb_VA(state, NULL, true, 1,
+				 "myowner", jbvString, owner);
 }
 
 /*
- * Allocate a new object tree to store parameter values.
+ * A helper routine to insert jsonb for coltyp to the output parse state.
  */
-static ObjTree *
-new_objtree(char *fmt)
+static void
+new_jsonb_for_type(JsonbParseState *state, Oid typeId, int32 typmod)
 {
-	ObjTree    *objtree;
+	Oid			typnspid;
+	char	   *type_nsp;
+	char	   *type_name = NULL;
+	char	   *typmodstr;
+	bool		type_array;
 
-	objtree = palloc0(sizeof(ObjTree));
-	objtree->present = true;
-	slist_init(&objtree->params);
+	format_type_detailed(typeId, typmod,
+						 &typnspid, &type_name, &typmodstr, &type_array);
 
-	if (fmt)
-	{
-		objtree->fmtinfo = makeStringInfo();
-		appendStringInfoString(objtree->fmtinfo, fmt);
-	}
+	if (OidIsValid(typnspid))
+		type_nsp = get_namespace_name_or_temp(typnspid);
+	else
+		type_nsp = pstrdup("");
+
+	new_jsonb_VA(state, NULL, false, 4,
+				 "schemaname", jbvString, type_nsp,
+				 "typename", jbvString, type_name,
+				 "typmod", jbvString, typmodstr,
+				 "typarray", jbvBool, type_array);
 
-	return objtree;
 }
 
 /*
- * A helper routine to set up %{}D and %{}O elements.
+ * A helper routine to set up name: schemaname, objname
  *
  * Elements "schema_name" and "obj_name" are set.  If the namespace OID
  * corresponds to a temp schema, that's set to "pg_temp".
@@ -459,10 +362,9 @@ new_objtree(char *fmt)
  * be quoted as an identifier or not, which is not something that this routine
  * concerns itself with; that will be up to the expand function.
  */
-static ObjTree *
-new_objtree_for_qualname(Oid nspid, char *name)
+static void
+new_jsonb_for_qualname(JsonbParseState *state, Oid nspid, char *objName, char *keyName, bool skipObject)
 {
-	ObjTree    *qualified;
 	char	   *namespace;
 
 	if (isAnyTempNamespace(nspid))
@@ -470,21 +372,22 @@ new_objtree_for_qualname(Oid nspid, char *name)
 	else
 		namespace = get_namespace_name(nspid);
 
-	qualified = new_objtree_VA(NULL, 2,
-							   "schemaname", ObjTypeString, namespace,
-							   "objname", ObjTypeString, pstrdup(name));
+	/* Push the key first */
+	if (keyName)
+		insert_jsonb_key(state, keyName);
 
-	return qualified;
+	new_jsonb_VA(state, NULL, skipObject, 2,
+				 "schemaname", jbvString, namespace,
+				 "objname", jbvString, objName);
 }
 
 /*
- * A helper routine to set up %{}D and %{}O elements, with the object specified
- * by classId/objId.
+ * A helper routine to set up name: 'schemaname, objname' where the object is
+ * specified by classId and objId.
  */
-static ObjTree *
-new_objtree_for_qualname_id(Oid classId, Oid objectId)
+static void
+new_jsonb_for_qualname_id(JsonbParseState *state, Oid classId, Oid objectId, char *keyName, bool skipObject)
 {
-	ObjTree    *qualified;
 	Relation	catalog;
 	HeapTuple	catobj;
 	Datum		obj_nsp;
@@ -504,445 +407,405 @@ new_objtree_for_qualname_id(Oid classId, Oid objectId)
 	Anum_namespace = get_object_attnum_namespace(classId);
 
 	obj_nsp = heap_getattr(catobj, Anum_namespace, RelationGetDescr(catalog),
-						  &isnull);
+						   &isnull);
 	if (isnull)
 		elog(ERROR, "null namespace for object %u", objectId);
 
 	obj_name = heap_getattr(catobj, Anum_name, RelationGetDescr(catalog),
-						   &isnull);
+							&isnull);
 	if (isnull)
 		elog(ERROR, "null attribute name for object %u", objectId);
 
-	qualified = new_objtree_for_qualname(DatumGetObjectId(obj_nsp),
-										 NameStr(*DatumGetName(obj_name)));
+	new_jsonb_for_qualname(state, DatumGetObjectId(obj_nsp),
+						   NameStr(*DatumGetName(obj_name)), keyName, skipObject);
 	table_close(catalog, AccessShareLock);
-
-	return qualified;
 }
 
 /*
- * A helper routine to setup %{}T elements.
+ * A helper routine to insert key:value where value is array of qualname to
+ * the output parse state.
  */
-static ObjTree *
-new_objtree_for_type(Oid typeId, int32 typmod)
+static void
+new_jsonbArray_for_qualname_id(JsonbParseState *state, char *keyname, List *array)
 {
-	Oid			typnspid;
-	char	   *type_nsp;
-	char	   *type_name = NULL;
-	char	   *typmodstr;
-	bool		type_array;
+	ListCell   *lc;
 
-	format_type_detailed(typeId, typmod,
-						 &typnspid, &type_name, &typmodstr, &type_array);
+	/* Push the key first */
+	insert_jsonb_key(state, keyname);
 
-	if (OidIsValid(typnspid))
-		type_nsp = get_namespace_name_or_temp(typnspid);
-	else
-		type_nsp = pstrdup("");
+	pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
+	/* Push the array elements now */
+	foreach(lc, array)
+		new_jsonb_for_qualname_id(state, RelationRelationId, lfirst_oid(lc),
+								  NULL, false);
 
-	return new_objtree_VA(NULL, 4,
-						  "schemaname", ObjTypeString, type_nsp,
-						  "typename", ObjTypeString, type_name,
-						  "typmod", ObjTypeString, typmodstr,
-						  "typarray", ObjTypeBool, type_array);
+	pushJsonbValue(&state, WJB_END_ARRAY, NULL);
 }
 
 /*
- * Allocate a new object tree to store parameter values -- varargs version.
- *
- * The "fmt" argument is used to append as a "fmt" element in the output blob.
- * numobjs indicates the number of extra elements to append; for each one, a
- * name (string), type (from the ObjType enum) and value must be supplied.  The
- * value must match the type given; for instance, ObjTypeInteger requires an
- * int64, ObjTypeString requires a char *, ObjTypeArray requires a list (of
- * ObjElem), ObjTypeObject requires an ObjTree, and so on.  Each element type *
- * must match the conversion specifier given in the format string, as described
- * in ddl_deparse_expand_command, q.v.
- *
- * Note we don't have the luxury of sprintf-like compiler warnings for
- * malformed argument lists.
+ * A helper routine to insert collate object for column definition to the output parse state.
  */
-static ObjTree *
-new_objtree_VA(char *fmt, int numobjs, ...)
+static void
+insert_collate_object(JsonbParseState *state, char *fmt, Oid classId, Oid objectId, char *key)
 {
-	ObjTree    *tree;
-	va_list		args;
-	int			i;
-
-	/* Set up the toplevel object and its "fmt" */
-	tree = new_objtree(fmt);
 
-	/* And process the given varargs */
-	va_start(args, numobjs);
-	for (i = 0; i < numobjs; i++)
-	{
-		char	   *name;
-		ObjType		type;
-		ObjElem    *elem;
-
-		name = va_arg(args, char *);
-		type = va_arg(args, ObjType);
-		elem = new_object(type, NULL);
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-		/*
-		 * For all param types other than ObjTypeNull, there must be a value in
-		 * the varargs. Fetch it and add the fully formed subobject into the
-		 * main object.
-		 */
-		switch (type)
-		{
-			case ObjTypeNull:
-				/* Null params don't have a value (obviously) */
-				break;
-			case ObjTypeBool:
-				elem->value.boolean = va_arg(args, int);
-				break;
-			case ObjTypeString:
-				elem->value.string = va_arg(args, char *);
-				break;
-			case ObjTypeArray:
-				elem->value.array = va_arg(args, List *);
-				break;
-			case ObjTypeInteger:
-				elem->value.integer = va_arg(args, int);
-				break;
-			case ObjTypeObject:
-				elem->value.object = va_arg(args, ObjTree *);
-				break;
-			default:
-				elog(ERROR, "invalid ObjTree element type %d", type);
-		}
+	fmt_to_jsonb_element(state, fmt);
 
-		elem->name = name;
-		append_premade_object(tree, elem);
-	}
+	/* push object now */
+	new_jsonb_for_qualname_id(state, classId, objectId, key, false);
 
-	va_end(args);
-	return tree;
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 }
 
 /*
- * Process the pre-built format string from the ObjTree into the output parse
- * state.
+ * A helper routine to insert identity object for the table definition
+ * to the output parse state.
  */
 static void
-objtree_fmt_to_jsonb_element(JsonbParseState *state, ObjTree *tree)
+insert_identity_object(JsonbParseState *state, Oid nspid, char *relname)
 {
-	JsonbValue	key;
-	JsonbValue	val;
-
-	if (tree->fmtinfo == NULL)
-		return;
-
-	/* Push the key first */
-	key.type = jbvString;
-	key.val.string.val = "fmt";
-	key.val.string.len = strlen(key.val.string.val);
-	pushJsonbValue(&state, WJB_KEY, &key);
-
-	/* Then process the pre-built format string */
-	val.type = jbvString;
-	val.val.string.len = tree->fmtinfo->len;
-	val.val.string.val = tree->fmtinfo->data;
-	pushJsonbValue(&state, WJB_VALUE, &val);
+	new_jsonb_for_qualname(state, nspid, relname, "identity", false);
 }
 
 /*
- * Process the role string into the output parse state.
- */
-static void
-role_to_jsonb_element(JsonbParseState *state, char *owner)
+ * Deparse the sequence CACHE option to Jsonb
+ *
+ * Verbose syntax
+ * SET CACHE %{value}s
+ * OR
+ * CACHE %{value}
+ */
+static inline void
+deparse_Seq_Cache_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata, bool alter_table)
 {
-	JsonbValue	key;
-	JsonbValue	val;
-
-	if (owner == NULL)
-		return;
+	char	   *fmt;
 
-	/* Push the key first */
-	key.type = jbvString;
-	key.val.string.val = "myowner";
-	key.val.string.len = strlen(key.val.string.val);
-	pushJsonbValue(&state, WJB_KEY, &key);
+	fmt = alter_table ? "SET CACHE %{value}s" : "CACHE %{value}s";
 
-	/* Then process the role string */
-	val.type = jbvString;
-	val.val.string.len = strlen(owner);
-	val.val.string.val = owner;
-	pushJsonbValue(&state, WJB_VALUE, &val);
+	new_jsonb_VA(state, fmt, false, 2,
+				 "clause", jbvString, "cache",
+				 "value", jbvString, psprintf(INT64_FORMAT, seqdata->seqcache));
 }
 
 /*
- * Create a JSONB representation from an ObjTree and its owner (if given).
+ * Deparse the sequence CYCLE option to Jsonb.
+ *
+ * Verbose syntax
+ * SET %{no}s CYCLE
+ * OR
+ * %{no}s CYCLE
  */
-static Jsonb *
-objtree_to_jsonb(ObjTree *tree, char *owner)
+static inline void
+deparse_Seq_Cycle_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata, bool alter_table)
 {
-	JsonbValue *value;
+	char	   *fmt;
 
-	value = objtree_to_jsonb_rec(tree, NULL, owner);
-	return JsonbValueToJsonb(value);
+	fmt = alter_table ? "SET %{no}s CYCLE" : "%{no}s CYCLE";
+
+	new_jsonb_VA(state, fmt, false, 2,
+				 "clause", jbvString, "cycle",
+				 "no", jbvString, seqdata->seqcycle ? "" : "NO");
 }
 
 /*
- * Helper for objtree_to_jsonb_rec: process an individual element from an object or
- * an array into the output parse state.
+ * Deparse the sequence INCREMENT BY option to Jsonb
+ *
+ * Verbose syntax
+ * SET INCREMENT BY %{value}s
+ * OR
+ * INCREMENT BY %{value}s
  */
-static void
-objtree_to_jsonb_element(JsonbParseState *state, ObjElem *object,
-						 JsonbIteratorToken elem_token)
+static inline void
+deparse_Seq_IncrementBy_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata, bool alter_table)
 {
-	JsonbValue	val;
-
-	switch (object->objtype)
-	{
-		case ObjTypeNull:
-			val.type = jbvNull;
-			pushJsonbValue(&state, elem_token, &val);
-			break;
-
-		case ObjTypeString:
-			val.type = jbvString;
-			val.val.string.len = strlen(object->value.string);
-			val.val.string.val = object->value.string;
-			pushJsonbValue(&state, elem_token, &val);
-			break;
-
-		case ObjTypeInteger:
-			val.type = jbvNumeric;
-			val.val.numeric = (Numeric)
-				DatumGetNumeric(DirectFunctionCall1(int8_numeric,
-													object->value.integer));
-			pushJsonbValue(&state, elem_token, &val);
-			break;
-
-		case ObjTypeBool:
-			val.type = jbvBool;
-			val.val.boolean = object->value.boolean;
-			pushJsonbValue(&state, elem_token, &val);
-			break;
-
-		case ObjTypeObject:
-			/* Recursively add the object into the existing parse state */
-			objtree_to_jsonb_rec(object->value.object, state, NULL);
-			break;
-
-		case ObjTypeArray:
-			{
-				ListCell   *cell;
-
-				pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
-				foreach(cell, object->value.array)
-				{
-					ObjElem    *elem = lfirst(cell);
+	char	   *fmt;
 
-					objtree_to_jsonb_element(state, elem, WJB_ELEM);
-				}
-				pushJsonbValue(&state, WJB_END_ARRAY, NULL);
-			}
-			break;
+	fmt = alter_table ? "SET INCREMENT BY %{value}s" : "INCREMENT BY %{value}s";
 
-		default:
-			elog(ERROR, "unrecognized object type %d", object->objtype);
-			break;
-	}
+	new_jsonb_VA(state, fmt, false, 2,
+				 "clause", jbvString, "seqincrement",
+				 "value", jbvString, psprintf(INT64_FORMAT, seqdata->seqincrement));
 }
 
 /*
- * Recursive helper for objtree_to_jsonb.
+ * Deparse the sequence MAXVALUE option to Jsonb.
+ *
+ * Verbose syntax
+ * SET MAXVALUE %{value}s
+ * OR
+ * MAXVALUE %{value}s
  */
-static JsonbValue *
-objtree_to_jsonb_rec(ObjTree *tree, JsonbParseState *state, char *owner)
+static inline void
+deparse_Seq_Maxvalue_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata, bool alter_table)
 {
-	slist_iter	iter;
-
-	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	char	   *fmt;
 
-	role_to_jsonb_element(state, owner);
-	objtree_fmt_to_jsonb_element(state, tree);
+	fmt = alter_table ? "SET MAXVALUE %{value}s" : "MAXVALUE %{value}s";
 
-	slist_foreach(iter, &tree->params)
-	{
-		ObjElem    *object = slist_container(ObjElem, node, iter.cur);
-		JsonbValue	key;
+	new_jsonb_VA(state, fmt, false, 2,
+				 "clause", jbvString, "maxvalue",
+				 "value", jbvString, psprintf(INT64_FORMAT, seqdata->seqmax));
+}
 
-		/* Push the key first */
-		key.type = jbvString;
-		key.val.string.len = strlen(object->name);
-		key.val.string.val = object->name;
-		pushJsonbValue(&state, WJB_KEY, &key);
+/*
+ * Deparse the sequence MINVALUE option to Jsonb
+ *
+ * Verbose syntax
+ * SET MINVALUE %{value}s
+ * OR
+ * MINVALUE %{value}s
+ */
+static inline void
+deparse_Seq_Minvalue_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata, bool alter_table)
+{
+	char	   *fmt;
 
-		/* Then process the value according to its type */
-		objtree_to_jsonb_element(state, object, WJB_VALUE);
-	}
+	fmt = alter_table ? "SET MINVALUE %{value}s" : "MINVALUE %{value}s";
 
-	return pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+	new_jsonb_VA(state, fmt, false, 2,
+				 "clause", jbvString, "minvalue",
+				 "value", jbvString, psprintf(INT64_FORMAT, seqdata->seqmin));
 }
 
 /*
- * Subroutine for CREATE TABLE deparsing.
- *
- * Given a table OID, obtain its constraints and append them to the given
- * elements list.  The updated list is returned.
- *
- * This works for typed tables, regular tables.
+ * Deparse the sequence OWNED BY command.
  *
- * Note that CONSTRAINT_FOREIGN constraints are always ignored.
+ * Verbose syntax
+ * OWNED BY %{owner}D
  */
-static List *
-obtainConstraints(List *elements, Oid relationId)
+static void
+deparse_Seq_OwnedBy_toJsonb(JsonbParseState *state, Oid sequenceId, bool alter_table)
 {
-	Relation	conRel;
-	ScanKeyData key;
+	Relation	depRel;
 	SysScanDesc scan;
+	ScanKeyData keys[3];
 	HeapTuple	tuple;
-	ObjTree    *constr;
+	JsonbValue *value = NULL;
 
-	Assert(OidIsValid(relationId));
-
-	/*
-	 * Scan pg_constraint to fetch all constraints linked to the given
-	 * relation.
-	 */
-	conRel = table_open(ConstraintRelationId, AccessShareLock);
-	ScanKeyInit(&key, Anum_pg_constraint_conrelid, BTEqualStrategyNumber,
-				F_OIDEQ, ObjectIdGetDatum(relationId));
-	scan = systable_beginscan(conRel, ConstraintRelidTypidNameIndexId, true,
-							  NULL, 1, &key);
+	depRel = table_open(DependRelationId, AccessShareLock);
+	ScanKeyInit(&keys[0],
+				Anum_pg_depend_classid,
+				BTEqualStrategyNumber, F_OIDEQ,
+				ObjectIdGetDatum(RelationRelationId));
+	ScanKeyInit(&keys[1],
+				Anum_pg_depend_objid,
+				BTEqualStrategyNumber, F_OIDEQ,
+				ObjectIdGetDatum(sequenceId));
+	ScanKeyInit(&keys[2],
+				Anum_pg_depend_objsubid,
+				BTEqualStrategyNumber, F_INT4EQ,
+				Int32GetDatum(0));
 
-	/*
-	 * For each constraint, add a node to the list of table elements.  In
-	 * these nodes we include not only the printable information ("fmt"), but
-	 * also separate attributes to indicate the type of constraint, for
-	 * automatic processing.
-	 */
+	scan = systable_beginscan(depRel, DependDependerIndexId, true,
+							  NULL, 3, keys);
 	while (HeapTupleIsValid(tuple = systable_getnext(scan)))
 	{
-		Form_pg_constraint constrForm;
-		char	   *contype;
+		Oid			ownerId;
+		Form_pg_depend depform;
+		char	   *colname;
 
-		constrForm = (Form_pg_constraint) GETSTRUCT(tuple);
+		depform = (Form_pg_depend) GETSTRUCT(tuple);
 
-		switch (constrForm->contype)
-		{
-			case CONSTRAINT_CHECK:
-				contype = "check";
-				break;
-			case CONSTRAINT_FOREIGN:
-				continue;		/* not here */
-			case CONSTRAINT_PRIMARY:
-				contype = "primary key";
-				break;
-			case CONSTRAINT_UNIQUE:
-				contype = "unique";
-				break;
-			case CONSTRAINT_EXCLUSION:
-				contype = "exclusion";
-				break;
-			default:
-				elog(ERROR, "unrecognized constraint type");
-		}
+		/* Only consider AUTO dependencies on pg_class */
+		if (depform->deptype != DEPENDENCY_AUTO)
+			continue;
+		if (depform->refclassid != RelationRelationId)
+			continue;
+		if (depform->refobjsubid <= 0)
+			continue;
 
-		/*
-		 * "type" and "contype" are not part of the printable output, but are
-		 * useful to programmatically distinguish these from columns and among
-		 * different constraint types.
-		 *
-		 * XXX it might be useful to also list the column names in a PK, etc.
-		 */
-		constr = new_objtree_VA("CONSTRAINT %{name}I %{definition}s", 4,
-								"type", ObjTypeString, "constraint",
-								"contype", ObjTypeString, contype,
-								"name", ObjTypeString, NameStr(constrForm->conname),
-								"definition", ObjTypeString,
-								pg_get_constraintdef_string(constrForm->oid));
+		ownerId = depform->refobjid;
+		colname = get_attname(ownerId, depform->refobjsubid, false);
+		if (colname == NULL)
+			continue;
 
-		if (constrForm->conindid &&
-			(constrForm->contype == CONSTRAINT_PRIMARY ||
-			 constrForm->contype == CONSTRAINT_UNIQUE ||
-			 constrForm->contype == CONSTRAINT_EXCLUSION))
-		{
-			Oid			tblspc = get_rel_tablespace(constrForm->conindid);
+		/* mark the begin of owner's definition object */
+		pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-			if (OidIsValid(tblspc))
-			{
-				char	   *tblspcname = get_tablespace_name(tblspc);
+		new_jsonb_VA(state, "OWNED BY %{owner}D", true, 1,
+					 "clause", jbvString, "owned");
 
-				if (!tblspcname)
-				{
-					elog(ERROR, "cache lookup failed for tablespace %u",
-									tblspc);
-				}
+		/* owner key */
+		insert_jsonb_key(state, "owner");
 
-				append_string_object(constr,
-									 "USING INDEX TABLESPACE %{tblspc}s",
-									 "tblspc",
-									 tblspcname);
-			}
-		}
+		/* owner value begin */
+		pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-		elements = lappend(elements, new_object_object(constr));
+		new_jsonb_for_qualname_id(state, RelationRelationId, ownerId, NULL, true);
+		new_jsonb_VA(state, NULL, true, 1,
+					 "attrname", jbvString, colname);
+
+		/* owner value end */
+		pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+
+		/* mark the end of owner's definition object */
+		value = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 	}
 
 	systable_endscan(scan);
-	table_close(conRel, AccessShareLock);
+	relation_close(depRel, AccessShareLock);
 
-	return elements;
+	/*
+	 * If there's no owner column, assert. The caller must have checked
+	 * presence of owned_by element before invoking this.
+	 */
+	Assert(value);
 }
 
 /*
- * Obtain the deparsed default value for the given column of the given table.
+ * Deparse the sequence START WITH option to Jsonb.
  *
- * Caller must have set a correct deparse context and must ensure that the
- * passed attribute has a default value.
+ * Verbose syntax
+ * SET START WITH %{value}s
+ * OR
+ * START WITH %{value}s
  */
-static char *
-RelationGetColumnDefault(Relation rel, AttrNumber attno, List *dpcontext,
-						 Node **expr)
+static inline void
+deparse_Seq_Startwith_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata, bool alter_table)
 {
-	Node	   *defval;
-	char	   *defstr;
+	char	   *fmt;
 
-	defval = build_column_default(rel, attno);
-	Assert(defval != NULL);
+	fmt = alter_table ? "SET START WITH %{value}s" : "START WITH %{value}s";
 
-	defstr = deparse_expression(defval, dpcontext, false, false);
+	new_jsonb_VA(state, fmt, false, 2,
+				 "clause", jbvString, "start",
+				 "value", jbvString, psprintf(INT64_FORMAT, seqdata->seqstart));
+}
 
-	/* Collect the expression for later replication safety checks */
-	if (expr)
-		*expr = defval;
+/*
+ * Deparse the sequence RESTART option to Jsonb
+ *
+ * Verbose syntax
+ * RESTART %{value}s
+ */
+static inline void
+deparse_Seq_Restart_toJsonb(JsonbParseState *state, int64 last_value)
+{
+	new_jsonb_VA(state, "RESTART %{value}s", false, 2,
+				 "clause", jbvString, "restart",
+				 "value", jbvString, psprintf(INT64_FORMAT, last_value));
+}
 
-	return defstr;
+/*
+ * Deparse the sequence AS option.
+ *
+ * Verbose syntax
+ * AS %{seqtype}T
+ */
+static inline void
+deparse_Seq_As_toJsonb(JsonbParseState *state, Form_pg_sequence seqdata)
+{
+	StringInfoData fmtStr;
+
+	initStringInfo(&fmtStr);
+	appendStringInfoString(&fmtStr, "AS");
+
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+	/* Push the key first */
+	insert_jsonb_key(state, "seqtype");
+
+	if (OidIsValid(seqdata->seqtypid))
+	{
+		appendStringInfoString(&fmtStr, " %{seqtype}T");
+
+		/* Push the value for seqtype */
+		new_jsonb_for_type(state, seqdata->seqtypid, -1);
+	}
+	else
+	{
+		if (verbose)
+			appendStringInfoString(&fmtStr, " %{seqtype}T");
+		insert_not_present_obj(state, NULL);
+	}
+
+	/* We have full fmt by now, so add jsonb element for that */
+	fmt_to_jsonb_element(state, fmtStr.data);
+
+	pfree(fmtStr.data);
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 }
 
+
 /*
- * Obtain the deparsed partition bound expression for the given table.
+ * Deparse the definition of column identity to Jsonb.
+ *
+ * Verbose syntax
+ * SET GENERATED %{option}s %{identity_type}s %{seq_definition: }s
+ * 	OR
+ * GENERATED %{option}s AS IDENTITY %{identity_type}s ( %{seq_definition: }s )
  */
-static char *
-RelationGetPartitionBound(Oid relid)
+static void
+deparse_ColumnIdentity_toJsonb(JsonbParseState *state, Oid seqrelid, char identity, bool alter_table)
 {
-	Datum		deparsed;
-	Datum		boundDatum;
-	bool		isnull;
-	HeapTuple	tuple;
+	Form_pg_sequence seqform;
+	Sequence_values *seqvalues;
+	char	   *fmt;
 
-	tuple = SearchSysCache1(RELOID, relid);
-	if (!HeapTupleIsValid(tuple))
-		elog(ERROR, "cache lookup failed for relation with OID %u", relid);
+	if (alter_table)
+		fmt = "%{identity_type}s %{seq_definition: }s";
+	else
+		fmt = "%{identity_type}s ( %{seq_definition: }s )";
 
-	boundDatum = SysCacheGetAttr(RELOID, tuple,
-								 Anum_pg_class_relpartbound,
-								 &isnull);
+	/* create object now for value of identity_column */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmt);
 
-	deparsed = DirectFunctionCall2(pg_get_expr,
-								   CStringGetTextDatum(TextDatumGetCString(boundDatum)),
-								   relid);
+	/* identity_type object creation */
+	{
+		char	   *identfmt;
 
-	ReleaseSysCache(tuple);
+		/* Push the key first */
+		insert_jsonb_key(state, "identity_type");
 
-	return TextDatumGetCString(deparsed);
+		if (alter_table)
+			identfmt = "SET GENERATED %{option}s";
+		else
+			identfmt = "GENERATED %{option}s AS IDENTITY";
+
+		if (identity == ATTRIBUTE_IDENTITY_ALWAYS)
+			new_jsonb_VA(state, identfmt, false, 1,
+						 "option", jbvString, "ALWAYS");
+		else if (identity == ATTRIBUTE_IDENTITY_BY_DEFAULT)
+			new_jsonb_VA(state, identfmt, false, 1,
+						 "option", jbvString, "BY DEFAULT");
+		else
+			insert_not_present_obj(state, verbose ? identfmt : (alter_table ? "SET GENERATED " : "GENERATED "));
+	}
+
+	/* seq_definition array object creation */
+	{
+
+		/* Push the key first */
+		insert_jsonb_key(state, "seq_definition");
+
+		pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
+		seqvalues = get_sequence_values(seqrelid);
+		seqform = seqvalues->seqform;
+
+		/* Definition elements */
+		deparse_Seq_Cache_toJsonb(state, seqform, alter_table);
+		deparse_Seq_Cycle_toJsonb(state, seqform, alter_table);
+		deparse_Seq_IncrementBy_toJsonb(state, seqform, alter_table);
+		deparse_Seq_Minvalue_toJsonb(state, seqform, alter_table);
+		deparse_Seq_Maxvalue_toJsonb(state, seqform, alter_table);
+		deparse_Seq_Startwith_toJsonb(state, seqform, alter_table);
+		deparse_Seq_Restart_toJsonb(state, seqvalues->last_value);
+		/* We purposefully do not emit OWNED BY here */
+
+		pushJsonbValue(&state, WJB_END_ARRAY, NULL);
+	}
+
+	/* end of idendity_column object */
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 }
 
+
 /*
  * Deparse a ColumnDef node within a regular (non-typed) table creation.
  *
@@ -951,20 +814,22 @@ RelationGetPartitionBound(Oid relid)
  * elsewhere (the info in the parse node is incomplete anyway).
  *
  * Verbose syntax
- * %{name}I %{coltype}T %{compression}s %{default}s %{not_null}s %{collation}s
+ * "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s
+ *  %{not_null}s %{default}s %{identity_column}s %{generated_column}s"
  */
-static ObjTree *
-deparse_ColumnDef(Relation relation, List *dpcontext, bool composite,
-				  ColumnDef *coldef, bool is_alter, Node **expr)
+static void
+deparse_ColumnDef_toJsonb(JsonbParseState *state, Relation relation,
+						  List *dpcontext, bool composite, ColumnDef *coldef,
+						  bool is_alter, Node **expr)
 {
-	ObjTree    *ret;
-	ObjTree    *tmp_obj;
 	Oid			relid = RelationGetRelid(relation);
 	HeapTuple	attrTup;
 	Form_pg_attribute attrForm;
 	Oid			typid;
 	int32		typmod;
 	Oid			typcollation;
+	char	   *fmtStr = "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s "
+		"%{not_null}s %{default}s %{identity_column}s %{generated_column}s";
 	bool		saw_notnull;
 	ListCell   *cell;
 
@@ -975,7 +840,7 @@ deparse_ColumnDef(Relation relation, List *dpcontext, bool composite,
 	 * such?
 	 */
 	if (!coldef->is_local)
-		return NULL;
+		return;
 
 	attrTup = SearchSysCacheAttName(relid, coldef->colname);
 	if (!HeapTupleIsValid(attrTup))
@@ -986,36 +851,55 @@ deparse_ColumnDef(Relation relation, List *dpcontext, bool composite,
 	get_atttypetypmodcoll(relid, attrForm->attnum,
 						  &typid, &typmod, &typcollation);
 
-	ret = new_objtree_VA("%{name}I %{coltype}T", 3,
-						 "type", ObjTypeString, "column",
-						 "name", ObjTypeString, coldef->colname,
-						 "coltype", ObjTypeObject,
-						 new_objtree_for_type(typid, typmod));
+	/* start making column object */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+	/* creat name and type elements for column */
+	new_jsonb_VA(state, fmtStr, true, 2,
+				 "name", jbvString, coldef->colname,
+				 "type", jbvString, "column");
+
+	/*
+	 * create coltype object having 4 elements: schemaname, typename, typemod,
+	 * typearray
+	 */
+	{
+		/* Push the key first */
+		insert_jsonb_key(state, "coltype");
+
+		/* Push the value */
+		new_jsonb_for_type(state, typid, typmod);
+	}
 
 	/* STORAGE clause */
 	if (!composite)
-		append_string_object(ret, "STORAGE %{colstorage}s", "colstorage",
-							 storage_name(attrForm->attstorage));
+		new_jsonb_VA(state, NULL, true, 1, "colstorage", jbvString, storage_name(attrForm->attstorage));
 
 	/* COMPRESSION clause */
-	tmp_obj = new_objtree("COMPRESSION");
-	if (coldef->compression)
-		append_string_object(tmp_obj, "%{compression_method}I",
-							 "compression_method", coldef->compression);
-	else
-		append_not_present(tmp_obj, "%{compression_method}I");
+	{
+		/* Push the key first */
+		insert_jsonb_key(state, "compression");
 
-	append_object_object(ret, "%{compression}s", tmp_obj);
+		/* Push the value now: object in this case */
+		if (coldef->compression)
+			new_jsonb_VA(state, "COMPRESSION %{compression_method}I", false, 1,
+						 "compression_method", jbvString, coldef->compression);
+		else
+			insert_not_present_obj(state, verbose ? "COMPRESSION %{compression_method}I" : "COMPRESSION");
+	}
 
-	tmp_obj = new_objtree("COLLATE");
-	if (OidIsValid(typcollation))
-		append_object_object(tmp_obj, "%{collation_name}D",
-							 new_objtree_for_qualname_id(CollationRelationId,
-														 typcollation));
-	else
-		append_not_present(tmp_obj, "%{collation_name}D");
+	/* COLLATE clause */
+	{
+		/* Push the key first */
+		insert_jsonb_key(state, "collation");
 
-	append_object_object(ret, "%{collation}s", tmp_obj);
+		if (OidIsValid(typcollation))
+			insert_collate_object(state, "COLLATE %{collation_name}D",
+								  CollationRelationId, typcollation,
+								  "collation_name");
+		else
+			insert_not_present_obj(state, verbose ? "COLLATE %{collation_name}D" : "COLLATE");
+	}
 
 	if (!composite)
 	{
@@ -1048,10 +932,13 @@ deparse_ColumnDef(Relation relation, List *dpcontext, bool composite,
 		if (is_alter && coldef->is_not_null)
 			saw_notnull = true;
 
-		append_string_object(ret, "%{not_null}s", "not_null",
-							 saw_notnull ? "NOT NULL" : "");
+		/* NOT NULL */
+		new_jsonb_VA(state, NULL, true, 1, "not_null", jbvString, saw_notnull ? "NOT NULL" : "");
+
+		/* DEFAULT: Push the key first */
+		insert_jsonb_key(state, "default");
 
-		tmp_obj = new_objtree("DEFAULT");
+		/* DEFAULT: Push the value now */
 		if (attrForm->atthasdef &&
 			coldef->generated != ATTRIBUTE_GENERATED_STORED)
 		{
@@ -1059,13 +946,12 @@ deparse_ColumnDef(Relation relation, List *dpcontext, bool composite,
 
 			defstr = RelationGetColumnDefault(relation, attrForm->attnum,
 											  dpcontext, expr);
-
-			append_string_object(tmp_obj, "%{default}s", "default", defstr);
+			new_jsonb_VA(state, "DEFAULT %{default}s", false, 1,
+						 "default", jbvString, defstr);
 		}
 		else
-			append_not_present(tmp_obj, "%{default}s");
+			insert_not_present_obj(state, verbose ? "DEFAULT %{default}s" : "DEFAULT");
 
-		append_object_object(ret, "%{default}s", tmp_obj);
 
 		/* IDENTITY COLUMN */
 		if (coldef->identity)
@@ -1079,57 +965,50 @@ deparse_ColumnDef(Relation relation, List *dpcontext, bool composite,
 				seqrelid = RangeVarGetRelid(coldef->identitySequence, NoLock, false);
 		}
 
-		tmp_obj = new_objtree("");
+		/* IDENTITY COLUMN: Push the key first */
+		insert_jsonb_key(state, "identity_column");
+
+		/* IDENTITY COLUMN: Push the value now */
 		if (OidIsValid(seqrelid))
 		{
-			ObjTree    *tmp_obj2;
 
-			tmp_obj2 = deparse_ColumnIdentity(seqrelid, coldef->identity, is_alter);
-			append_object_object(tmp_obj, "%{identity_column}s", tmp_obj2);
+			deparse_ColumnIdentity_toJsonb(state, seqrelid, coldef->identity, is_alter);
 		}
 		else
-			append_not_present(tmp_obj, "%{identity_column}s");
+			insert_not_present_obj(state, verbose ? "%{identity_column}s" : "");
 
-		append_object_object(ret, "%{identity_column}s", tmp_obj);
+		/* GENERATED COLUMN EXPRESSION: Push the key first */
+		insert_jsonb_key(state, "generated_column");
 
-		/* GENERATED COLUMN EXPRESSION */
-		tmp_obj = new_objtree("GENERATED ALWAYS AS");
+		/* GENERATED COLUMN EXPRESSION: Push the value now */
 		if (coldef->generated == ATTRIBUTE_GENERATED_STORED)
 		{
 			char	   *defstr;
 
 			defstr = RelationGetColumnDefault(relation, attrForm->attnum,
 											  dpcontext, expr);
-			append_string_object(tmp_obj, "(%{generation_expr}s) STORED",
-								 "generation_expr", defstr);
+			new_jsonb_VA(state, "GENERATED ALWAYS AS (%{generation_expr}s) STORED", false, 1,
+						 "generation_expr", jbvString, defstr);
 		}
 		else
-			append_not_present(tmp_obj, "(%{generation_expr}s) STORED");
-
-		append_object_object(ret, "%{generated_column}s", tmp_obj);
+			insert_not_present_obj(state, verbose ? "GENERATED ALWAYS AS (%{generation_expr}s) STORED" : "GENERATED ALWAYS AS");
 	}
-
 	ReleaseSysCache(attrTup);
 
-	return ret;
+	/* mark the end of one column object */
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 }
 
 /*
- * Deparse a ColumnDef node within a typed table creation. This is simpler
- * than the regular case, because we don't have to emit the type declaration,
- * collation, or default. Here we only return something if the column is being
- * declared NOT NULL.
+ * Helper for deparse_ColumnDef_typed_toJsonb()
  *
- * As in deparse_ColumnDef, any other constraint is processed elsewhere.
- *
- * Verbose syntax
- * %{name}I WITH OPTIONS %{not_null}s %{default}s.
+ * Returns true if we need to deparse a ColumnDef node within a typed
+ * table creation.
  */
-static ObjTree *
-deparse_ColumnDef_typed(Relation relation, List *dpcontext, ColumnDef *coldef)
+static bool
+deparse_ColDef_typed_needed(Relation relation, ColumnDef *coldef,
+							Form_pg_attribute *atFormOut, bool *notnull)
 {
-	ObjTree    *ret = NULL;
-	ObjTree    *tmp_obj;
 	Oid			relid = RelationGetRelid(relation);
 	HeapTuple	attrTup;
 	Form_pg_attribute attrForm;
@@ -1143,8 +1022,12 @@ deparse_ColumnDef_typed(Relation relation, List *dpcontext, ColumnDef *coldef)
 	if (!HeapTupleIsValid(attrTup))
 		elog(ERROR, "could not find cache entry for column \"%s\" of relation %u",
 			 coldef->colname, relid);
+
 	attrForm = (Form_pg_attribute) GETSTRUCT(attrTup);
 
+	if (atFormOut)
+		*atFormOut = attrForm;
+
 	get_atttypetypmodcoll(relid, attrForm->attnum,
 						  &typid, &typmod, &typcollation);
 
@@ -1165,203 +1048,226 @@ deparse_ColumnDef_typed(Relation relation, List *dpcontext, ColumnDef *coldef)
 		}
 	}
 
+	if (notnull)
+		*notnull = saw_notnull;
+
 	if (!saw_notnull && !attrForm->atthasdef)
 	{
 		ReleaseSysCache(attrTup);
-		return NULL;
+		return false;
 	}
 
-	tmp_obj = new_objtree("DEFAULT");
+	ReleaseSysCache(attrTup);
+	return true;
+}
+
+/*
+ * Deparse a ColumnDef node within a typed table creation. This is simpler
+ * than the regular case, because we don't have to emit the type declaration,
+ * collation, or default. Here we only return something if the column is being
+ * declared NOT NULL.
+ *
+ * As in deparse_ColumnDef, any other constraint is processed elsewhere.
+ *
+ * Verbose syntax
+ * %{name}I WITH OPTIONS %{not_null}s %{default}s.
+ */
+static void
+deparse_ColumnDef_typed_toJsonb(JsonbParseState *state, Relation relation,
+								List *dpcontext, ColumnDef *coldef)
+{
+	char	   *fmtStr = "%{name}I WITH OPTIONS %{not_null}s %{default}s";
+	bool		needed;
+	Form_pg_attribute attrForm;
+	bool		saw_notnull;
+
+	needed = deparse_ColDef_typed_needed(relation, coldef, &attrForm, &saw_notnull);
+	if (!needed)
+		return;
+
+	/* start making column object */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmtStr);
+
+	/* Insert TYPE, NAME and NOT_NULL elements */
+	new_jsonb_VA(state, fmtStr, true, 3,
+				 "type", jbvString, "column",
+				 "name", jbvString, coldef->colname,
+				 "not_null", jbvString, saw_notnull ? "NOT NULL" : "");
+
+	/* DEFAULT: Push the key first */
+	insert_jsonb_key(state, "default");
+
+	/* DEFAULT: Push the value now */
 	if (attrForm->atthasdef)
 	{
 		char	   *defstr;
 
 		defstr = RelationGetColumnDefault(relation, attrForm->attnum,
 										  dpcontext, NULL);
-
-		append_string_object(tmp_obj, "%{default}s", "default", defstr);
+		new_jsonb_VA(state, "DEFAULT %{default}s", false, 1,
+					 "default", jbvString, defstr);
 	}
 	else
-		append_not_present(tmp_obj, "%{default}s");
+		insert_not_present_obj(state, verbose ? "DEFAULT %{default}s" : "DEFAULT");
 
-	ret = new_objtree_VA("%{name}I WITH OPTIONS %{not_null}s %{default}s", 4,
-						 "type", ObjTypeString, "column",
-						 "name", ObjTypeString, coldef->colname,
-						 "not_null", ObjTypeString,
-						 saw_notnull ? "NOT NULL" : "",
-						 "default", ObjTypeObject, tmp_obj);
+	/* mark the end of column object */
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 
 	/* Generated columns are not supported on typed tables, so we are done */
 
-	ReleaseSysCache(attrTup);
-
-	return ret;
 }
 
 /*
- * Deparse the definition of column identity.
+ * Subroutine for CREATE TABLE deparsing.
  *
- * Verbose syntax
- * SET GENERATED %{option}s %{identity_type}s %{seq_definition: }s
- * 	OR
- * GENERATED %{option}s AS IDENTITY %{identity_type}s ( %{seq_definition: }s )
+ * Returns true if at-least one local column is present
+ * (i.e. not inherited).
  */
-static ObjTree *
-deparse_ColumnIdentity(Oid seqrelid, char identity, bool alter_table)
+static bool
+table_elem_present_col(Relation relation, List *tableElements, bool typed)
 {
-	ObjTree    *ret;
-	ObjTree    *ident_obj;
-	List	   *elems = NIL;
-	Form_pg_sequence seqform;
-	Sequence_values *seqvalues;
-	char	   *identfmt;
-	char	   *objfmt;
+	ListCell   *lc;
 
-	if (alter_table)
-	{
-		identfmt = "SET GENERATED ";
-		objfmt = "%{option}s";
-	}
-	else
+	foreach(lc, tableElements)
 	{
-		identfmt = "GENERATED ";
-		objfmt = "%{option}s AS IDENTITY";
-	}
-
-	ident_obj = new_objtree(identfmt);
-	if (identity == ATTRIBUTE_IDENTITY_ALWAYS)
-		append_string_object(ident_obj, objfmt, "option", "ALWAYS");
-	else if (identity == ATTRIBUTE_IDENTITY_BY_DEFAULT)
-		append_string_object(ident_obj, objfmt, "option", "BY DEFAULT");
-	else
-		append_not_present(ident_obj, objfmt);
-
-	ret = new_objtree_VA("%{identity_type}s", 1,
-						 "identity_type", ObjTypeObject, ident_obj);
-
-	seqvalues = get_sequence_values(seqrelid);
-	seqform = seqvalues->seqform;
-
-	/* Definition elements */
-	elems = lappend(elems, deparse_Seq_Cache(seqform, alter_table));
-	elems = lappend(elems, deparse_Seq_Cycle(seqform, alter_table));
-	elems = lappend(elems, deparse_Seq_IncrementBy(seqform, alter_table));
-	elems = lappend(elems, deparse_Seq_Minvalue(seqform, alter_table));
-	elems = lappend(elems, deparse_Seq_Maxvalue(seqform, alter_table));
-	elems = lappend(elems, deparse_Seq_Startwith(seqform, alter_table));
-	elems = lappend(elems, deparse_Seq_Restart(seqvalues->last_value));
-	/* We purposefully do not emit OWNED BY here */
+		Node	   *elt = (Node *) lfirst(lc);
 
-	if (alter_table)
-		append_array_object(ret, "%{seq_definition: }s", elems);
-	else
-		append_array_object(ret, "( %{seq_definition: }s )", elems);
+		switch (nodeTag(elt))
+		{
+			case T_ColumnDef:
+				{
+					if (typed)
+					{
+						if (deparse_ColDef_typed_needed(relation,
+														((ColumnDef *) elt), NULL, NULL))
+							return true;
+					}
+					else
+					{
+						if (((ColumnDef *) elt)->is_local)
+							return true;
+					}
+				}
+				break;
+			case T_Constraint:
+				break;
+			default:
+				elog(ERROR, "invalid node type %d", nodeTag(elt));
+		}
+	}
 
-	return ret;
+	return false;
 }
 
+
 /*
- * ... ALTER COLUMN ... SET/RESET (...)
+ * Subroutine for CREATE TABLE deparsing.
  *
- * Verbose syntax
- * ALTER COLUMN %{column}I RESET|SET (%{options:, }s)
+ * Returns true if at-least one constraint is present.
+ *
+ * Note that CONSTRAINT_FOREIGN constraints are always ignored.
  */
-static ObjTree *
-deparse_ColumnSetOptions(AlterTableCmd *subcmd)
+static bool
+table_elem_present_const(Oid relationId)
 {
-	List	   *sets = NIL;
-	ListCell   *cell;
-	ObjTree    *ret;
-	bool		is_reset = subcmd->subtype == AT_ResetOptions;
+	Relation	conRel;
+	ScanKeyData key;
+	SysScanDesc scan;
+	HeapTuple	tuple;
+	bool		bconst = false;
+
+	Assert(OidIsValid(relationId));
 
-	ret = new_objtree_VA("ALTER COLUMN %{column}I %{option}s", 2,
-						 "column", ObjTypeString, subcmd->name,
-						 "option", ObjTypeString, is_reset ? "RESET" : "SET");
+	/*
+	 * Scan pg_constraint to fetch all constraints linked to the given
+	 * relation.
+	 */
+	conRel = table_open(ConstraintRelationId, AccessShareLock);
+	ScanKeyInit(&key, Anum_pg_constraint_conrelid, BTEqualStrategyNumber,
+				F_OIDEQ, ObjectIdGetDatum(relationId));
+	scan = systable_beginscan(conRel, ConstraintRelidTypidNameIndexId, true,
+							  NULL, 1, &key);
 
-	foreach(cell, (List *) subcmd->def)
+	while (HeapTupleIsValid(tuple = systable_getnext(scan)))
 	{
-		DefElem    *elem;
-		ObjTree    *set;
+		Form_pg_constraint constrForm;
 
-		elem = (DefElem *) lfirst(cell);
-		set = deparse_DefElem(elem, is_reset);
-		sets = lappend(sets, new_object_object(set));
+		constrForm = (Form_pg_constraint) GETSTRUCT(tuple);
+
+		switch (constrForm->contype)
+		{
+			case CONSTRAINT_CHECK:
+			case CONSTRAINT_PRIMARY:
+			case CONSTRAINT_UNIQUE:
+			case CONSTRAINT_EXCLUSION:
+				bconst = true;
+				break;
+			case CONSTRAINT_FOREIGN:
+				continue;		/* not here */
+			default:
+				elog(ERROR, "unrecognized constraint type");
+		}
 	}
 
-	Assert(sets);
-	append_array_object(ret, "(%{options:, }s)", sets);
+	systable_endscan(scan);
+	table_close(conRel, AccessShareLock);
 
-	return ret;
+	return bconst;
 }
 
 /*
- * Deparse SET/RESET clause as used by ALTER TABLE ... SET/RESET (...)
+ * Subroutine for CREATE TABLE deparsing.
  *
- * Verbose syntax
- * RESET|SET (%{options:, }s)
+ * Deal with all the table elements (columns and constraints).
+ *
+ * Note we ignore constraints in the parse node here; they are extracted from
+ * system catalogs instead.
  */
-static ObjTree *
-deparse_RelSetOptions(AlterTableCmd *subcmd)
+
+static void
+deparse_TableElems_ToJsonb(JsonbParseState *state, Relation relation,
+						   List *tableElements, List *dpcontext,
+						   bool typed, bool composite)
 {
-	List	   *sets = NIL;
-	ListCell   *cell;
-	bool		is_reset = subcmd->subtype == AT_ResetRelOptions;
+	ListCell   *lc;
 
-	foreach(cell, (List *) subcmd->def)
+	foreach(lc, tableElements)
 	{
-		DefElem    *elem;
-		ObjTree    *set;
+		Node	   *elt = (Node *) lfirst(lc);
 
-		elem = (DefElem *) lfirst(cell);
-		set = deparse_DefElem(elem, is_reset);
-		sets = lappend(sets, new_object_object(set));
+		switch (nodeTag(elt))
+		{
+			case T_ColumnDef:
+				{
+					if (typed)
+						deparse_ColumnDef_typed_toJsonb(state, relation, dpcontext,
+														(ColumnDef *) elt);
+					else
+						deparse_ColumnDef_toJsonb(state, relation, dpcontext,
+												  composite, (ColumnDef *) elt,
+												  false, NULL);
+				}
+				break;
+			case T_Constraint:
+				break;
+			default:
+				elog(ERROR, "invalid node type %d", nodeTag(elt));
+		}
 	}
 
-	Assert(sets);
-
-	return new_objtree_VA("%{set_reset}s (%{options:, }s)", 2,
-						  "set_reset", ObjTypeString, is_reset ? "RESET" : "SET",
-						  "options", ObjTypeArray, sets);
 }
 
 /*
- * Deparse DefElems, as used e.g. by ALTER COLUMN ... SET, into a list of SET
- * (...)  or RESET (...) contents.
+ * Subroutine for CREATE TABLE deparsing.
  *
- * Verbose syntax
- * %{label}s = %{value}L
- */
-static ObjTree *
-deparse_DefElem(DefElem *elem, bool is_reset)
-{
-	ObjTree    *ret;
-	ObjTree    *optname = new_objtree("");
-
-	if (elem->defnamespace != NULL)
-		append_string_object(optname, "%{schema}I.", "schema",
-							 elem->defnamespace);
-
-	append_string_object(optname, "%{label}I", "label", elem->defname);
-
-	ret = new_objtree_VA("%{label}s", 1,
-						 "label", ObjTypeObject, optname);
-
-	if (!is_reset)
-		append_string_object(ret, "= %{value}L", "value",
-							 elem->arg ? defGetString(elem) :
-							 defGetBoolean(elem) ? "TRUE" : "FALSE");
-
-	return ret;
-}
-
-/*
  * Deparse the INHERITS relations.
  *
  * Given a table OID, return a schema-qualified table list representing
  * the parent tables.
  */
 static List *
-deparse_InhRelations(Oid objectId)
+deparse_InhRels_ToJsonb(Oid objectId)
 {
 	List	   *parents = NIL;
 	Relation	inhRel;
@@ -1381,12 +1287,9 @@ deparse_InhRelations(Oid objectId)
 
 	while (HeapTupleIsValid(tuple = systable_getnext(scan)))
 	{
-		ObjTree    *parent;
 		Form_pg_inherits formInh = (Form_pg_inherits) GETSTRUCT(tuple);
 
-		parent = new_objtree_for_qualname_id(RelationRelationId,
-											 formInh->inhparent);
-		parents = lappend(parents, new_object_object(parent));
+		parents = lappend_oid(parents, formInh->inhparent);
 	}
 
 	systable_endscan(scan);
@@ -1396,445 +1299,338 @@ deparse_InhRelations(Oid objectId)
 }
 
 /*
- * Deparse the ON COMMIT ... clause for CREATE ... TEMPORARY ...
- *
- * Verbose syntax
- * ON COMMIT %{on_commit_value}s
- */
-static ObjTree *
-deparse_OnCommitClause(OnCommitAction option)
-{
-	ObjTree    *ret  = new_objtree("ON COMMIT");
-	switch (option)
-	{
-		case ONCOMMIT_DROP:
-			append_string_object(ret, "%{on_commit_value}s",
-								 "on_commit_value", "DROP");
-			break;
-
-		case ONCOMMIT_DELETE_ROWS:
-			append_string_object(ret, "%{on_commit_value}s",
-								 "on_commit_value", "DELETE ROWS");
-			break;
-
-		case ONCOMMIT_PRESERVE_ROWS:
-			append_string_object(ret, "%{on_commit_value}s",
-								 "on_commit_value", "PRESERVE ROWS");
-			break;
-
-		case ONCOMMIT_NOOP:
-			append_not_present(ret, "%{on_commit_value}s");
-			break;
-	}
-
-	return ret;
-}
-
-/*
- * Deparse the sequence CACHE option.
- *
- * Verbose syntax
- * SET CACHE %{value}s
- * OR
- * CACHE %{value}
- */
-static inline ObjElem *
-deparse_Seq_Cache(Form_pg_sequence seqdata, bool alter_table)
-{
-	ObjTree    *ret;
-	char	   *fmt;
-
-	fmt = alter_table ? "SET CACHE %{value}s" : "CACHE %{value}s";
-
-	ret = new_objtree_VA(fmt, 2,
-						 "clause", ObjTypeString, "cache",
-						 "value", ObjTypeString,
-						 psprintf(INT64_FORMAT, seqdata->seqcache));
-
-	return new_object_object(ret);
-}
-
-/*
- * Deparse the sequence CYCLE option.
+ * Subroutine for CREATE TABLE deparsing.
  *
- * Verbose syntax
- * SET %{no}s CYCLE
- * OR
- * %{no}s CYCLE
- */
-static inline ObjElem *
-deparse_Seq_Cycle(Form_pg_sequence seqdata, bool alter_table)
-{
-	ObjTree    *ret;
-	char	   *fmt;
-
-	fmt = alter_table ? "SET %{no}s CYCLE" : "%{no}s CYCLE";
-
-	ret = new_objtree_VA(fmt, 2,
-						 "clause", ObjTypeString, "cycle",
-						 "no", ObjTypeString,
-						 seqdata->seqcycle ? "" : "NO");
-
-	return new_object_object(ret);
-}
-
-/*
- * Deparse the sequence INCREMENT BY option.
+ * Given a table OID, obtain its constraints and append them to the given
+ * JsonbParseState.
  *
- * Verbose syntax
- * SET INCREMENT BY %{value}s
- * OR
- * INCREMENT BY %{value}s
- */
-static inline ObjElem *
-deparse_Seq_IncrementBy(Form_pg_sequence seqdata, bool alter_table)
-{
-	ObjTree    *ret;
-	char	   *fmt;
-
-	fmt = alter_table ? "SET INCREMENT BY %{value}s" : "INCREMENT BY %{value}s";
-
-	ret = new_objtree_VA(fmt, 2,
-						 "clause", ObjTypeString, "seqincrement",
-						 "value", ObjTypeString,
-						 psprintf(INT64_FORMAT, seqdata->seqincrement));
-
-	return new_object_object(ret);
-}
-
-/*
- * Deparse the sequence MAXVALUE option.
+ * This works for typed tables, regular tables.
  *
- * Verbose syntax
- * SET MAXVALUE %{value}s
- * OR
- * MAXVALUE %{value}s
+ * Note that CONSTRAINT_FOREIGN constraints are always ignored.
  */
-static inline ObjElem *
-deparse_Seq_Maxvalue(Form_pg_sequence seqdata, bool alter_table)
+static void
+deparse_Constraints_ToJsonb(JsonbParseState *state, Oid relationId)
 {
-	ObjTree    *ret;
-	char	   *fmt;
-
-	fmt = alter_table ? "SET MAXVALUE %{value}s" : "MAXVALUE %{value}s";
-
-	ret = new_objtree_VA(fmt, 2,
-						 "clause", ObjTypeString, "maxvalue",
-						 "value", ObjTypeString,
-						 psprintf(INT64_FORMAT, seqdata->seqmax));
+	Relation	conRel;
+	ScanKeyData key;
+	SysScanDesc scan;
+	HeapTuple	tuple;
 
-	return new_object_object(ret);
-}
+	Assert(OidIsValid(relationId));
 
-/*
- * Deparse the sequence MINVALUE option.
- *
- * Verbose syntax
- * SET MINVALUE %{value}s
- * OR
- * MINVALUE %{value}s
- */
-static inline ObjElem *
-deparse_Seq_Minvalue(Form_pg_sequence seqdata, bool alter_table)
-{
-	ObjTree    *ret;
-	char	   *fmt;
+	/*
+	 * Scan pg_constraint to fetch all constraints linked to the given
+	 * relation.
+	 */
+	conRel = table_open(ConstraintRelationId, AccessShareLock);
+	ScanKeyInit(&key, Anum_pg_constraint_conrelid, BTEqualStrategyNumber,
+				F_OIDEQ, ObjectIdGetDatum(relationId));
+	scan = systable_beginscan(conRel, ConstraintRelidTypidNameIndexId, true,
+							  NULL, 1, &key);
 
-	fmt = alter_table ? "SET MINVALUE %{value}s" : "MINVALUE %{value}s";
+	/*
+	 * For each constraint, add a node to the list of table elements.  In
+	 * these nodes we include not only the printable information ("fmt"), but
+	 * also separate attributes to indicate the type of constraint, for
+	 * automatic processing.
+	 */
+	while (HeapTupleIsValid(tuple = systable_getnext(scan)))
+	{
+		Form_pg_constraint constrForm;
+		char	   *contype;
+		char	   *fmtStr = "CONSTRAINT %{name}I %{definition}s";
 
-	ret = new_objtree_VA(fmt, 2,
-						 "clause", ObjTypeString, "minvalue",
-						 "value", ObjTypeString,
-						 psprintf(INT64_FORMAT, seqdata->seqmin));
+		constrForm = (Form_pg_constraint) GETSTRUCT(tuple);
 
-	return new_object_object(ret);
-}
+		switch (constrForm->contype)
+		{
+			case CONSTRAINT_CHECK:
+				contype = "check";
+				break;
+			case CONSTRAINT_FOREIGN:
+				continue;		/* not here */
+			case CONSTRAINT_PRIMARY:
+				contype = "primary key";
+				break;
+			case CONSTRAINT_UNIQUE:
+				contype = "unique";
+				break;
+			case CONSTRAINT_EXCLUSION:
+				contype = "exclusion";
+				break;
+			default:
+				elog(ERROR, "unrecognized constraint type");
+		}
 
-/*
- * Deparse the sequence OWNED BY command.
- *
- * Verbose syntax
- * OWNED BY %{owner}D
- */
-static ObjElem *
-deparse_Seq_OwnedBy(Oid sequenceId, bool alter_table)
-{
-	ObjTree    *ret = NULL;
-	Relation	depRel;
-	SysScanDesc scan;
-	ScanKeyData keys[3];
-	HeapTuple	tuple;
+		/*
+		 * "type" and "contype" are not part of the printable output, but are
+		 * useful to programmatically distinguish these from columns and among
+		 * different constraint types.
+		 *
+		 * XXX it might be useful to also list the column names in a PK, etc.
+		 */
 
-	depRel = table_open(DependRelationId, AccessShareLock);
-	ScanKeyInit(&keys[0],
-				Anum_pg_depend_classid,
-				BTEqualStrategyNumber, F_OIDEQ,
-				ObjectIdGetDatum(RelationRelationId));
-	ScanKeyInit(&keys[1],
-				Anum_pg_depend_objid,
-				BTEqualStrategyNumber, F_OIDEQ,
-				ObjectIdGetDatum(sequenceId));
-	ScanKeyInit(&keys[2],
-				Anum_pg_depend_objsubid,
-				BTEqualStrategyNumber, F_INT4EQ,
-				Int32GetDatum(0));
+		pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-	scan = systable_beginscan(depRel, DependDependerIndexId, true,
-							  NULL, 3, keys);
-	while (HeapTupleIsValid(tuple = systable_getnext(scan)))
-	{
-		Oid			ownerId;
-		Form_pg_depend depform;
-		ObjTree    *tmp_obj;
-		char	   *colname;
+		new_jsonb_VA(state, fmtStr, true, 4,
+					 "type", jbvString, "constraint",
+					 "contype", jbvString, contype,
+					 "name", jbvString, NameStr(constrForm->conname),
+					 "definition", jbvString,
+					 pg_get_constraintdef_string(constrForm->oid));
 
-		depform = (Form_pg_depend) GETSTRUCT(tuple);
+		if (constrForm->conindid &&
+			(constrForm->contype == CONSTRAINT_PRIMARY ||
+			 constrForm->contype == CONSTRAINT_UNIQUE ||
+			 constrForm->contype == CONSTRAINT_EXCLUSION))
+		{
+			Oid			tblspc = get_rel_tablespace(constrForm->conindid);
 
-		/* Only consider AUTO dependencies on pg_class */
-		if (depform->deptype != DEPENDENCY_AUTO)
-			continue;
-		if (depform->refclassid != RelationRelationId)
-			continue;
-		if (depform->refobjsubid <= 0)
-			continue;
+			if (OidIsValid(tblspc))
+			{
+				char	   *tblspcname = get_tablespace_name(tblspc);
 
-		ownerId = depform->refobjid;
-		colname = get_attname(ownerId, depform->refobjsubid, false);
-		if (colname == NULL)
-			continue;
+				if (!tblspcname)
+					elog(ERROR, "cache lookup failed for tablespace %u", tblspc);
+
+				new_jsonb_VA(state, "USING INDEX TABLESPACE %{tblspc}s", true, 1,
+							 "tblspc", jbvString, tblspcname);
+			}
+		}
 
-		tmp_obj = new_objtree_for_qualname_id(RelationRelationId, ownerId);
-		append_string_object(tmp_obj, "attrname", "attrname", colname);
-		ret = new_objtree_VA("OWNED BY %{owner}D", 2,
-							 "clause", ObjTypeString, "owned",
-							 "owner", ObjTypeObject, tmp_obj);
+		pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 	}
 
 	systable_endscan(scan);
-	relation_close(depRel, AccessShareLock);
-
-	/*
-	 * If there's no owner column, emit an empty OWNED BY element, set up so
-	 * that it won't print anything.
-	 */
-	if (!ret)
-		/* XXX this shouldn't happen ... */
-		ret = new_objtree_VA("OWNED BY %{owner}D", 3,
-							 "clause", ObjTypeString, "owned",
-							 "owner", ObjTypeNull,
-							 "present", ObjTypeBool, false);
-
-	return new_object_object(ret);
+	table_close(conRel, AccessShareLock);
 }
 
 /*
- * Deparse the sequence RESTART option.
+ * Deparse DefElems, as used by Create Table
  *
  * Verbose syntax
- * RESTART %{value}s
+ * %{label}s = %{value}L
  */
-static inline ObjElem *
-deparse_Seq_Restart(int64 last_value)
+static void
+deparse_DefElem_ToJsonb(JsonbParseState *state, DefElem *elem, bool is_reset)
 {
-	ObjTree    *ret;
+	StringInfoData fmtStr;
 
-	ret = new_objtree_VA("RESTART %{value}s", 2,
-						 "clause", ObjTypeString, "restart",
-						 "value", ObjTypeString,
-						 psprintf(INT64_FORMAT, last_value));
+	initStringInfo(&fmtStr);
 
-	return new_object_object(ret);
-}
+	appendStringInfoString(&fmtStr, "%{label}s");
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-/*
- * Deparse the sequence AS option.
- *
- * Verbose syntax
- * AS %{seqtype}T
- */
-static inline ObjElem *
-deparse_Seq_As(Form_pg_sequence seqdata)
-{
-	ObjTree    *ret;
+	/* LABEL */
+	{
+		StringInfoData labelfmt;
 
-	ret = new_objtree("AS");
-	if (OidIsValid(seqdata->seqtypid))
-		append_object_object(ret, "%{seqtype}T",
-							 new_objtree_for_type(seqdata->seqtypid, -1));
-	else
-		append_not_present(ret, "%{seqtype}T");
+		initStringInfo(&labelfmt);
+
+		/* insert LABEL as key */
+		insert_jsonb_key(state, "label");
+
+		/* LABEL's value is an object */
+		pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-	return new_object_object(ret);
+		if (elem->defnamespace != NULL)
+		{
+			appendStringInfoString(&labelfmt, "%{schema}I.");
+			new_jsonb_VA(state, NULL, true, 1, "schema", jbvString, elem->defnamespace);
+		}
+
+		appendStringInfoString(&labelfmt, "%{label}I");
+		new_jsonb_VA(state, NULL, true, 1, "label", jbvString, elem->defname);
+
+		fmt_to_jsonb_element(state, labelfmt.data);
+		pfree(labelfmt.data);
+
+		pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+	}
+
+	/* VALUE */
+	if (!is_reset)
+	{
+		appendStringInfoString(&fmtStr, " = %{value}L");
+		new_jsonb_VA(state, NULL, true, 1, "value", jbvString,
+					 elem->arg ? defGetString(elem) :
+					 defGetBoolean(elem) ? "TRUE" : "FALSE");
+	}
+
+	fmt_to_jsonb_element(state, fmtStr.data);
+	pfree(fmtStr.data);
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 }
 
 /*
- * Deparse the sequence START WITH option.
+ * Deparse SET/RESET as used by
+ * ALTER TABLE ... ALTER COLUMN ... SET/RESET (...)
  *
  * Verbose syntax
- * SET START WITH %{value}s
- * OR
- * START WITH %{value}s
+ * ALTER COLUMN %{column}I RESET|SET (%{options:, }s)
  */
-static inline ObjElem *
-deparse_Seq_Startwith(Form_pg_sequence seqdata, bool alter_table)
+static void
+deparse_ColumnSetOptions_ToJsonb(JsonbParseState *state, AlterTableCmd *subcmd)
 {
-	ObjTree    *ret;
-	char	   *fmt;
+	ListCell   *cell;
+	bool		is_reset = subcmd->subtype == AT_ResetOptions;
+	bool		elem_found PG_USED_FOR_ASSERTS_ONLY = false;
 
-	fmt = alter_table ? "SET START WITH %{value}s" : "START WITH %{value}s";
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	new_jsonb_VA(state,
+				 "ALTER COLUMN %{column}I %{option}s (%{options:, }s)", true, 2,
+				 "column", jbvString, subcmd->name,
+				 "option", jbvString, is_reset ? "RESET" : "SET");
+
+	insert_jsonb_key(state, "options");
+	pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
+	foreach(cell, (List *) subcmd->def)
+	{
+		DefElem    *elem;
+
+		elem = (DefElem *) lfirst(cell);
+		deparse_DefElem_ToJsonb(state, elem, is_reset);
+
+#ifdef USE_ASSERT_CHECKING
+		elem_found = true;
+#endif
+	}
 
-	ret = new_objtree_VA(fmt, 2,
-						 "clause", ObjTypeString, "start",
-						 "value", ObjTypeString,
-						 psprintf(INT64_FORMAT, seqdata->seqstart));
+	pushJsonbValue(&state, WJB_END_ARRAY, NULL);
 
-	return new_object_object(ret);
+	Assert(elem_found);
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 }
 
 /*
- * Subroutine for CREATE TABLE deparsing.
- *
- * Deal with all the table elements (columns and constraints).
+ * Deparse SET/RESET as used by ALTER TABLE ... SET/RESET (...)
  *
- * Note we ignore constraints in the parse node here; they are extracted from
- * system catalogs instead.
+ * Verbose syntax
+ * RESET|SET (%{options:, }s)
  */
-static List *
-deparse_TableElements(Relation relation, List *tableElements, List *dpcontext,
-					  bool typed, bool composite)
+static void
+deparse_RelSetOptions_toJsonb(JsonbParseState *state, AlterTableCmd *subcmd)
 {
-	List	   *elements = NIL;
-	ListCell   *lc;
+	ListCell   *cell;
+	bool		is_reset = subcmd->subtype == AT_ResetRelOptions;
+	bool		elem_found PG_USED_FOR_ASSERTS_ONLY = false;
 
-	foreach(lc, tableElements)
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	new_jsonb_VA(state, "%{set_reset}s (%{options:, }s)", true, 1,
+				 "set_reset", jbvString, is_reset ? "RESET" : "SET");
+
+	/* insert options array */
+	insert_jsonb_key(state, "options");
+
+	pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
+	foreach(cell, (List *) subcmd->def)
 	{
-		Node	   *elt = (Node *) lfirst(lc);
+		DefElem    *elem;
 
-		switch (nodeTag(elt))
-		{
-			case T_ColumnDef:
-				{
-					ObjTree    *tree;
-
-					tree = typed ?
-						deparse_ColumnDef_typed(relation, dpcontext,
-												(ColumnDef *) elt) :
-						deparse_ColumnDef(relation, dpcontext,
-										  composite, (ColumnDef *) elt,
-										  false, NULL);
-					if (tree != NULL)
-						elements = lappend(elements, new_object_object(tree));
-				}
-				break;
-			case T_Constraint:
-				break;
-			default:
-				elog(ERROR, "invalid node type %d", nodeTag(elt));
-		}
+		elem = (DefElem *) lfirst(cell);
+		deparse_DefElem_ToJsonb(state, elem, is_reset);
+
+#ifdef USE_ASSERT_CHECKING
+		elem_found = true;
+#endif
 	}
 
-	return elements;
+	pushJsonbValue(&state, WJB_END_ARRAY, NULL);
+
+	Assert(elem_found);
+
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 }
 
 /*
- * Deparse a CreateSeqStmt.
- *
- * Given a sequence OID and the parse tree that created it, return an ObjTree
- * representing the creation command.
- *
- * Note: We need to deparse the CREATE SEQUENCE command for the TABLE
- * commands. For example, When creating a table, if we specify a column as a
- * sequence type, then we will create a sequence for that column and set that
- * sequence OWNED BY the table.
- *
- * Verbose syntax
- * CREATE %{persistence}s SEQUENCE %{identity}D %{definition: }s
+ * Deparse WITH clause, as used by Create Table.
  */
-static ObjTree *
-deparse_CreateSeqStmt(Oid objectId, Node *parsetree)
+static void
+deparse_withObj_ToJsonb(JsonbParseState *state, char *fmt, CreateStmt *node)
 {
-	ObjTree    *ret;
-	Relation	relation;
-	List	   *elems = NIL;
-	Form_pg_sequence seqform;
-	Sequence_values *seqvalues;
-	CreateSeqStmt *createSeqStmt = (CreateSeqStmt *) parsetree;
-
-	/*
-	 * Only support sequence for IDENTITY COLUMN output separately (via CREATE
-	 * TABLE or ALTER TABLE). Otherwise, return empty here.
-	 */
-	if (createSeqStmt->for_identity)
-		return NULL;
+	ListCell   *cell;
 
-	seqvalues = get_sequence_values(objectId);
-	seqform = seqvalues->seqform;
+	/* with_clause's value is an object */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+	fmt_to_jsonb_element(state, fmt);
 
-	/* Definition elements */
-	elems = lappend(elems, deparse_Seq_Cache(seqform, false));
-	elems = lappend(elems, deparse_Seq_Cycle(seqform, false));
-	elems = lappend(elems, deparse_Seq_IncrementBy(seqform, false));
-	elems = lappend(elems, deparse_Seq_Minvalue(seqform, false));
-	elems = lappend(elems, deparse_Seq_Maxvalue(seqform, false));
-	elems = lappend(elems, deparse_Seq_Startwith(seqform, false));
-	elems = lappend(elems, deparse_Seq_Restart(seqvalues->last_value));
-	elems = lappend(elems, deparse_Seq_As(seqform));
+	/* WITH */
+	{
+		/* insert with as key */
+		insert_jsonb_key(state, "with");
 
-	/* We purposefully do not emit OWNED BY here */
+		/* with's value is an array */
+		pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
 
-	relation = relation_open(objectId, AccessShareLock);
+		/* add elements to array */
+		foreach(cell, node->options)
+		{
+			DefElem    *opt = (DefElem *) lfirst(cell);
 
-	ret = new_objtree_VA("CREATE %{persistence}s SEQUENCE %{if_not_exists}s %{identity}D %{definition: }s", 4,
-						 "persistence", ObjTypeString,
-						 get_persistence_str(relation->rd_rel->relpersistence),
-						 "if_not_exists", ObjTypeString,
-						 createSeqStmt->if_not_exists ? "IF NOT EXISTS" : "",
-						 "identity", ObjTypeObject,
-						 new_objtree_for_qualname(relation->rd_rel->relnamespace,
-												  RelationGetRelationName(relation)),
-						 "definition", ObjTypeArray, elems);
+			deparse_DefElem_ToJsonb(state, opt, false);
+		}
 
-	relation_close(relation, AccessShareLock);
+		/* with's array end */
+		pushJsonbValue(&state, WJB_END_ARRAY, NULL);
+	}
 
-	return ret;
+	/* with_clause's object end */
+	pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 }
 
 /*
  * Deparse a CreateStmt (CREATE TABLE).
  *
- * Given a table OID and the parse tree that created it, return an ObjTree
+ * Given a table OID and the parse tree that created it, return JsonbValue
  * representing the creation command.
  *
  * Verbose syntax
  * CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D [OF
  * %{of_type}T | PARTITION OF %{parent_identity}D] %{table_elements}s
  * %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s
- * %{on_commit}s %{tablespace}s
+ * %{tablespace}s
  */
-static ObjTree *
-deparse_CreateStmt(Oid objectId, Node *parsetree)
+static Jsonb *
+deparse_CreateStmt(Oid objectId, Node *parsetree, char *owner)
 {
 	CreateStmt *node = (CreateStmt *) parsetree;
 	Relation	relation = relation_open(objectId, AccessShareLock);
+	Oid			nspid = relation->rd_rel->relnamespace;
+	char	   *relname = RelationGetRelationName(relation);
 	List	   *dpcontext;
-	ObjTree    *ret;
-	ObjTree    *tmp_obj;
-	List	   *list = NIL;
-	ListCell   *cell;
+	StringInfoData fmtStr;
+	JsonbParseState *state = NULL;
+	bool		telems = false;
+	JsonbValue *value;
 
-	ret = new_objtree_VA("CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D", 3,
-						 "persistence", ObjTypeString,
-						 get_persistence_str(relation->rd_rel->relpersistence),
-						 "if_not_exists", ObjTypeString,
-						 node->if_not_exists ? "IF NOT EXISTS" : "",
-						 "identity", ObjTypeObject,
-						 new_objtree_for_qualname(relation->rd_rel->relnamespace,
-												  RelationGetRelationName(relation)));
+	initStringInfo(&fmtStr);
 
 	dpcontext = deparse_context_for(RelationGetRelationName(relation),
 									objectId);
 
+	appendStringInfoString(&fmtStr, "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D");
+
+	/* mark the start of ROOT object */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+	/* create owner jsonb element */
+	role_to_jsonb_element(state, owner);
+
+	/* PERSISTENCE and IF NOT EXISTS */
+	new_jsonb_VA(state, NULL, true, 2,
+				 "persistence", jbvString, get_persistence_str(relation->rd_rel->relpersistence),
+				 "if_not_exists", jbvString, node->if_not_exists ? "IF NOT EXISTS" : "");
+
+	/* IDENTITY creation */
+	insert_identity_object(state, nspid, relname);
+
 	/*
+	 * TABLE-ELEMENTS array creation
+	 *
 	 * Typed tables and partitions use a slightly different format string: we
 	 * must not put table_elements with parents directly in the fmt string,
 	 * because if there are no options the parentheses must not be emitted;
@@ -1842,8 +1638,6 @@ deparse_CreateStmt(Oid objectId, Node *parsetree)
 	 */
 	if (node->ofTypename || node->partbound)
 	{
-		List	   *tableelts = NIL;
-
 		/*
 		 * We can't put table elements directly in the fmt string as an array
 		 * surrounded by parentheses here, because an empty clause would cause
@@ -1852,41 +1646,67 @@ deparse_CreateStmt(Oid objectId, Node *parsetree)
 		 */
 		if (node->ofTypename)
 		{
-			tmp_obj = new_objtree_for_type(relation->rd_rel->reloftype, -1);
-			append_object_object(ret, "OF %{of_type}T", tmp_obj);
+			appendStringInfoString(&fmtStr, " OF %{of_type}T");
+
+			/* Push the key first */
+			insert_jsonb_key(state, "of_type");
+
+			/* Push the value */
+			new_jsonb_for_type(state, relation->rd_rel->reloftype, -1);
 		}
 		else
 		{
 			List	   *parents;
-			ObjElem    *elem;
+			Oid			objid;
 
-			parents = deparse_InhRelations(objectId);
-			elem = (ObjElem *) linitial(parents);
+			appendStringInfoString(&fmtStr, " PARTITION OF %{parent_identity}D");
 
-			Assert(list_length(parents) == 1);
+			parents = deparse_InhRels_ToJsonb(objectId);
+			objid = linitial_oid(parents);
 
-			append_format_string(ret, "PARTITION OF");
+			Assert(list_length(parents) == 1);
 
-			append_object_object(ret, "%{parent_identity}D",
-								 elem->value.object);
+			new_jsonb_for_qualname_id(state, RelationRelationId,
+									  objid, "parent_identity", false);
 		}
 
-		tableelts = deparse_TableElements(relation, node->tableElts, dpcontext,
-										  true, /* typed table */
-										  false);	/* not composite */
-		tableelts = obtainConstraints(tableelts, objectId);
+		telems = table_elem_present_col(relation, node->tableElts, true);
+		if (!telems)
+			telems = table_elem_present_const(objectId);
 
-		tmp_obj = new_objtree("");
-		if (tableelts)
-			append_array_object(tmp_obj, "(%{elements:, }s)", tableelts);
-		else
-			append_not_present(tmp_obj, "(%{elements:, }s)");
+		appendStringInfoString(&fmtStr, " %{table_elements}s");
+
+		if (telems)
+		{
+			insert_jsonb_key(state, "table_elements");
+			pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+			fmt_to_jsonb_element(state, "(%{elements:, }s)");
+
+			insert_jsonb_key(state, "elements");
+			pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
+			deparse_TableElems_ToJsonb(state, relation, node->tableElts, dpcontext,
+									   true,	/* typed table */
+									   false);	/* not composite */
+
+			deparse_Constraints_ToJsonb(state, objectId);
+
+			/* end of elements array */
+			pushJsonbValue(&state, WJB_END_ARRAY, NULL);
 
-		append_object_object(ret, "%{table_elements}s", tmp_obj);
+			/* end of table_elements object */
+			pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+		}
+		else
+		{
+			insert_jsonb_key(state, "table_elements");
+			insert_not_present_obj(state, "(%{elements:, }s)");
+		}
 	}
 	else
 	{
-		List	   *tableelts = NIL;
+		List	   *inhrelations;
 
 		/*
 		 * There is no need to process LIKE clauses separately; they have
@@ -1899,15 +1719,34 @@ deparse_CreateStmt(Oid objectId, Node *parsetree)
 		 * get constraints we rely on pg_constraint, because the parse node
 		 * might be missing some things such as the name of the constraints.
 		 */
-		tableelts = deparse_TableElements(relation, node->tableElts, dpcontext,
-										  false,	/* not typed table */
-										  false);	/* not composite */
-		tableelts = obtainConstraints(tableelts, objectId);
+		telems = table_elem_present_col(relation, node->tableElts, false);
+		if (!telems)
+			telems = table_elem_present_const(objectId);
+
+		if (telems)
+		{
+			appendStringInfoString(&fmtStr, " (%{table_elements:, }s)");
+			insert_jsonb_key(state, "table_elements");
+
+			/*
+			 * It will be of array type for multi-columns table, so lets begin
+			 * an arrayobject. deparse_TableElems_ToJsonb() will add elements
+			 * to it.
+			 */
+			pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
+			deparse_TableElems_ToJsonb(state, relation, node->tableElts, dpcontext,
+									   false,	/* not typed table */
+									   false);	/* not composite */
+			deparse_Constraints_ToJsonb(state, objectId);
 
-		if (tableelts)
-			append_array_object(ret, "(%{table_elements:, }s)", tableelts);
+			pushJsonbValue(&state, WJB_END_ARRAY, NULL);
+		}
 		else
-			append_format_string(ret, "()");
+			appendStringInfoString(&fmtStr, " ()");
+
+		appendStringInfoString(&fmtStr, " %{inherits}s");
+		insert_jsonb_key(state, "inherits");
 
 		/*
 		 * Add inheritance specification.  We cannot simply scan the list of
@@ -1916,82 +1755,88 @@ deparse_CreateStmt(Oid objectId, Node *parsetree)
 		 * re-resolve them from the information in the parse node, it seems
 		 * more accurate and convenient to grab it from pg_inherits.
 		 */
-		tmp_obj = new_objtree("INHERITS");
 		if (node->inhRelations != NIL)
-			append_array_object(tmp_obj, "(%{parents:, }D)",
-								deparse_InhRelations(objectId));
-		else
-			append_not_present(tmp_obj, "(%{parents:, }D)");
+		{
+			pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-		append_object_object(ret, "%{inherits}s", tmp_obj);
+			fmt_to_jsonb_element(state, "INHERITS (%{parents:, }D)");
+			inhrelations = deparse_InhRels_ToJsonb(objectId);
+
+			new_jsonbArray_for_qualname_id(state, "parents", inhrelations);
+			pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+		}
+		else
+			insert_not_present_obj(state, verbose ? "INHERITS (%{parents:, }D)" : "INHERITS");
 	}
 
+
 	/* FOR VALUES clause */
 	if (node->partbound)
 	{
+		appendStringInfoString(&fmtStr, " %{partition_bound}s");
+
 		/*
 		 * Get pg_class.relpartbound. We cannot use partbound in the parsetree
 		 * directly as it's the original partbound expression which haven't
 		 * been transformed.
 		 */
-		append_string_object(ret, "%{partition_bound}s", "partition_bound",
-							 RelationGetPartitionBound(objectId));
+		new_jsonb_VA(state, NULL, true, 1,
+					 "partition_bound", jbvString, RelationGetPartitionBound(objectId));
 	}
 
 	/* PARTITION BY clause */
-	tmp_obj = new_objtree("PARTITION BY");
+	appendStringInfoString(&fmtStr, " %{partition_by}s");
+	insert_jsonb_key(state, "partition_by");
+
 	if (relation->rd_rel->relkind == RELKIND_PARTITIONED_TABLE)
-		append_string_object(tmp_obj, "%{definition}s", "definition",
-							 pg_get_partkeydef_string(objectId));
+		new_jsonb_VA(state, "PARTITION BY %{definition}s", false, 1,
+					 "definition", jbvString, pg_get_partkeydef_string(objectId));
 	else
-		append_not_present(tmp_obj, "%{definition}s");
+		insert_not_present_obj(state, verbose ? "PARTITION BY %{definition}s" : "PARTITION BY");
 
-	append_object_object(ret, "%{partition_by}s", tmp_obj);
 
 	/* USING clause */
-	tmp_obj = new_objtree("USING");
+	appendStringInfoString(&fmtStr, " %{access_method}s");
+	insert_jsonb_key(state, "access_method");
+
 	if (node->accessMethod)
-		append_string_object(tmp_obj, "%{access_method}I", "access_method",
-							 node->accessMethod);
+		new_jsonb_VA(state, "USING %{access_method}I", false, 1,
+					 "access_method", jbvString, node->accessMethod);
 	else
-		append_not_present(tmp_obj, "%{access_method}I");
-
-	append_object_object(ret, "%{access_method}s", tmp_obj);
+		insert_not_present_obj(state, verbose ? "USING %{access_method}I" : "USING");
 
 	/* WITH clause */
-	tmp_obj = new_objtree("WITH");
-
-	foreach(cell, node->options)
-	{
-		ObjTree    *tmp_obj2;
-		DefElem    *opt = (DefElem *) lfirst(cell);
+	appendStringInfoString(&fmtStr, " %{with_clause}s");
+	insert_jsonb_key(state, "with_clause");
 
-		tmp_obj2 = deparse_DefElem(opt, false);
-		list = lappend(list, new_object_object(tmp_obj2));
-	}
-
-	if (list)
-		append_array_object(tmp_obj, "(%{with:, }s)", list);
+	if (node->options)
+		deparse_withObj_ToJsonb(state, "WITH (%{with:, }s)", node);
 	else
-		append_not_present(tmp_obj, "(%{with:, }s)");
+		insert_not_present_obj(state, verbose ? "WITH (%{with:, }s)" : "WITH");
 
-	append_object_object(ret, "%{with_clause}s", tmp_obj);
+	/* TABLESPACE */
+	appendStringInfoString(&fmtStr, " %{tablespace}s");
+	insert_jsonb_key(state, "tablespace");
 
-	append_object_object(ret, "%{on_commit}s",
-						 deparse_OnCommitClause(node->oncommit));
-
-	tmp_obj = new_objtree("TABLESPACE");
+	/* Push the value now: object in this case */
 	if (node->tablespacename)
-		append_string_object(tmp_obj, "%{tablespace}I", "tablespace",
-							 node->tablespacename);
+		new_jsonb_VA(state, "TABLESPACE %{tablespace}I", false, 1,
+					 "tablespace", jbvString, node->tablespacename);
 	else
-		append_not_present(tmp_obj, "%{tablespace}I");
+		insert_not_present_obj(state, verbose ? "TABLESPACE %{tablespace}I" : "TABLESPACE");
 
-	append_object_object(ret, "%{tablespace}s", tmp_obj);
 
 	relation_close(relation, AccessShareLock);
 
-	return ret;
+	/* We have full fmt by now, so add jsonb element for that */
+	fmt_to_jsonb_element(state, fmtStr.data);
+
+	pfree(fmtStr.data);
+
+	/* Mark the end of ROOT object */
+	value = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+
+	return JsonbValueToJsonb(value);
 }
 
 /*
@@ -2000,122 +1845,229 @@ deparse_CreateStmt(Oid objectId, Node *parsetree)
  * deparse_CreateStmt do the actual work as we deparse the final CreateStmt for
  * CREATE TABLE AS command.
  */
-static ObjTree *
-deparse_CreateTableAsStmt(CollectedCommand *cmd)
+static Jsonb *
+deparse_CreateTableAsStmt(CollectedCommand *cmd, ddl_deparse_context * context)
 {
 	Oid			objectId;
 	Node	   *parsetree;
+	char	   *owner = context->include_owner ? cmd->role : NULL;
 
 	Assert(cmd->type == SCT_CreateTableAs);
 
 	parsetree = cmd->d.ctas.real_create;
 	objectId = cmd->d.ctas.address.objectId;
+	return deparse_CreateStmt(objectId, parsetree, owner);
+}
+
+/*
+ * Deparse a DropStmt (DROP TABLE).
+ *
+ * Given an object identity and the parse tree that created it, return
+ * jsonb string representing the drop command.
+ *
+ * Verbose syntax
+ * DROP %{objtype}s %{concurrently}s %{if_exists}s %{objidentity}s %{cascade}s
+ */
+char *
+deparse_drop_table(const char *objidentity, const char *objecttype,
+				   Node *parsetree)
+{
+	DropStmt   *node = (DropStmt *) parsetree;
+	StringInfoData fmtStr;
+	char	   *identity = (char *) objidentity;
+	JsonbValue *jsonbval;
+	Jsonb	   *jsonb;
+	StringInfoData str;
+	JsonbParseState *state = NULL;
+
+	initStringInfo(&str);
+	initStringInfo(&fmtStr);
 
-	return deparse_CreateStmt(objectId, parsetree);
+	/* Start constructing fmt string */
+	appendStringInfoString(&fmtStr, "DROP %{objtype}s %{concurrently}s %{if_exists}s %{objidentity}s");
+
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+
+	new_jsonb_VA(state, NULL, true, 4,
+				 "objtype", jbvString, objecttype,
+				 "concurrently", jbvString, node->concurrent ? "CONCURRENTLY" : "",
+				 "if_exists", jbvString, node->missing_ok ? "IF EXISTS" : "",
+				 "objidentity", jbvString, identity);
+
+	if (node->behavior == DROP_CASCADE)
+	{
+		appendStringInfoString(&fmtStr, " %{cascade}s");
+		insert_jsonb_key(state, "cascade");
+
+		pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+		fmt_to_jsonb_element(state, "CASCADE");
+		pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+	}
+
+	/* We have full fmt by now, so add jsonb element for that */
+	fmt_to_jsonb_element(state, fmtStr.data);
+	pfree(fmtStr.data);
+
+	jsonbval = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+
+	jsonb = JsonbValueToJsonb(jsonbval);
+	return JsonbToCString(&str, &jsonb->root, JSONB_ESTIMATED_LEN);
 }
 
 /*
- * Deparse all the collected subcommands and return an ObjTree representing the
- * alter command.
+ * Deparse all the collected subcommands and return jsonb string representing
+ * the alter command.
  *
  * Verbose syntax
  * ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s
  */
-static ObjTree *
-deparse_AlterRelation(CollectedCommand *cmd, ddl_deparse_context *context)
+static Jsonb *
+deparse_AlterTableStmt(CollectedCommand *cmd, ddl_deparse_context * context)
 {
-	ObjTree    *ret;
-	ObjTree    *tmp_obj;
-	ObjTree    *tmp_obj2;
 	List	   *dpcontext;
 	Relation	rel;
-	List	   *subcmds = NIL;
 	ListCell   *cell;
 	const char *reltype;
 	Node	   *expr = NULL;
 	Oid			relId = cmd->d.alterTable.objectId;
 	AlterTableStmt *stmt = NULL;
+	StringInfoData fmtStr;
+	JsonbParseState *state = NULL;
+	bool		subCmdArray = false;
+	JsonbValue *value;
 
 	Assert(cmd->type == SCT_AlterTable);
 	stmt = (AlterTableStmt *) cmd->parsetree;
-	Assert(IsA(stmt, AlterTableStmt));
 
-	/*
-	 * ALTER TABLE subcommands generated for TableLikeClause is processed in
-	 * the top level CREATE TABLE command; return empty here.
-	 */
-	if (stmt->table_like)
-		return NULL;
+	Assert(IsA(stmt, AlterTableStmt) || IsA(stmt, AlterTableMoveAllStmt));
 
-	rel = relation_open(relId, AccessShareLock);
+	initStringInfo(&fmtStr);
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-	switch (rel->rd_rel->relkind)
+	/* Start constructing fmt string */
+	if (IsA(stmt, AlterTableStmt))
 	{
-		case RELKIND_RELATION:
-		case RELKIND_PARTITIONED_TABLE:
-			reltype = "TABLE";
-			break;
-		case RELKIND_INDEX:
-		case RELKIND_PARTITIONED_INDEX:
-		case RELKIND_VIEW:
-		case RELKIND_COMPOSITE_TYPE:
-		case RELKIND_FOREIGN_TABLE:
-		case RELKIND_MATVIEW:
-			/* unsupported relkind */
-			table_close(rel, AccessShareLock);
+		stmt = (AlterTableStmt *) cmd->parsetree;
+
+		/*
+		 * ALTER TABLE subcommands generated for TableLikeClause is processed in
+		 * the top level CREATE TABLE command; return empty here.
+		 */
+		if (IsA(stmt, AlterTableStmt) && stmt->table_like)
 			return NULL;
 
-		default:
-			elog(ERROR, "unexpected relkind %d", rel->rd_rel->relkind);
+		rel = relation_open(relId, AccessShareLock);
+
+		switch (rel->rd_rel->relkind)
+		{
+			case RELKIND_RELATION:
+			case RELKIND_PARTITIONED_TABLE:
+				reltype = "TABLE";
+				break;
+			case RELKIND_INDEX:
+			case RELKIND_PARTITIONED_INDEX:
+			case RELKIND_VIEW:
+			case RELKIND_COMPOSITE_TYPE:
+			case RELKIND_FOREIGN_TABLE:
+			case RELKIND_MATVIEW:
+				/* unsupported relkind */
+				table_close(rel, AccessShareLock);
+				return NULL;
+
+			default:
+				elog(ERROR, "unexpected relkind %d", rel->rd_rel->relkind);
+		}
+
+
+		dpcontext = deparse_context_for(RelationGetRelationName(rel), relId);
+
+		appendStringInfoString(&fmtStr, "ALTER %{objtype}s %{only}s %{identity}D ");
+		new_jsonb_VA(state, NULL, true, 2,
+					 "objtype", jbvString, reltype,
+					 "only", jbvString, stmt->relation->inh ? "" : "ONLY");
+
+		insert_identity_object(state, rel->rd_rel->relnamespace,
+							   RelationGetRelationName(rel));
 	}
+	else
+	{
+		AlterTableMoveAllStmt *alterstmt = (AlterTableMoveAllStmt *) cmd->parsetree;
+
+		appendStringInfoString(&fmtStr, "ALTER %{objtype}s ALL IN TABLESPACE %{tablespace}s %{ownedby}s ");
+		new_jsonb_VA(state, NULL, true, 2,
+					 "objtype", jbvString, stringify_objtype(alterstmt->objtype),
+					 "tablespace", jbvString, alterstmt->orig_tablespacename);
+
+		insert_jsonb_key(state, "ownedby");
+		if (alterstmt->roles)
+		{
+			pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-	dpcontext = deparse_context_for(RelationGetRelationName(rel),
-									relId);
+			fmt_to_jsonb_element(state, "OWNED BY %{roles:, }s");
 
-	ret = new_objtree_VA("ALTER %{objtype}s %{only}s %{identity}D", 3,
-						 "objtype", ObjTypeString, reltype,
-						 "only", ObjTypeString,
-						 stmt->relation->inh ? "" : "ONLY",
-						 "identity", ObjTypeObject,
-						 new_objtree_for_qualname(rel->rd_rel->relnamespace,
-												  RelationGetRelationName(rel)));
+			insert_jsonb_key(state, "roles");
+			pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
+			foreach (cell, alterstmt->roles)
+				new_jsonb_VA(state, "%{role}s", false, 1,
+							 "role", jbvString,
+							 get_rolespec_name((RoleSpec *) lfirst(cell)));
+
+			pushJsonbValue(&state, WJB_END_ARRAY, NULL);
+			pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+		}
+		else
+			insert_not_present_obj(state, verbose ? "OWNED BY %{roles:, }s" : "OWNED BY");
+	}
 
 	foreach(cell, cmd->d.alterTable.subcmds)
 	{
 		CollectedATSubcmd *sub = (CollectedATSubcmd *) lfirst(cell);
 		AlterTableCmd *subcmd = (AlterTableCmd *) sub->parsetree;
-		ObjTree    *tree;
 
 		Assert(IsA(subcmd, AlterTableCmd));
 
-	   /*
-		* Skip deparse of the subcommand if the objectId doesn't match the
-		* target relation ID. It can happen for inherited tables when
-		* subcommands for inherited tables and the parent table are both
-		* collected in the ALTER TABLE command for the parent table.
-		*/
+		/*
+		 * Skip deparse of the subcommand if the objectId doesn't match the
+		 * target relation ID. It can happen for inherited tables when
+		 * subcommands for inherited tables and the parent table are both
+		 * collected in the ALTER TABLE command for the parent table.
+		 */
 		if (subcmd->subtype != AT_AttachPartition &&
 			sub->address.objectId != relId &&
 			has_superclass(sub->address.objectId))
 			continue;
 
+		if (!subCmdArray)
+		{
+			insert_jsonb_key(state, "subcmds");
+			pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+			subCmdArray = true;
+		}
+
 		switch (subcmd->subtype)
 		{
 			case AT_AddColumn:
 				/* XXX need to set the "recurse" bit somewhere? */
 				Assert(IsA(subcmd->def, ColumnDef));
-				tree = deparse_ColumnDef(rel, dpcontext, false,
-										 (ColumnDef *) subcmd->def, true, &expr);
 
 				mark_function_volatile(context, expr);
 
-				tmp_obj = new_objtree_VA("ADD %{objtype}s %{if_not_exists}s %{definition}s", 4,
-										"objtype", ObjTypeString, "COLUMN",
-										"type", ObjTypeString, "add column",
-										"if_not_exists", ObjTypeString,
-										subcmd->missing_ok ? "IF NOT EXISTS" : "",
-										"definition", ObjTypeObject, tree);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state,
+							 "ADD %{objtype}s %{if_not_exists}s %{definition}s", true, 3,
+							 "objtype", jbvString, "COLUMN",
+							 "type", jbvString, "add column",
+							 "if_not_exists", jbvString,
+							 subcmd->missing_ok ? "IF NOT EXISTS" : "");
+
+				/* Push definition key-value pair */
+				insert_jsonb_key(state, "definition");
+				deparse_ColumnDef_toJsonb(state, rel, dpcontext,
+										  false, (ColumnDef *) subcmd->def,
+										  true, NULL);
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 				break;
 
 			case AT_AddIndexConstraint:
@@ -2137,24 +2089,21 @@ deparse_AlterRelation(CollectedCommand *cmd, ddl_deparse_context *context)
 					 * ADD CONSTRAINT %{name}I %{constraint_type}s USING INDEX
 					 * %index_name}I %{deferrable}s %{init_deferred}s
 					 */
-					tmp_obj = new_objtree_VA("ADD CONSTRAINT %{name}I %{constraint_type}s USING INDEX %{index_name}I %{deferrable}s %{init_deferred}s", 6,
-											"type", ObjTypeString, "add constraint using index",
-											"name", ObjTypeString, get_constraint_name(constrOid),
-											"constraint_type", ObjTypeString,
-											istmt->primary ? "PRIMARY KEY" : "UNIQUE",
-											"index_name", ObjTypeString,
-											RelationGetRelationName(idx),
-											"deferrable", ObjTypeString,
-											istmt->deferrable ? "DEFERRABLE" : "NOT DEFERRABLE",
-											"init_deferred", ObjTypeString,
-											istmt->initdeferred ? "INITIALLY DEFERRED" : "INITIALLY IMMEDIATE");
-
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
-
+					new_jsonb_VA(state,
+								 "ADD CONSTRAINT %{name}I %{constraint_type}s USING INDEX %{index_name}I %{deferrable}s %{init_deferred}s", false, 6,
+								 "type", jbvString, "add constraint using index",
+								 "name", jbvString, get_constraint_name(constrOid),
+								 "constraint_type", jbvString,
+								 istmt->primary ? "PRIMARY KEY" : "UNIQUE",
+								 "index_name", jbvString,
+								 RelationGetRelationName(idx),
+								 "deferrable", jbvString,
+								 istmt->deferrable ? "DEFERRABLE" : "NOT DEFERRABLE",
+								 "init_deferred", jbvString,
+								 istmt->initdeferred ? "INITIALLY DEFERRED" : "INITIALLY IMMEDIATE");
 					relation_close(idx, AccessShareLock);
+					break;
 				}
-				break;
-
 			case AT_ReAddIndex:
 			case AT_ReAddConstraint:
 			case AT_ReAddDomainConstraint:
@@ -2199,124 +2148,130 @@ deparse_AlterRelation(CollectedCommand *cmd, ddl_deparse_context *context)
 
 			case AT_ColumnDefault:
 				if (subcmd->def == NULL)
-					tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I DROP DEFAULT", 2,
-											"type", ObjTypeString, "drop default",
-											"column", ObjTypeString, subcmd->name);
+					new_jsonb_VA(state,
+								 "ALTER COLUMN %{column}I DROP DEFAULT", false, 2,
+								 "type", jbvString, "drop default",
+								 "column", jbvString, subcmd->name);
 				else
 				{
 					List	   *dpcontext_rel;
 					HeapTuple	attrtup;
 					AttrNumber	attno;
 
-					tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I SET DEFAULT", 2,
-											"type", ObjTypeString, "set default",
-											"column", ObjTypeString, subcmd->name);
-
 					dpcontext_rel = deparse_context_for(RelationGetRelationName(rel),
 														RelationGetRelid(rel));
 					attrtup = SearchSysCacheAttName(RelationGetRelid(rel), subcmd->name);
 					attno = ((Form_pg_attribute) GETSTRUCT(attrtup))->attnum;
-					append_string_object(tmp_obj, "%{definition}s", "definition",
-										 RelationGetColumnDefault(rel, attno,
-																  dpcontext_rel,
-																  NULL));
+
+					new_jsonb_VA(state,
+								 "ALTER COLUMN %{column}I SET DEFAULT %{definition}s", false, 3,
+								 "type", jbvString, "set default",
+								 "column", jbvString, subcmd->name,
+								 "definition", jbvString,
+								 RelationGetColumnDefault(rel, attno,
+														  dpcontext_rel,
+														  NULL));
 					ReleaseSysCache(attrtup);
 				}
 
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
 				break;
 
 			case AT_DropNotNull:
-				tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I DROP NOT NULL", 2,
-										"type", ObjTypeString, "drop not null",
-										"column", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "ALTER COLUMN %{column}I DROP NOT NULL", false, 2,
+							 "type", jbvString, "drop not null",
+							 "column", jbvString, subcmd->name);
 				break;
 
 			case AT_ForceRowSecurity:
-				tmp_obj = new_objtree("FORCE ROW LEVEL SECURITY");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "FORCE ROW LEVEL SECURITY", false, 0);
 				break;
 
 			case AT_NoForceRowSecurity:
-				tmp_obj = new_objtree("NO FORCE ROW LEVEL SECURITY");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "NO FORCE ROW LEVEL SECURITY", false, 0);
 				break;
 
 			case AT_SetNotNull:
-				tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I SET NOT NULL", 2,
-										"type", ObjTypeString, "set not null",
-										"column", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "ALTER COLUMN %{column}I SET NOT NULL", false, 2,
+							 "type", jbvString, "set not null",
+							 "column", jbvString, subcmd->name);
 				break;
 
 			case AT_DropExpression:
-				tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I DROP EXPRESSION %{if_exists}s", 3,
-										"type", ObjTypeString, "drop expression",
-										"column", ObjTypeString, subcmd->name,
-										"if_exists", ObjTypeString,
-										subcmd->missing_ok ? "IF EXISTS" : "");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "ALTER COLUMN %{column}I DROP EXPRESSION %{if_exists}s", false, 3,
+							 "type", jbvString, "drop expression",
+							 "column", jbvString, subcmd->name,
+							 "if_exists", jbvString,
+							 subcmd->missing_ok ? "IF EXISTS" : "");
 				break;
 
 			case AT_SetStatistics:
 				{
 					Assert(IsA(subcmd->def, Integer));
 					if (subcmd->name)
-						tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I SET STATISTICS %{statistics}n", 3,
-												"type", ObjTypeString, "set statistics",
-												"column", ObjTypeString, subcmd->name,
-												"statistics", ObjTypeInteger,
-												intVal((Integer *) subcmd->def));
+						new_jsonb_VA(state,
+									 "ALTER COLUMN %{column}I SET STATISTICS %{statistics}n", false, 3,
+									 "type", jbvString, "set statistics",
+									 "column", jbvString, subcmd->name,
+									 "statistics", jbvNumeric,
+									 intVal((Integer *) subcmd->def));
 					else
-						tmp_obj = new_objtree_VA("ALTER COLUMN %{column}n SET STATISTICS %{statistics}n", 3,
-												"type", ObjTypeString, "set statistics",
-												"column", ObjTypeInteger, subcmd->num,
-												"statistics", ObjTypeInteger,
-												intVal((Integer *) subcmd->def));
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
+						new_jsonb_VA(state,
+									 "ALTER COLUMN %{column}n SET STATISTICS %{statistics}n", false, 3,
+									 "type", jbvString, "set statistics",
+									 "column", jbvNumeric, subcmd->num,
+									 "statistics", jbvNumeric,
+									 intVal((Integer *) subcmd->def));
 				}
 				break;
 
 			case AT_SetOptions:
 			case AT_ResetOptions:
-				subcmds = lappend(subcmds, new_object_object(
-															 deparse_ColumnSetOptions(subcmd)));
+				deparse_ColumnSetOptions_ToJsonb(state, subcmd);
 				break;
 
 			case AT_SetStorage:
 				Assert(IsA(subcmd->def, String));
-				tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I SET STORAGE %{storage}s", 3,
-										"type", ObjTypeString, "set storage",
-										"column", ObjTypeString, subcmd->name,
-										"storage", ObjTypeString,
-										strVal((String *) subcmd->def));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "ALTER COLUMN %{column}I SET STORAGE %{storage}s", false, 3,
+							 "type", jbvString, "set storage",
+							 "column", jbvString, subcmd->name,
+							 "storage", jbvString,
+							 strVal((String *) subcmd->def));
 				break;
 
 			case AT_SetCompression:
 				Assert(IsA(subcmd->def, String));
-				tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I SET COMPRESSION %{compression_method}s", 3,
-										"type", ObjTypeString, "set compression",
-										"column", ObjTypeString, subcmd->name,
-										"compression_method", ObjTypeString,
-										strVal((String *) subcmd->def));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "ALTER COLUMN %{column}I SET COMPRESSION %{compression_method}s", false, 3,
+							 "type", jbvString, "set compression",
+							 "column", jbvString, subcmd->name,
+							 "compression_method", jbvString,
+							 strVal((String *) subcmd->def));
 				break;
 
 			case AT_DropColumn:
-				tmp_obj = new_objtree_VA("DROP %{objtype}s %{if_exists}s %{column}I", 4,
-										"objtype", ObjTypeString, "COLUMN",
-										"type", ObjTypeString, "drop column",
-										"if_exists", ObjTypeString,
-										subcmd->missing_ok ? "IF EXISTS" : "",
-										"column", ObjTypeString, subcmd->name);
-				tmp_obj2 = new_objtree("CASCADE");
-				if (subcmd->behavior != DROP_CASCADE)
-					append_not_present(tmp_obj2, NULL);
-				append_object_object(tmp_obj, "%{cascade}s", tmp_obj2);
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state,
+							 "DROP %{objtype}s %{if_exists}s %{column}I %{cascade}s", true, 4,
+							 "objtype", jbvString, "COLUMN",
+							 "type", jbvString, "drop column",
+							 "if_exists", jbvString,
+							 subcmd->missing_ok ? "IF EXISTS" : "",
+							 "column", jbvString, subcmd->name);
+
+				if (subcmd->behavior == DROP_CASCADE)
+					new_jsonb_VA(state, NULL, true, 1, "cascade", jbvString, "CASCADE");
+				else
+				{
+					insert_jsonb_key(state, "cascade");
+					insert_not_present_obj(state, "CASCADE");
+				}
+
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
 				break;
 
 			case AT_AddIndex:
@@ -2339,17 +2294,16 @@ deparse_AlterRelation(CollectedCommand *cmd, ddl_deparse_context *context)
 					constrOid = get_relation_constraint_oid(
 															cmd->d.alterTable.objectId, idxname, false);
 
-					tmp_obj = new_objtree_VA("ADD CONSTRAINT %{name}I %{definition}s", 3,
-											"type", ObjTypeString, "add constraint",
-											"name", ObjTypeString, idxname,
-											"definition", ObjTypeString,
-											pg_get_constraintdef_string(constrOid));
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
+					new_jsonb_VA(state,
+								 "ADD CONSTRAINT %{name}I %{definition}s", false, 3,
+								 "type", jbvString, "add constraint",
+								 "name", jbvString, idxname,
+								 "definition", jbvString,
+								 pg_get_constraintdef_string(constrOid));
 
 					relation_close(idx, AccessShareLock);
 				}
 				break;
-
 			case AT_AddConstraint:
 				{
 					/* XXX need to set the "recurse" bit somewhere? */
@@ -2389,12 +2343,12 @@ deparse_AlterRelation(CollectedCommand *cmd, ddl_deparse_context *context)
 						}
 					}
 
-					tmp_obj = new_objtree_VA("ADD CONSTRAINT %{name}I %{definition}s", 3,
-											"type", ObjTypeString, "add constraint",
-											"name", ObjTypeString, get_constraint_name(constrOid),
-											"definition", ObjTypeString,
-											pg_get_constraintdef_string(constrOid));
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
+					new_jsonb_VA(state,
+								 "ADD CONSTRAINT %{name}I %{definition}s", false, 3,
+								 "type", jbvString, "add constraint",
+								 "name", jbvString, get_constraint_name(constrOid),
+								 "definition", jbvString,
+								 pg_get_constraintdef_string(constrOid));
 				}
 				break;
 
@@ -2408,34 +2362,34 @@ deparse_AlterRelation(CollectedCommand *cmd, ddl_deparse_context *context)
 						break;
 
 					Assert(IsA(c, Constraint));
-					tmp_obj = new_objtree_VA("ALTER CONSTRAINT %{name}I %{deferrable}s %{init_deferred}s", 4,
-											"type", ObjTypeString, "alter constraint",
-											"name", ObjTypeString, get_constraint_name(constrOid),
-											"deferrable", ObjTypeString,
-											c->deferrable ? "DEFERRABLE" : "NOT DEFERRABLE",
-											"init_deferred", ObjTypeString,
-											c->initdeferred ? "INITIALLY DEFERRED" : "INITIALLY IMMEDIATE");
-
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
+
+					new_jsonb_VA(state,
+								 "ALTER CONSTRAINT %{name}I %{deferrable}s %{init_deferred}s", false, 4,
+								 "type", jbvString, "alter constraint",
+								 "name", jbvString, get_constraint_name(constrOid),
+								 "deferrable", jbvString,
+								 c->deferrable ? "DEFERRABLE" : "NOT DEFERRABLE",
+								 "init_deferred", jbvString,
+								 c->initdeferred ? "INITIALLY DEFERRED" : "INITIALLY IMMEDIATE");
 				}
 				break;
 
 			case AT_ValidateConstraint:
-				tmp_obj = new_objtree_VA("VALIDATE CONSTRAINT %{constraint}I", 2,
-										"type", ObjTypeString, "validate constraint",
-										"constraint", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "VALIDATE CONSTRAINT %{constraint}I", false, 2,
+							 "type", jbvString, "validate constraint",
+							 "constraint", jbvString, subcmd->name);
 				break;
 
 			case AT_DropConstraint:
-				tmp_obj = new_objtree_VA("DROP CONSTRAINT %{if_exists}s %{constraint}I %{cascade}s", 4,
-										"type", ObjTypeString, "drop constraint",
-										"if_exists", ObjTypeString,
-										subcmd->missing_ok ? "IF EXISTS" : "",
-										"constraint", ObjTypeString, subcmd->name,
-										"cascade", ObjTypeString,
-										subcmd->behavior == DROP_CASCADE ? "CASCADE" : "");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "DROP CONSTRAINT %{if_exists}s %{constraint}I %{cascade}s", false, 4,
+							 "type", jbvString, "drop constraint",
+							 "if_exists", jbvString,
+							 subcmd->missing_ok ? "IF EXISTS" : "",
+							 "constraint", jbvString, subcmd->name,
+							 "cascade", jbvString,
+							 subcmd->behavior == DROP_CASCADE ? "CASCADE" : "");
 				break;
 
 			case AT_AlterColumnType:
@@ -2448,354 +2402,322 @@ deparse_AlterRelation(CollectedCommand *cmd, ddl_deparse_context *context)
 					def = (ColumnDef *) subcmd->def;
 					Assert(IsA(def, ColumnDef));
 
-					tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I SET DATA TYPE %{datatype}T", 3,
-											"type", ObjTypeString, "alter column type",
-											"column", ObjTypeString, subcmd->name,
-											"datatype", ObjTypeObject,
-											new_objtree_for_type(att->atttypid,
-																 att->atttypmod));
+					pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+					new_jsonb_VA(state,
+								 "ALTER COLUMN %{column}I SET DATA TYPE %{datatype}T %{collation}s %{using}s", true, 2,
+								 "type", jbvString, "alter column type",
+								 "column", jbvString, subcmd->name);
+
+					insert_jsonb_key(state, "datatype");
+
+					new_jsonb_for_type(state, att->atttypid, att->atttypmod);
 
 					/* Add a COLLATE clause, if needed */
-					tmp_obj2 = new_objtree("COLLATE");
+					insert_jsonb_key(state, "collation");
 					if (OidIsValid(att->attcollation))
-					{
-						ObjTree    *collname;
-
-						collname = new_objtree_for_qualname_id(CollationRelationId,
-															   att->attcollation);
-						append_object_object(tmp_obj2, "%{name}D", collname);
-					}
+						insert_collate_object(state, "COLLATE %{name}D",
+											  CollationRelationId, att->attcollation, "name");
 					else
-						append_not_present(tmp_obj2, "%{name}D");
-
-					append_object_object(tmp_obj, "%{collation}s", tmp_obj2);
+						insert_not_present_obj(state, verbose ? "COLLATE %{name}D" : "COLLATE");
 
 					/*
 					 * If there's a USING clause, transformAlterTableStmt ran
 					 * it through transformExpr and stored the resulting node
 					 * in cooked_default, which we can use here.
 					 */
-					tmp_obj2 = new_objtree("USING");
+					insert_jsonb_key(state, "using");
 					if (def->raw_default)
 					{
-						append_string_object(tmp_obj2, "%{expression}s",
-											 "expression", sub->usingexpr);
+						new_jsonb_VA(state, "USING %{expression}s", false, 1,
+									 "expression", jbvString, sub->usingexpr);
 						mark_function_volatile(context, def->cooked_default);
 					}
 					else
-						append_not_present(tmp_obj2, "%{expression}s");
-
-					append_object_object(tmp_obj, "%{using}s", tmp_obj2);
+						insert_not_present_obj(state,
+											   verbose ? "USING %{expression}s" : "USING");
 
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
+					pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 				}
 				break;
 
-#ifdef TODOLIST
-			case AT_AlterColumnGenericOptions:
-				tmp_obj = deparse_FdwOptions((List *) subcmd->def,
-											subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
-#endif
 			case AT_ChangeOwner:
-				tmp_obj = new_objtree_VA("OWNER TO %{owner}I", 2,
-										"type", ObjTypeString, "change owner",
-										"owner", ObjTypeString,
-										get_rolespec_name(subcmd->newowner));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "OWNER TO %{owner}I", false, 2,
+							 "type", jbvString, "change owner",
+							 "owner", jbvString,
+							 get_rolespec_name(subcmd->newowner));
 				break;
 
 			case AT_ClusterOn:
-				tmp_obj = new_objtree_VA("CLUSTER ON %{index}I", 2,
-										"type", ObjTypeString, "cluster on",
-										"index", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "CLUSTER ON %{index}I", false, 2,
+							 "type", jbvString, "cluster on",
+							 "index", jbvString, subcmd->name);
 				break;
 
+
 			case AT_DropCluster:
-				tmp_obj = new_objtree_VA("SET WITHOUT CLUSTER", 1,
-										"type", ObjTypeString, "set without cluster");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "SET WITHOUT CLUSTER", false, 1,
+							 "type", jbvString, "set without cluster");
 				break;
 
 			case AT_SetLogged:
-				tmp_obj = new_objtree_VA("SET LOGGED", 1,
-										"type", ObjTypeString, "set logged");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "SET LOGGED", false, 1,
+							 "type", jbvString, "set logged");
 				break;
 
 			case AT_SetUnLogged:
-				tmp_obj = new_objtree_VA("SET UNLOGGED", 1,
-										"type", ObjTypeString, "set unlogged");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "SET UNLOGGED", false, 1,
+							 "type", jbvString, "set unlogged");
 				break;
 
 			case AT_DropOids:
-				tmp_obj = new_objtree_VA("SET WITHOUT OIDS", 1,
-										"type", ObjTypeString, "set without oids");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "SET WITHOUT OIDS", false, 1,
+							 "type", jbvString, "set without oids");
 				break;
+
 			case AT_SetAccessMethod:
-				tmp_obj = new_objtree_VA("SET ACCESS METHOD %{access_method}I", 2,
-										"type", ObjTypeString, "set access method",
-										"access_method", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "SET ACCESS METHOD %{access_method}I", false, 2,
+							 "type", jbvString, "set access method",
+							 "access_method", jbvString, subcmd->name);
 				break;
+
 			case AT_SetTableSpace:
-				tmp_obj = new_objtree_VA("SET TABLESPACE %{tablespace}I", 2,
-										"type", ObjTypeString, "set tablespace",
-										"tablespace", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state,
+							 "SET TABLESPACE %{tablespace}I", false, 2,
+							 "type", jbvString, "set tablespace",
+							 "tablespace", jbvString, subcmd->name);
 				break;
 
 			case AT_SetRelOptions:
 			case AT_ResetRelOptions:
-				subcmds = lappend(subcmds, new_object_object(
-															 deparse_RelSetOptions(subcmd)));
+				deparse_RelSetOptions_toJsonb(state, subcmd);
 				break;
 
 			case AT_EnableTrig:
-				tmp_obj = new_objtree_VA("ENABLE TRIGGER %{trigger}I", 2,
-										"type", ObjTypeString, "enable trigger",
-										"trigger", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "ENABLE TRIGGER %{trigger}I", false, 2,
+							 "type", jbvString, "enable trigger",
+							 "trigger", jbvString, subcmd->name);
 				break;
 
 			case AT_EnableAlwaysTrig:
-				tmp_obj = new_objtree_VA("ENABLE ALWAYS TRIGGER %{trigger}I", 2,
-										"type", ObjTypeString, "enable always trigger",
-										"trigger", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "ENABLE ALWAYS TRIGGER %{trigger}I", false, 2,
+							 "type", jbvString, "enable always trigger",
+							 "trigger", jbvString, subcmd->name);
 				break;
 
 			case AT_EnableReplicaTrig:
-				tmp_obj = new_objtree_VA("ENABLE REPLICA TRIGGER %{trigger}I", 2,
-										"type", ObjTypeString, "enable replica trigger",
-										"trigger", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "ENABLE REPLICA TRIGGER %{trigger}I", false, 2,
+							 "type", jbvString, "enable replica trigger",
+							 "trigger", jbvString, subcmd->name);
 				break;
 
 			case AT_DisableTrig:
-				tmp_obj = new_objtree_VA("DISABLE TRIGGER %{trigger}I", 2,
-										"type", ObjTypeString, "disable trigger",
-										"trigger", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "DISABLE TRIGGER %{trigger}I", false, 2,
+							 "type", jbvString, "disable trigger",
+							 "trigger", jbvString, subcmd->name);
 				break;
 
 			case AT_EnableTrigAll:
-				tmp_obj = new_objtree_VA("ENABLE TRIGGER ALL", 1,
-										"type", ObjTypeString, "enable trigger all");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "ENABLE TRIGGER ALL", false, 1,
+							 "type", jbvString, "enable trigger all");
 				break;
 
 			case AT_DisableTrigAll:
-				tmp_obj = new_objtree_VA("DISABLE TRIGGER ALL", 1,
-										"type", ObjTypeString, "disable trigger all");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "DISABLE TRIGGER ALL", false, 1,
+							 "type", jbvString, "disable trigger all");
 				break;
 
 			case AT_EnableTrigUser:
-				tmp_obj = new_objtree_VA("ENABLE TRIGGER USER", 1,
-										"type", ObjTypeString, "enable trigger user");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "ENABLE TRIGGER USER", false, 1,
+							 "type", jbvString, "enable trigger user");
 				break;
 
 			case AT_DisableTrigUser:
-				tmp_obj = new_objtree_VA("DISABLE TRIGGER USER", 1,
-										"type", ObjTypeString, "disable trigger user");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "DISABLE TRIGGER USER", false, 1,
+							 "type", jbvString, "disable trigger user");
 				break;
 
 			case AT_EnableRule:
-				tmp_obj = new_objtree_VA("ENABLE RULE %{rule}I", 2,
-										"type", ObjTypeString, "enable rule",
-										"rule", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "ENABLE RULE %{rule}I", false, 2,
+							 "type", jbvString, "enable rule",
+							 "rule", jbvString, subcmd->name);
 				break;
 
 			case AT_EnableAlwaysRule:
-				tmp_obj = new_objtree_VA("ENABLE ALWAYS RULE %{rule}I", 2,
-										"type", ObjTypeString, "enable always rule",
-										"rule", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "ENABLE ALWAYS RULE %{rule}I", false, 2,
+							 "type", jbvString, "enable always rule",
+							 "rule", jbvString, subcmd->name);
 				break;
 
 			case AT_EnableReplicaRule:
-				tmp_obj = new_objtree_VA("ENABLE REPLICA RULE %{rule}I", 2,
-										"type", ObjTypeString, "enable replica rule",
-										"rule", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "ENABLE REPLICA RULE %{rule}I", false, 2,
+							 "type", jbvString, "enable replica rule",
+							 "rule", jbvString, subcmd->name);
 				break;
 
 			case AT_DisableRule:
-				tmp_obj = new_objtree_VA("DISABLE RULE %{rule}I", 2,
-										"type", ObjTypeString, "disable rule",
-										"rule", ObjTypeString, subcmd->name);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "DISABLE RULE %{rule}I", false, 2,
+							 "type", jbvString, "disable rule",
+							 "rule", jbvString, subcmd->name);
 				break;
 
 			case AT_AddInherit:
-				tmp_obj = new_objtree_VA("INHERIT %{parent}D", 2,
-										"type", ObjTypeString, "inherit",
-										"parent", ObjTypeObject,
-										new_objtree_for_qualname_id(RelationRelationId,
-																	sub->address.objectId));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "INHERIT %{parent}D", true, 1,
+							 "type", jbvString, "inherit");
+				new_jsonb_for_qualname_id(state, RelationRelationId, sub->address.objectId, "parent", false);
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 				break;
 
 			case AT_DropInherit:
-				tmp_obj = new_objtree_VA("NO INHERIT %{parent}D", 2,
-										"type", ObjTypeString, "drop inherit",
-										"parent", ObjTypeObject,
-										new_objtree_for_qualname_id(RelationRelationId,
-																	sub->address.objectId));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "NO INHERIT %{parent}D", true, 1,
+							 "type", jbvString, "drop inherit");
+				new_jsonb_for_qualname_id(state, RelationRelationId, sub->address.objectId, "parent", false);
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 				break;
 
 			case AT_AddOf:
-				tmp_obj = new_objtree_VA("OF %{type_of}T", 2,
-										"type", ObjTypeString, "add of",
-										"type_of", ObjTypeObject,
-										new_objtree_for_type(sub->address.objectId, -1));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "OF %{type_of}T", true, 1,
+							 "type", jbvString, "add of");
+				insert_jsonb_key(state, "type_of");
+				new_jsonb_for_type(state, sub->address.objectId, -1);
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 				break;
 
 			case AT_DropOf:
-				tmp_obj = new_objtree_VA("NOT OF", 1,
-										"type", ObjTypeString, "not of");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "NOT OF", false, 1,
+							 "type", jbvString, "not of");
 				break;
 
 			case AT_ReplicaIdentity:
-				tmp_obj = new_objtree_VA("REPLICA IDENTITY", 1,
-										"type", ObjTypeString, "replica identity");
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "REPLICA IDENTITY %{ident}s", true, 1,
+							 "type", jbvString, "replica identity");
 				switch (((ReplicaIdentityStmt *) subcmd->def)->identity_type)
 				{
 					case REPLICA_IDENTITY_DEFAULT:
-						append_string_object(tmp_obj, "%{ident}s", "ident",
-											 "DEFAULT");
+						new_jsonb_VA(state, NULL, true, 1, "ident", jbvString, "DEFAULT");
 						break;
 					case REPLICA_IDENTITY_FULL:
-						append_string_object(tmp_obj, "%{ident}s", "ident",
-											 "FULL");
+						new_jsonb_VA(state, NULL, true, 1, "ident", jbvString, "FULL");
 						break;
 					case REPLICA_IDENTITY_NOTHING:
-						append_string_object(tmp_obj, "%{ident}s", "ident",
-											 "NOTHING");
+						new_jsonb_VA(state, NULL, true, 1, "ident", jbvString, "NOTHING");
 						break;
 					case REPLICA_IDENTITY_INDEX:
-						tmp_obj2 = new_objtree_VA("USING INDEX %{index}I", 1,
-												 "index", ObjTypeString,
-												 ((ReplicaIdentityStmt *) subcmd->def)->name);
-						append_object_object(tmp_obj, "%{ident}s", tmp_obj2);
+						insert_jsonb_key(state, "ident");
+						new_jsonb_VA(state, "USING INDEX %{index}I", false, 1,
+									 "index", jbvString,
+									 ((ReplicaIdentityStmt *) subcmd->def)->name);
 						break;
 				}
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 				break;
 
 			case AT_EnableRowSecurity:
-				tmp_obj = new_objtree_VA("ENABLE ROW LEVEL SECURITY", 1,
-										"type", ObjTypeString, "enable row security");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "ENABLE ROW LEVEL SECURITY", false, 1,
+							 "type", jbvString, "enable row security");
 				break;
 
 			case AT_DisableRowSecurity:
-				tmp_obj = new_objtree_VA("DISABLE ROW LEVEL SECURITY", 1,
-										"type", ObjTypeString, "disable row security");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
-#ifdef TODOLIST
-			case AT_GenericOptions:
-				tmp_obj = deparse_FdwOptions((List *) subcmd->def, NULL);
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				new_jsonb_VA(state, "DISABLE ROW LEVEL SECURITY", false, 1,
+							 "type", jbvString, "disable row security");
 				break;
-#endif
+
 			case AT_AttachPartition:
-				tmp_obj = new_objtree_VA("ATTACH PARTITION %{partition_identity}D",
-										2, "type", ObjTypeString, "attach partition",
-										"partition_identity", ObjTypeObject,
-										new_objtree_for_qualname_id(RelationRelationId,
-																	sub->address.objectId));
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "ATTACH PARTITION %{partition_identity}D %{partition_bound}s", true,
+							 1, "type", jbvString, "attach partition");
+				new_jsonb_for_qualname_id(state, RelationRelationId, sub->address.objectId, "partition_identity", false);
 
-				tmp_obj2 = new_objtree("");
 				if (rel->rd_rel->relkind == RELKIND_PARTITIONED_TABLE)
-					append_string_object(tmp_obj, "%{partition_bound}s",
-										 "partition_bound",
-										 RelationGetPartitionBound(sub->address.objectId));
+					new_jsonb_VA(state, NULL, true, 1, "partition_bound", jbvString, RelationGetPartitionBound(sub->address.objectId));
 				else
-					append_not_present(tmp_obj2, "%{partition_bound}s");
+					new_jsonb_VA(state, NULL, true, 1, "partition_bound", jbvString, "");
 
-				append_object_object(tmp_obj, "%{partition_bound}s", tmp_obj2);
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
 				break;
 			case AT_DetachPartition:
-			{
-				PartitionCmd *cmd;
-
-				Assert(IsA(subcmd->def, PartitionCmd));
-				cmd = (PartitionCmd *) subcmd->def;
-
-				tmp_obj = new_objtree_VA("DETACH PARTITION %{partition_identity}D %{concurrent}s", 3,
-										"type", ObjTypeString,
-										"detach partition",
-										"partition_identity", ObjTypeObject,
-										new_objtree_for_qualname_id(RelationRelationId,
-																	sub->address.objectId),
-										"concurrent", ObjTypeString,
-										cmd->concurrent ? "CONCURRENTLY" : "");
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
-			}
+				{
+					PartitionCmd *cmd;
+
+					Assert(IsA(subcmd->def, PartitionCmd));
+					cmd = (PartitionCmd *) subcmd->def;
+
+					pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+					new_jsonb_VA(state, "DETACH PARTITION %{partition_identity}D %{concurrent}s", true, 2,
+								 "type", jbvString, "detach partition",
+								 "concurrent", jbvString,
+								 cmd->concurrent ? "CONCURRENTLY" : "");
+					new_jsonb_for_qualname_id(state, RelationRelationId, sub->address.objectId, "partition_identity", false);
+					pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+					break;
+				}
 			case AT_DetachPartitionFinalize:
-				tmp_obj = new_objtree_VA("DETACH PARTITION %{partition_identity}D FINALIZE", 2,
-										"type", ObjTypeString, "detach partition finalize",
-										"partition_identity", ObjTypeObject,
-										new_objtree_for_qualname_id(RelationRelationId,
-																	sub->address.objectId));
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "DETACH PARTITION %{partition_identity}D FINALIZE", true, 1,
+							 "type", jbvString, "detach partition finalize");
+
+				new_jsonb_for_qualname_id(state, RelationRelationId, sub->address.objectId, "partition_identity", false);
+				pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 				break;
 			case AT_AddIdentity:
 				{
 					AttrNumber	attnum;
 					Oid			seq_relid;
-					ObjTree    *seqdef;
 					ColumnDef  *coldef = (ColumnDef *) subcmd->def;
 
-					tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I", 2,
-											"type", ObjTypeString, "add identity",
-											"column", ObjTypeString, subcmd->name);
+					pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+					new_jsonb_VA(state, "ALTER COLUMN %{column}I %{definition}s", true, 2,
+								 "type", jbvString, "add identity",
+								 "column", jbvString, subcmd->name);
 
 					attnum = get_attnum(RelationGetRelid(rel), subcmd->name);
 					seq_relid = getIdentitySequence(RelationGetRelid(rel), attnum, true);
 
-					tmp_obj2 = new_objtree("ADD");
+					insert_jsonb_key(state, "definition");
 					if (OidIsValid(seq_relid))
 					{
-						seqdef = deparse_ColumnIdentity(seq_relid, coldef->identity, false);
-						append_object_object(tmp_obj2, "%{identity_column}s", seqdef);
+						/* insert definition's value now */
+						pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+						fmt_to_jsonb_element(state, "ADD %{identity_column}s");
+
+						/* insert identity_column as key */
+						insert_jsonb_key(state, "identity_column");
+
+						/* insert identity_column's value */
+						deparse_ColumnIdentity_toJsonb(state, seq_relid, coldef->identity, false);
+
+						/* mark definition's value end */
+						pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 					}
 					else
-						append_not_present(tmp_obj2, "%{identity_column}s");
-
-					append_object_object(tmp_obj, "%{definition}s", tmp_obj2);
+						insert_not_present_obj(state, verbose ? "ADD %{identity_column}s" : "ADD");
 
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
+					pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 				}
 				break;
 			case AT_SetIdentity:
 				{
 					DefElem    *defel;
 					char		identity = 0;
-					ObjTree    *seqdef;
 					AttrNumber	attnum;
 					Oid			seq_relid;
 
-
-					tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I", 2,
-											"type", ObjTypeString, "set identity",
-											"column", ObjTypeString, subcmd->name);
+					pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+					new_jsonb_VA(state, "ALTER COLUMN %{column}I %{definition}s", true, 2,
+								 "type", jbvString, "set identity",
+								 "column", jbvString, subcmd->name);
 
 					if (subcmd->def)
 					{
@@ -2810,31 +2732,26 @@ deparse_AlterRelation(CollectedCommand *cmd, ddl_deparse_context *context)
 					attnum = get_attnum(RelationGetRelid(rel), subcmd->name);
 					seq_relid = getIdentitySequence(RelationGetRelid(rel), attnum, true);
 
-					tmp_obj2 = new_objtree("");
+					insert_jsonb_key(state, "definition");
 					if (OidIsValid(seq_relid))
 					{
-						seqdef = deparse_ColumnIdentity(seq_relid, identity, true);
-						append_object_object(tmp_obj2, "%{definition}s", seqdef);
+						deparse_ColumnIdentity_toJsonb(state, seq_relid, identity, true);
 					}
 					else
-						append_not_present(tmp_obj2, "%{definition}s");
+						insert_not_present_obj(state, verbose ? "%{definition}s" : "");
 
-					append_object_object(tmp_obj, "%{definition}s", tmp_obj2);
+					pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 
-					subcmds = lappend(subcmds, new_object_object(tmp_obj));
 					break;
 				}
 			case AT_DropIdentity:
-				tmp_obj = new_objtree_VA("ALTER COLUMN %{column}I DROP IDENTITY", 2,
-										"type", ObjTypeString, "drop identity",
-										"column", ObjTypeString, subcmd->name);
-
-				append_string_object(tmp_obj, "%{if_exists}s",
-									 "if_exists",
-									 subcmd->missing_ok ? "IF EXISTS" : "");
-
-				subcmds = lappend(subcmds, new_object_object(tmp_obj));
-				break;
+				{
+					new_jsonb_VA(state, "ALTER COLUMN %{column}I DROP IDENTITY %{if_exists}s", false, 3,
+								 "type", jbvString, "drop identity",
+								 "column", jbvString, subcmd->name,
+								 "if_exists", jbvString, subcmd->missing_ok ? "IF EXISTS" : "");
+					break;
+				}
 			default:
 				elog(WARNING, "unsupported alter table subtype %d",
 					 subcmd->subtype);
@@ -2842,126 +2759,115 @@ deparse_AlterRelation(CollectedCommand *cmd, ddl_deparse_context *context)
 		}
 	}
 
-	table_close(rel, AccessShareLock);
+	if (IsA(stmt, AlterTableStmt))
+		table_close(rel, AccessShareLock);
 
-	if (list_length(subcmds) == 0)
+	/* sub commands not found, return NULL */
+	if (!subCmdArray)
 		return NULL;
 
-	append_array_object(ret, "%{subcmds:, }s", subcmds);
-
-	return ret;
-}
-
-/*
- * Handle deparsing of DROP commands.
- *
- * Verbose syntax
- * DROP %{objtype}s %{concurrently}s %{if_exists}s %{objidentity}s %{cascade}s
- */
-char *
-deparse_drop_command(const char *objidentity, const char *objecttype,
-					 Node *parsetree)
-{
-	DropStmt   *node = (DropStmt *) parsetree;
-	StringInfoData str;
-	char	   *command;
-	char	   *identity = (char *) objidentity;
-	ObjTree    *stmt;
-	ObjTree    *tmp_obj;
-	Jsonb	   *jsonb;
+	pushJsonbValue(&state, WJB_END_ARRAY, NULL);
+	appendStringInfoString(&fmtStr, "%{subcmds:, }s");
 
-	initStringInfo(&str);
+	if (IsA(stmt, AlterTableMoveAllStmt))
+	{
+		AlterTableMoveAllStmt *alterstmt = (AlterTableMoveAllStmt *) cmd->parsetree;
+		if (alterstmt->nowait)
+			appendStringInfoString(&fmtStr, " NO WAIT");
+	}
 
-	stmt = new_objtree_VA("DROP %{objtype}s %{concurrently}s %{if_exists}s %{objidentity}s", 4,
-						  "objtype", ObjTypeString, objecttype,
-						  "concurrently", ObjTypeString,
-						  node->concurrent ? "CONCURRENTLY" : "",
-						  "if_exists", ObjTypeString,
-						  node->missing_ok ? "IF EXISTS" : "",
-						  "objidentity", ObjTypeString, identity);
+	/* We have full fmt by now, so add jsonb element for that */
+	fmt_to_jsonb_element(state, fmtStr.data);
 
-	tmp_obj = new_objtree("CASCADE");
-	if (node->behavior != DROP_CASCADE)
-		append_not_present(tmp_obj, NULL);
-	append_object_object(stmt, "%{cascade}s", tmp_obj);
+	pfree(fmtStr.data);
 
-	jsonb = objtree_to_jsonb(stmt, NULL /* Owner/role can be skipped for drop command */);
-	command = JsonbToCString(&str, &jsonb->root, JSONB_ESTIMATED_LEN);
+	/* Mark the end of ROOT object */
+	value = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 
-	return command;
+	return JsonbValueToJsonb(value);
 }
 
 /*
- * Deparse an AlterObjectSchemaStmt (ALTER ... SET SCHEMA command)
+ * Deparse a CreateSeqStmt.
  *
- * Given the object address and the parse tree that created it, return an
- * ObjTree representing the alter command.
+ * Given a sequence OID and the parse tree that created it, return Jsonb
+ * representing the creation command.
+ *
+ * Note: We need to deparse the CREATE SEQUENCE command for the TABLE
+ * commands. For example, When creating a table, if we specify a column as a
+ * sequence type, then we will create a sequence for that column and set that
+ * sequence OWNED BY the table.
  *
  * Verbose syntax
- * ALTER %{objtype}s %{identity}s SET SCHEMA %{newschema}I
+ * CREATE %{persistence}s SEQUENCE %{identity}D %{definition: }s
  */
-static ObjTree *
-deparse_AlterObjectSchemaStmt(ObjectAddress address, Node *parsetree,
-							  ObjectAddress old_schema)
+static Jsonb *
+deparse_CreateSeqStmt(Oid objectId, Node *parsetree, char *owner)
 {
-	AlterObjectSchemaStmt *node = (AlterObjectSchemaStmt *) parsetree;
-	char	   *identity;
-	char	   *new_schema = node->newschema;
-	char	   *old_schname;
-	char	   *ident;
+	Relation	relation;
+	Form_pg_sequence seqform;
+	Sequence_values *seqvalues;
+	CreateSeqStmt *createSeqStmt = (CreateSeqStmt *) parsetree;
+	JsonbParseState *state = NULL;
+	JsonbValue *value;
 
 	/*
-	 * Since the command has already taken place from the point of view of
-	 * catalogs, getObjectIdentity returns the object name with the already
-	 * changed schema.  The output of our deparsing must return the original
-	 * schema name, however, so we chop the schema name off the identity
-	 * string and then prepend the quoted schema name.
-	 *
-	 * XXX This is pretty clunky. Can we do better?
+	 * Only support sequence for IDENTITY COLUMN output separately (via CREATE
+	 * TABLE or ALTER TABLE). Otherwise, return empty here.
 	 */
-	identity = getObjectIdentity(&address, false);
-	old_schname = get_namespace_name(old_schema.objectId);
-	if (!old_schname)
-		elog(ERROR, "cache lookup failed for schema with OID %u",
-			 old_schema.objectId);
+	if (createSeqStmt->for_identity)
+		return NULL;
 
-	ident = psprintf("%s%s", quote_identifier(old_schname),
-					 identity + strlen(quote_identifier(new_schema)));
+	relation = relation_open(objectId, AccessShareLock);
 
-	return new_objtree_VA("ALTER %{objtype}s %{identity}s SET SCHEMA %{newschema}I", 3,
-						  "objtype", ObjTypeString,
-						  stringify_objtype(node->objectType),
-						  "identity", ObjTypeString, ident,
-						  "newschema", ObjTypeString, new_schema);
-}
+	/* mark the start of ROOT object */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-/*
- * Deparse an AlterOwnerStmt (ALTER ... OWNER TO ...).
- *
- * Given the object address and the parse tree that created it, return an
- * ObjTree representing the alter command.
- *
- * Verbose syntax
- * ALTER %{objtype}s %{identity}s OWNER TO %{newowner}I
- */
-static ObjTree *
-deparse_AlterOwnerStmt(ObjectAddress address, Node *parsetree)
-{
-	AlterOwnerStmt *node = (AlterOwnerStmt *) parsetree;
+	/* create owner jsonb element */
+	role_to_jsonb_element(state, owner);
+
+	new_jsonb_VA(state, "CREATE %{persistence}s SEQUENCE %{if_not_exists}s %{identity}D %{definition: }s", true, 2,
+				 "persistence", jbvString,
+				 get_persistence_str(relation->rd_rel->relpersistence),
+				 "if_not_exists", jbvString,
+				 createSeqStmt->if_not_exists ? "IF NOT EXISTS" : "");
+
+	insert_identity_object(state, relation->rd_rel->relnamespace,
+						   RelationGetRelationName(relation));
+	relation_close(relation, AccessShareLock);
+
+	seqvalues = get_sequence_values(objectId);
+	seqform = seqvalues->seqform;
+
+	/* sequence definition array object creation, push the key first */
+	insert_jsonb_key(state, "definition");
+
+	pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
+	/* Definition elements */
+	deparse_Seq_Cache_toJsonb(state, seqform, false);
+	deparse_Seq_Cycle_toJsonb(state, seqform, false);
+	deparse_Seq_IncrementBy_toJsonb(state, seqform, false);
+	deparse_Seq_Minvalue_toJsonb(state, seqform, false);
+	deparse_Seq_Maxvalue_toJsonb(state, seqform, false);
+	deparse_Seq_Startwith_toJsonb(state, seqform, false);
+	deparse_Seq_Restart_toJsonb(state, seqvalues->last_value);
+	deparse_Seq_As_toJsonb(state, seqform);
+	/* We purposefully do not emit OWNED BY here */
+
+	/* mark the end of sequence definition array */
+	pushJsonbValue(&state, WJB_END_ARRAY, NULL);
 
-	return new_objtree_VA("ALTER %{objtype}s %{identity}s OWNER TO %{newowner}I", 3,
-						  "objtype", ObjTypeString,
-						  stringify_objtype(node->objectType),
-						  "identity", ObjTypeString,
-						  getObjectIdentity(&address, false),
-						  "newowner", ObjTypeString,
-						  get_rolespec_name(node->newowner));
+	/* mark the end of ROOT object */
+	value = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+
+	return JsonbValueToJsonb(value);
 }
 
 /*
  * Deparse an AlterSeqStmt.
  *
- * Given a sequence OID and a parse tree that modified it, return an ObjTree
+ * Given a sequence OID and a parse tree that modified it, return Jsonb
  * representing the alter command.
  *
  * Note: We need to deparse the ALTER SEQUENCE command for the TABLE commands.
@@ -2972,16 +2878,16 @@ deparse_AlterOwnerStmt(ObjectAddress address, Node *parsetree)
  * Verbose syntax
  * ALTER SEQUENCE %{identity}D %{definition: }s
  */
-static ObjTree *
-deparse_AlterSeqStmt(Oid objectId, Node *parsetree)
+static Jsonb *
+deparse_AlterSeqStmt(Oid objectId, Node *parsetree, char *owner)
 {
-	ObjTree    *ret;
 	Relation	relation;
-	List	   *elems = NIL;
 	ListCell   *cell;
 	Form_pg_sequence seqform;
 	Sequence_values *seqvalues;
 	AlterSeqStmt *alterSeqStmt = (AlterSeqStmt *) parsetree;
+	JsonbParseState *state = NULL;
+	JsonbValue *value;
 
 	/*
 	 * Sequence for IDENTITY COLUMN output separately (via CREATE TABLE or
@@ -2990,49 +2896,62 @@ deparse_AlterSeqStmt(Oid objectId, Node *parsetree)
 	if (alterSeqStmt->for_identity)
 		return NULL;
 
+	relation = relation_open(objectId, AccessShareLock);
+
+	/* mark the start of ROOT object */
+	pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+
+	/* create owner jsonb element */
+	role_to_jsonb_element(state, owner);
+
+	new_jsonb_VA(state, "ALTER SEQUENCE %{identity}D %{definition: }s", true, 0);
+
+	insert_identity_object(state, relation->rd_rel->relnamespace,
+						   RelationGetRelationName(relation));
+	relation_close(relation, AccessShareLock);
+
 	seqvalues = get_sequence_values(objectId);
 	seqform = seqvalues->seqform;
 
+	/* sequence definition array object creation, push the key first */
+	insert_jsonb_key(state, "definition");
+
+	/* mark the start of sequence definition array */
+	pushJsonbValue(&state, WJB_BEGIN_ARRAY, NULL);
+
 	foreach(cell, ((AlterSeqStmt *) parsetree)->options)
 	{
 		DefElem    *elem = (DefElem *) lfirst(cell);
-		ObjElem    *newelm;
 
 		if (strcmp(elem->defname, "cache") == 0)
-			newelm = deparse_Seq_Cache(seqform, false);
+			deparse_Seq_Cache_toJsonb(state, seqform, false);
 		else if (strcmp(elem->defname, "cycle") == 0)
-			newelm = deparse_Seq_Cycle(seqform, false);
+			deparse_Seq_Cycle_toJsonb(state, seqform, false);
 		else if (strcmp(elem->defname, "increment") == 0)
-			newelm = deparse_Seq_IncrementBy(seqform, false);
+			deparse_Seq_IncrementBy_toJsonb(state, seqform, false);
 		else if (strcmp(elem->defname, "minvalue") == 0)
-			newelm = deparse_Seq_Minvalue(seqform, false);
+			deparse_Seq_Minvalue_toJsonb(state, seqform, false);
 		else if (strcmp(elem->defname, "maxvalue") == 0)
-			newelm = deparse_Seq_Maxvalue(seqform, false);
+			deparse_Seq_Maxvalue_toJsonb(state, seqform, false);
 		else if (strcmp(elem->defname, "start") == 0)
-			newelm = deparse_Seq_Startwith(seqform, false);
+			deparse_Seq_Startwith_toJsonb(state, seqform, false);
 		else if (strcmp(elem->defname, "restart") == 0)
-			newelm = deparse_Seq_Restart(seqvalues->last_value);
+			deparse_Seq_Restart_toJsonb(state, seqvalues->last_value);
 		else if (strcmp(elem->defname, "owned_by") == 0)
-			newelm = deparse_Seq_OwnedBy(objectId, false);
+			deparse_Seq_OwnedBy_toJsonb(state, objectId, false);
 		else if (strcmp(elem->defname, "as") == 0)
-			newelm = deparse_Seq_As(seqform);
+			deparse_Seq_As_toJsonb(state, seqform);
 		else
 			elog(ERROR, "invalid sequence option %s", elem->defname);
-
-		elems = lappend(elems, newelm);
 	}
 
-	relation = relation_open(objectId, AccessShareLock);
-
-	ret = new_objtree_VA("ALTER SEQUENCE %{identity}D %{definition: }s", 2,
-						 "identity", ObjTypeObject,
-						 new_objtree_for_qualname(relation->rd_rel->relnamespace,
-												  RelationGetRelationName(relation)),
-						 "definition", ObjTypeArray, elems);
+	/* mark the end of sequence definition array */
+	pushJsonbValue(&state, WJB_END_ARRAY, NULL);
 
-	relation_close(relation, AccessShareLock);
+	/* mark the end of ROOT object */
+	value = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
 
-	return ret;
+	return JsonbValueToJsonb(value);
 }
 
 /*
@@ -3045,13 +2964,15 @@ deparse_AlterSeqStmt(Oid objectId, Node *parsetree)
  * OR
  * ALTER %{objtype}s %{if_exists}s %{only}s %{identity}D RENAME COLUMN %{colname}I TO %{newname}I %{cascade}s
  */
-static ObjTree *
+
+static Jsonb *
 deparse_RenameStmt(ObjectAddress address, Node *parsetree)
 {
 	RenameStmt *node = (RenameStmt *) parsetree;
-	ObjTree    *ret;
 	Relation	relation;
 	Oid			schemaId;
+	JsonbParseState *state = NULL;
+	JsonbValue *value;
 
 	/*
 	 * In an ALTER .. RENAME command, we don't have the original name of the
@@ -3066,16 +2987,18 @@ deparse_RenameStmt(ObjectAddress address, Node *parsetree)
 		case OBJECT_TABLE:
 			relation = relation_open(address.objectId, AccessShareLock);
 			schemaId = RelationGetNamespace(relation);
-			ret = new_objtree_VA("ALTER %{objtype}s %{if_exists}s %{identity}D RENAME TO %{newname}I", 4,
-								 "objtype", ObjTypeString,
-								 stringify_objtype(node->renameType),
-								 "if_exists", ObjTypeString,
-								 node->missing_ok ? "IF EXISTS" : "",
-								 "identity", ObjTypeObject,
-								 new_objtree_for_qualname(schemaId,
-														  node->relation->relname),
-								 "newname", ObjTypeString,
-								 node->newname);
+
+			pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+			new_jsonb_VA(state, "ALTER %{objtype}s %{if_exists}s %{identity}D RENAME TO %{newname}I", true, 3,
+						 "objtype", jbvString,
+						 stringify_objtype(node->renameType),
+						 "if_exists", jbvString,
+						 node->missing_ok ? "IF EXISTS" : "",
+						 "newname", jbvString, node->newname);
+
+			insert_identity_object(state, schemaId, node->relation->relname);
+			value = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+
 			relation_close(relation, AccessShareLock);
 			break;
 
@@ -3091,60 +3014,161 @@ deparse_RenameStmt(ObjectAddress address, Node *parsetree)
 						 address.objectId);
 				constform = (Form_pg_constraint) GETSTRUCT(constrtup);
 
-				ret = new_objtree_VA("ALTER TABLE %{only}s %{identity}D RENAME CONSTRAINT %{oldname}I TO %{newname}I", 4,
-									"only",  ObjTypeString,
-									node->relation->inh ? "" : "ONLY",
-									"identity", ObjTypeObject,
-									new_objtree_for_qualname_id(RelationRelationId,
-																constform->conrelid),
-									"oldname", ObjTypeString, node->subname,
-									"newname", ObjTypeString, node->newname);
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
+				new_jsonb_VA(state, "ALTER TABLE %{only}s %{identity}D RENAME CONSTRAINT %{oldname}I TO %{newname}I", true, 3,
+							 "only", jbvString,
+							 node->relation->inh ? "" : "ONLY",
+							 "oldname", jbvString, node->subname,
+							 "newname", jbvString, node->newname);
+
+				new_jsonb_for_qualname_id(state, RelationRelationId,
+										  constform->conrelid, "identity", false);
+				value = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+
 				ReleaseSysCache(constrtup);
 			}
 			break;
 
 		case OBJECT_COLUMN:
-			relation = relation_open(address.objectId, AccessShareLock);
-			schemaId = RelationGetNamespace(relation);
+			{
+				StringInfoData fmtStr;
 
-			ret = new_objtree_VA("ALTER %{objtype}s", 1,
-								 "objtype", ObjTypeString,
-								 stringify_objtype(node->relationType));
+				initStringInfo(&fmtStr);
 
-			/* Composite types do not support IF EXISTS */
-			if (node->renameType == OBJECT_COLUMN)
-				append_string_object(ret, "%{if_exists}s",
-									 "if_exists",
-									 node->missing_ok ? "IF EXISTS" : "");
-			if (!node->relation->inh)
-				append_string_object(ret, "%{only}s", "only", "ONLY");
+				relation = relation_open(address.objectId, AccessShareLock);
+				schemaId = RelationGetNamespace(relation);
 
-			append_object_object(ret, "%{identity}D",
-								 new_objtree_for_qualname(schemaId,
-								 node->relation->relname));
-			append_string_object(ret, "RENAME COLUMN %{colname}I",
-								 "colname", node->subname);
+				pushJsonbValue(&state, WJB_BEGIN_OBJECT, NULL);
 
-			append_string_object(ret, "TO %{newname}I", "newname",
-								 node->newname);
+				appendStringInfoString(&fmtStr, "ALTER %{objtype}s");
 
-			if (node->renameType == OBJECT_ATTRIBUTE)
-			{
-				ObjTree    *tmp_obj = new_objtree("CASCADE");
+				new_jsonb_VA(state, NULL, true, 1,
+							 "objtype", jbvString,
+							 stringify_objtype(node->relationType));
 
-				if (node->behavior != DROP_CASCADE)
-					append_not_present(tmp_obj, NULL);
-				append_object_object(ret, "%{cascade}s", tmp_obj);
-			}
+				/* Composite types do not support IF EXISTS */
+				if (node->renameType == OBJECT_COLUMN)
+				{
+					appendStringInfoString(&fmtStr, " %{if_exists}s");
+					new_jsonb_VA(state, NULL, true, 1,
+								 "if_exists", jbvString,
+								 node->missing_ok ? "IF EXISTS" : "");
+				}
 
-			relation_close(relation, AccessShareLock);
-			break;
+				if (!node->relation->inh)
+				{
+					appendStringInfoString(&fmtStr, " %{only}s");
+					new_jsonb_VA(state, NULL, true, 1, "only", jbvString, "ONLY");
+				}
+
+				appendStringInfoString(&fmtStr, " %{identity}D RENAME COLUMN %{colname}I TO %{newname}I");
+				insert_identity_object(state, schemaId, node->relation->relname);
+				new_jsonb_VA(state, NULL, true, 2,
+							 "colname", jbvString, node->subname,
+							 "newname", jbvString, node->newname);
+
+				if (node->renameType == OBJECT_ATTRIBUTE)
+				{
+					appendStringInfoString(&fmtStr, " %{cascade}s");
+
+					if (node->behavior == DROP_CASCADE)
+						new_jsonb_VA(state, NULL, true, 1, "cascade", jbvString, "CASCADE");
+					else
+					{
+						insert_jsonb_key(state, "cascade");
+						insert_not_present_obj(state, "CASCADE");
+					}
+				}
+
+				/* We have full fmt by now, so add jsonb element for that */
+				fmt_to_jsonb_element(state, fmtStr.data);
+
+				pfree(fmtStr.data);
+
+				value = pushJsonbValue(&state, WJB_END_OBJECT, NULL);
+
+				relation_close(relation, AccessShareLock);
+				break;
+			}
 
 		default:
 			elog(ERROR, "unsupported object type %d", node->renameType);
 	}
 
-	return ret;
+	return JsonbValueToJsonb(value);
+}
+
+/*
+ * Deparse an AlterOwnerStmt (ALTER ... OWNER TO ...).
+ *
+ * Given the object address and the parse tree that created it, return
+ * Jsonb representing the alter command.
+ *
+ * Verbose syntax
+ * ALTER %{objtype}s %{identity}s OWNER TO %{newowner}I
+ */
+static Jsonb *
+deparse_AlterOwnerStmt(ObjectAddress address, Node *parsetree)
+{
+	AlterOwnerStmt *node = (AlterOwnerStmt *) parsetree;
+	JsonbParseState *state = NULL;
+	JsonbValue *value;
+
+	value = new_jsonb_VA(state, "ALTER %{objtype}s %{identity}s OWNER TO %{newowner}I", false, 3,
+						 "objtype", jbvString,
+						 stringify_objtype(node->objectType),
+						 "identity", jbvString,
+						 getObjectIdentity(&address, false),
+						 "newowner", jbvString,
+						 get_rolespec_name(node->newowner));
+	return JsonbValueToJsonb(value);
+}
+
+/*
+ * Deparse an AlterObjectSchemaStmt (ALTER ... SET SCHEMA command)
+ *
+ * Given the object address and the parse tree that created it, return an
+ * Jsonb representing the alter command.
+ *
+ * Verbose syntax
+ * ALTER %{objtype}s %{identity}s SET SCHEMA %{newschema}I
+ */
+static Jsonb *
+deparse_AlterObjectSchemaStmt(ObjectAddress address, Node *parsetree,
+							  ObjectAddress old_schema)
+{
+	AlterObjectSchemaStmt *node = (AlterObjectSchemaStmt *) parsetree;
+	char	   *identity;
+	char	   *new_schema = node->newschema;
+	char	   *old_schname;
+	char	   *ident;
+	JsonbParseState *state = NULL;
+	JsonbValue *value;
+
+	/*
+	 * Since the command has already taken place from the point of view of
+	 * catalogs, getObjectIdentity returns the object name with the already
+	 * changed schema.  The output of our deparsing must return the original
+	 * schema name, however, so we chop the schema name off the identity
+	 * string and then prepend the quoted schema name.
+	 *
+	 * XXX This is pretty clunky. Can we do better?
+	 */
+	identity = getObjectIdentity(&address, false);
+	old_schname = get_namespace_name(old_schema.objectId);
+	if (!old_schname)
+		elog(ERROR, "cache lookup failed for schema with OID %u",
+			 old_schema.objectId);
+
+	ident = psprintf("%s%s", quote_identifier(old_schname),
+					 identity + strlen(quote_identifier(new_schema)));
+
+	value = new_jsonb_VA(state, "ALTER %{objtype}s %{identity}s SET SCHEMA %{newschema}I", false, 3,
+						 "objtype", jbvString,
+						 stringify_objtype(node->objectType),
+						 "identity", jbvString, ident,
+						 "newschema", jbvString, new_schema);
+	return JsonbValueToJsonb(value);
 }
 
 /*
@@ -3152,11 +3176,12 @@ deparse_RenameStmt(ObjectAddress address, Node *parsetree)
  *
  * This function should cover all cases handled in ProcessUtilitySlow.
  */
-static ObjTree *
-deparse_simple_command(CollectedCommand *cmd, bool *include_owner)
+static Jsonb *
+deparse_simple_command(CollectedCommand *cmd, ddl_deparse_context * context)
 {
 	Oid			objectId;
 	Node	   *parsetree;
+	char	   *owner = context->include_owner ? cmd->role : NULL;
 
 	Assert(cmd->type == SCT_Simple);
 
@@ -3170,26 +3195,25 @@ deparse_simple_command(CollectedCommand *cmd, bool *include_owner)
 	switch (nodeTag(parsetree))
 	{
 		case T_AlterObjectSchemaStmt:
-			*include_owner = false;
+			context->include_owner = false;
 			return deparse_AlterObjectSchemaStmt(cmd->d.simple.address,
 												 parsetree,
 												 cmd->d.simple.secondaryObject);
 
 		case T_AlterOwnerStmt:
-			*include_owner = false;
+			context->include_owner = false;
 			return deparse_AlterOwnerStmt(cmd->d.simple.address, parsetree);
 
 		case T_AlterSeqStmt:
-			return deparse_AlterSeqStmt(objectId, parsetree);
+			return deparse_AlterSeqStmt(objectId, parsetree, owner);
 
 		case T_CreateSeqStmt:
-			return deparse_CreateSeqStmt(objectId, parsetree);
+			return deparse_CreateSeqStmt(objectId, parsetree, owner);
 
 		case T_CreateStmt:
-			return deparse_CreateStmt(objectId, parsetree);
-
+			return deparse_CreateStmt(objectId, parsetree, owner);
 		case T_RenameStmt:
-			*include_owner = false;
+			context->include_owner = false;
 			return deparse_RenameStmt(cmd->d.simple.address, parsetree);
 
 		default:
@@ -3204,14 +3228,14 @@ deparse_simple_command(CollectedCommand *cmd, bool *include_owner)
  * Workhorse to deparse a CollectedCommand.
  */
 char *
-deparse_utility_command(CollectedCommand *cmd, ddl_deparse_context *context)
+deparse_utility_command(CollectedCommand *cmd, ddl_deparse_context * context)
 {
 	OverrideSearchPath *overridePath;
 	MemoryContext oldcxt;
 	MemoryContext tmpcxt;
-	ObjTree    *tree;
 	char	   *command = NULL;
 	StringInfoData str;
+	Jsonb	   *jsonb;
 
 	/*
 	 * Allocate everything done by the deparsing routines into a temp context,
@@ -3245,14 +3269,14 @@ deparse_utility_command(CollectedCommand *cmd, ddl_deparse_context *context)
 	switch (cmd->type)
 	{
 		case SCT_Simple:
-			tree = deparse_simple_command(cmd, &context->include_owner);
+			jsonb = deparse_simple_command(cmd, context);
 			break;
 		case SCT_AlterTable:
-			tree = deparse_AlterRelation(cmd, context);
+			jsonb = deparse_AlterTableStmt(cmd, context);
 			context->include_owner = false;
 			break;
 		case SCT_CreateTableAs:
-			tree = deparse_CreateTableAsStmt(cmd);
+			jsonb = deparse_CreateTableAsStmt(cmd, context);
 			break;
 		default:
 			elog(ERROR, "unexpected deparse node type %d", cmd->type);
@@ -3260,14 +3284,8 @@ deparse_utility_command(CollectedCommand *cmd, ddl_deparse_context *context)
 
 	PopOverrideSearchPath();
 
-	if (tree)
-	{
-		Jsonb	   *jsonb;
-
-		jsonb = context->include_owner ? objtree_to_jsonb(tree, cmd->role) :
-										 objtree_to_jsonb(tree, NULL);
+	if (jsonb)
 		command = JsonbToCString(&str, &jsonb->root, JSONB_ESTIMATED_LEN);
-	}
 
 	/*
 	 * Clean up.  Note that since we created the StringInfo in the caller's
@@ -3279,6 +3297,7 @@ deparse_utility_command(CollectedCommand *cmd, ddl_deparse_context *context)
 	return command;
 }
 
+
 /*
  * Given a CollectedCommand, return a JSON representation of it.
  *
diff --git a/src/backend/replication/logical/ddltrigger.c b/src/backend/replication/logical/ddltrigger.c
index 94161a0497..be1c6b40c9 100644
--- a/src/backend/replication/logical/ddltrigger.c
+++ b/src/backend/replication/logical/ddltrigger.c
@@ -282,12 +282,15 @@ publication_deparse_ddl_command_end(PG_FUNCTION_ARGS)
 		else
 			continue;
 
-		command = deparse_drop_command(obj->objidentity, obj->objecttype,
+		command = deparse_drop_table(obj->objidentity, obj->objecttype,
 									   trigdata->parsetree);
 
 		if (command)
+		{
 			LogLogicalDDLMessage("deparse", obj->address.objectId, cmdtype,
 								 command, strlen(command) + 1);
+			elog(LOG, "COMMAND = %s", command);
+		}
 	}
 
 	return PointerGetDatum(NULL);
diff --git a/src/include/tcop/ddldeparse.h b/src/include/tcop/ddldeparse.h
index 1cceb53662..19b1274859 100644
--- a/src/include/tcop/ddldeparse.h
+++ b/src/include/tcop/ddldeparse.h
@@ -32,7 +32,7 @@ typedef struct
 
 extern char *deparse_utility_command(CollectedCommand *cmd, ddl_deparse_context *context);
 extern char *deparse_ddl_json_to_string(char *jsonb, char** owner);
-extern char *deparse_drop_command(const char *objidentity, const char *objecttype,
-								  Node *parsetree);
+extern char *deparse_drop_table(const char *objidentity, const char *objecttype,
+										   Node *parsetree);
 
 #endif							/* DDL_DEPARSE_H */
diff --git a/src/test/modules/test_ddl_deparse_regress/expected/alter_table.out b/src/test/modules/test_ddl_deparse_regress/expected/alter_table.out
index 9b22999cd9..0f9db82273 100644
--- a/src/test/modules/test_ddl_deparse_regress/expected/alter_table.out
+++ b/src/test/modules/test_ddl_deparse_regress/expected/alter_table.out
@@ -7,18 +7,18 @@ CREATE TABLE orders(
     quantity int,
     purchase_date date
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "orders", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.orders (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "orders", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.orders (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 -- ALTER TABLE [ IF EXISTS ] [ ONLY ] name [ * ]
 --     action [, ... ]
 CREATE TABLE parent_table(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "parent_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.parent_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "parent_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.parent_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 CREATE TABLE test_only () INHERITS (parent_table);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D () %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_only", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "parent_table", "schemaname": "public"}]}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": ""}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_only () INHERITS (public.parent_table)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D () %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_only", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "parent_table", "schemaname": "public"}]}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": ""}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_only () INHERITS (public.parent_table)    
 ALTER TABLE test_only ADD col1 int;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD %{objtype}s %{if_not_exists}s %{definition}s", "type": "add column", "objtype": "COLUMN", "definition": {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, "if_not_exists": ""}], "identity": {"objname": "test_only", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_only ADD COLUMN  col1 pg_catalog.int4 STORAGE PLAIN      
@@ -32,8 +32,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.parent_table ADD CONSTRAINT pare
 CREATE TABLE test_add_column(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_add_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_add_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_add_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_add_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_add_column ADD col1 int;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD %{objtype}s %{if_not_exists}s %{definition}s", "type": "add column", "objtype": "COLUMN", "definition": {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, "if_not_exists": ""}], "identity": {"objname": "test_add_column", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_add_column ADD COLUMN  col1 pg_catalog.int4 STORAGE PLAIN      
@@ -59,14 +59,14 @@ CREATE TABLE test_drop_column(
     UNIQUE (id),
     UNIQUE (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_drop_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_column_id_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_column_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_drop_column_id_key UNIQUE (id), CONSTRAINT test_drop_column_name_key UNIQUE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_drop_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_column_id_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_column_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_drop_column_id_key UNIQUE (id), CONSTRAINT test_drop_column_name_key UNIQUE (name))     
 CREATE TABLE foreign_table(
     id int REFERENCES test_drop_column (id),
     name varchar REFERENCES test_drop_column (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "foreign_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.foreign_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "foreign_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.foreign_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "foreign_table_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id) REFERENCES public.test_drop_column(id)"}, {"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "foreign_table_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.test_drop_column(name)"}], "identity": {"objname": "foreign_table", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.foreign_table ADD CONSTRAINT foreign_table_id_fkey FOREIGN KEY (id) REFERENCES public.test_drop_column(id), ADD CONSTRAINT foreign_table_name_fkey FOREIGN KEY (name) REFERENCES public.test_drop_column(name)
 ALTER TABLE test_drop_column DROP price;
@@ -78,14 +78,16 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_drop_column DROP COLUMN  qu
 ALTER TABLE test_drop_column DROP IF EXISTS description RESTRICT;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "DROP %{objtype}s %{if_exists}s %{column}I %{cascade}s", "type": "drop column", "column": "description", "cascade": {"fmt": "CASCADE", "present": false}, "objtype": "COLUMN", "if_exists": "IF EXISTS"}], "identity": {"objname": "test_drop_column", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_drop_column DROP COLUMN IF EXISTS description 
--- TOFIX
--- ALTER TABLE test_drop_column DROP IF EXISTS name CASCADE;
+ALTER TABLE test_drop_column DROP IF EXISTS name CASCADE;
+NOTICE:  drop cascades to constraint foreign_table_name_fkey on table foreign_table
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "DROP %{objtype}s %{if_exists}s %{column}I %{cascade}s", "type": "drop column", "column": "name", "cascade": "CASCADE", "objtype": "COLUMN", "if_exists": "IF EXISTS"}], "identity": {"objname": "test_drop_column", "schemaname": "public"}}
+NOTICE:  re-formed command: ALTER TABLE  public.test_drop_column DROP COLUMN IF EXISTS name CASCADE
 -- ALTER [ COLUMN ] column_name [ SET DATA ] TYPE data_type [ COLLATE collation ] [ USING expression ]
 CREATE TABLE test_alter_type(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_alter_type", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_type (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_alter_type", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_type (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_alter_type ALTER price TYPE int;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET DATA TYPE %{datatype}T %{collation}s %{using}s", "type": "alter column type", "using": {"fmt": "USING %{expression}s", "present": false}, "column": "price", "datatype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "collation": {"fmt": "COLLATE %{name}D", "present": false}}], "identity": {"objname": "test_alter_type", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_alter_type ALTER COLUMN price SET DATA TYPE pg_catalog.int4  
@@ -105,8 +107,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_alter_type ALTER COLUMN nam
 CREATE TABLE test_alter_set_default(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_alter_set_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_set_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_alter_set_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_set_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_alter_set_default ALTER price SET DEFAULT 100;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET DEFAULT %{definition}s", "type": "set default", "column": "price", "definition": "100"}], "identity": {"objname": "test_alter_set_default", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_alter_set_default ALTER COLUMN price SET DEFAULT 100
@@ -119,8 +121,8 @@ CREATE TABLE test_drop_default(
     default_price float4 DEFAULT 10.0,
     default_name varchar DEFAULT 'foo'
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_drop_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "default_price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "10.0"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "default_name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , default_price pg_catalog.float4 STORAGE PLAIN    DEFAULT 10.0  , default_name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"  DEFAULT 'foo'::character varying  )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_drop_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "default_price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "10.0"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "default_name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , default_price pg_catalog.float4 STORAGE PLAIN    DEFAULT 10.0  , default_name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"  DEFAULT 'foo'::character varying  )     
 ALTER TABLE test_drop_default ALTER default_price DROP DEFAULT;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I DROP DEFAULT", "type": "drop default", "column": "default_price"}], "identity": {"objname": "test_drop_default", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_drop_default ALTER COLUMN default_price DROP DEFAULT
@@ -132,8 +134,8 @@ CREATE TABLE test_set_not_null(
     LIKE orders,
     size int NOT NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_not_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "size", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_not_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , size pg_catalog.int4 STORAGE PLAIN   NOT NULL   )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_not_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "size", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_not_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , size pg_catalog.int4 STORAGE PLAIN   NOT NULL   )     
 ALTER TABLE test_set_not_null ALTER COLUMN id SET NOT NULL;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET NOT NULL", "type": "set not null", "column": "id"}], "identity": {"objname": "test_set_not_null", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_not_null ALTER COLUMN id SET NOT NULL
@@ -145,8 +147,8 @@ CREATE TABLE test_drop_expression(
     LIKE orders,
     new_id int GENERATED ALWAYS AS ( 3 * ID ) STORED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_drop_expression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "new_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr": "(3 OPERATOR(pg_catalog.*) id)"}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_expression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , new_id pg_catalog.int4 STORAGE PLAIN      GENERATED ALWAYS AS ((3 OPERATOR(pg_catalog.*) id)) STORED)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_drop_expression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "new_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr": "(3 OPERATOR(pg_catalog.*) id)"}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_expression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , new_id pg_catalog.int4 STORAGE PLAIN      GENERATED ALWAYS AS ((3 OPERATOR(pg_catalog.*) id)) STORED)     
 ALTER TABLE test_drop_expression ALTER new_id DROP EXPRESSION;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I DROP EXPRESSION %{if_exists}s", "type": "drop expression", "column": "new_id", "if_exists": ""}], "identity": {"objname": "test_drop_expression", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_drop_expression ALTER COLUMN new_id DROP EXPRESSION 
@@ -161,8 +163,8 @@ CREATE TABLE test_add_generated(
     col2 int NOT NULL,
     col3 int NOT NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_add_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_add_generated (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , col1 pg_catalog.int4 STORAGE PLAIN   NOT NULL   , col2 pg_catalog.int4 STORAGE PLAIN   NOT NULL   , col3 pg_catalog.int4 STORAGE PLAIN   NOT NULL   )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_add_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_add_generated (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , col1 pg_catalog.int4 STORAGE PLAIN   NOT NULL   , col2 pg_catalog.int4 STORAGE PLAIN   NOT NULL   , col3 pg_catalog.int4 STORAGE PLAIN   NOT NULL   )     
 ALTER TABLE test_add_generated ALTER col1 ADD GENERATED ALWAYS AS IDENTITY;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
@@ -208,8 +210,8 @@ NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id6", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id7", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_generated (id1 pg_catalog.int4 STORAGE PLAIN     GENERATED BY DEFAULT AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id2 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id3 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id4 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id5 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id6 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id7 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id6", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id7", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_generated (id1 pg_catalog.int4 STORAGE PLAIN     GENERATED BY DEFAULT AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id2 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id3 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id4 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id5 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id6 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) , id7 pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )     
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
 NOTICE:  deparsed json: <NULL>
@@ -227,37 +229,37 @@ NOTICE:  re-formed command: <NULL>
 ALTER TABLE test_set_generated ALTER id1 SET GENERATED ALWAYS;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id1", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "option": "ALWAYS"}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id1", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "option": "ALWAYS"}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id1 SET GENERATED ALWAYS SET CACHE 1 SET NO CYCLE SET INCREMENT BY 1 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 1
 ALTER TABLE test_set_generated ALTER id2 SET GENERATED BY DEFAULT;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id2", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id2", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id2 SET GENERATED BY DEFAULT SET CACHE 1 SET NO CYCLE SET INCREMENT BY 1 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 1
 ALTER TABLE test_set_generated ALTER id3 SET INCREMENT BY 10;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id3", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "10", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id3", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "10", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id3  SET CACHE 1 SET NO CYCLE SET INCREMENT BY 10 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 1
 ALTER TABLE test_set_generated ALTER id4 RESTART;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id4", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id4", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id4  SET CACHE 1 SET NO CYCLE SET INCREMENT BY 1 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 1
 ALTER TABLE test_set_generated ALTER id5 RESTART WITH 101;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id5", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "101", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id5", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "101", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id5  SET CACHE 1 SET NO CYCLE SET INCREMENT BY 1 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 101
 ALTER TABLE test_set_generated ALTER id6 RESTART WITH 201;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id6", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "201", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id6", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "present": false}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "201", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id6  SET CACHE 1 SET NO CYCLE SET INCREMENT BY 1 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 201
 ALTER TABLE test_set_generated ALTER COLUMN id7 SET GENERATED BY DEFAULT SET INCREMENT BY 100 RESTART WITH 301;
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id7", "definition": {"fmt": "%{definition}s", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "100", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "301", "clause": "restart"}]}}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{definition}s", "type": "set identity", "column": "id7", "definition": {"fmt": "%{identity_type}s %{seq_definition: }s", "identity_type": {"fmt": "SET GENERATED %{option}s", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "SET CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "SET %{no}s CYCLE", "clause": "cycle"}, {"fmt": "SET INCREMENT BY %{value}s", "value": "100", "clause": "seqincrement"}, {"fmt": "SET MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "SET MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "SET START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "301", "clause": "restart"}]}}], "identity": {"objname": "test_set_generated", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_generated ALTER COLUMN id7 SET GENERATED BY DEFAULT SET CACHE 1 SET NO CYCLE SET INCREMENT BY 100 SET MINVALUE 1 SET MAXVALUE 2147483647 SET START WITH 1 RESTART 301
 -- ALTER [ COLUMN ] column_name DROP IDENTITY [ IF EXISTS ]
 CREATE TABLE test_drop_identity(
@@ -266,8 +268,8 @@ CREATE TABLE test_drop_identity(
 );
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_drop_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_identity (id pg_catalog.int4 STORAGE PLAIN      , id_generated pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_drop_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_identity (id pg_catalog.int4 STORAGE PLAIN      , id_generated pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )     
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
 ALTER TABLE test_drop_identity ALTER id_generated DROP IDENTITY;
@@ -281,8 +283,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_drop_identity ALTER COLUMN
 CREATE TABLE test_set_statistics(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_statistics", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_statistics (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_statistics", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_statistics (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_statistics ALTER id SET STATISTICS 1;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET STATISTICS %{statistics}n", "type": "set statistics", "column": "id", "statistics": 1}], "identity": {"objname": "test_set_statistics", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_statistics ALTER COLUMN id SET STATISTICS 1
@@ -290,8 +292,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_statistics ALTER COLUMN
 CREATE TABLE test_set_attribute(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_attribute", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_attribute (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_attribute", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_attribute (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_attribute ALTER name SET (n_distinct = 102);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{option}s (%{options:, }s)", "column": "name", "option": "SET", "options": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "n_distinct"}, "value": "102"}]}], "identity": {"objname": "test_set_attribute", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_attribute ALTER COLUMN name SET (n_distinct = '102')
@@ -302,8 +304,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_attribute ALTER COLUMN
 CREATE TABLE test_reset_attribute(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_reset_attribute", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_reset_attribute (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_reset_attribute", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_reset_attribute (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_reset_attribute ALTER name RESET (n_distinct);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I %{option}s (%{options:, }s)", "column": "name", "option": "RESET", "options": [{"fmt": "%{label}s", "label": {"fmt": "%{label}I", "label": "n_distinct"}}]}], "identity": {"objname": "test_reset_attribute", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_reset_attribute ALTER COLUMN name RESET (n_distinct)
@@ -315,8 +317,8 @@ CREATE TABLE test_set_storage(
     LIKE orders,
     product_name text
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_storage", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "product_name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_storage (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , product_name pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_storage", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "product_name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_storage (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , product_name pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 ALTER TABLE test_set_storage ALTER id SET STORAGE PLAIN;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET STORAGE %{storage}s", "type": "set storage", "column": "id", "storage": "plain"}], "identity": {"objname": "test_set_storage", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage ALTER COLUMN id SET STORAGE plain
@@ -333,8 +335,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage ALTER COLUMN pr
 CREATE TABLE test_set_compression(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_compression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_compression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_compression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_compression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_compression ALTER name SET COMPRESSION "pglz";
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET COMPRESSION %{compression_method}s", "type": "set compression", "column": "name", "compression_method": "pglz"}], "identity": {"objname": "test_set_compression", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_compression ALTER COLUMN name SET COMPRESSION pglz
@@ -345,8 +347,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_compression ALTER COLUM
 CREATE TABLE test_add_table_constraint(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_add_table_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_add_table_constraint (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_add_table_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_add_table_constraint (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_add_table_constraint ADD PRIMARY KEY (id);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET NOT NULL", "type": "set not null", "column": "id"}, {"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "test_add_table_constraint_pkey", "type": "add constraint", "definition": "PRIMARY KEY (id)"}], "identity": {"objname": "test_add_table_constraint", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_add_table_constraint ALTER COLUMN id SET NOT NULL, ADD CONSTRAINT test_add_table_constraint_pkey PRIMARY KEY (id)
@@ -384,8 +386,8 @@ CREATE TABLE test_alter_constraint_referenced(
     id3 int UNIQUE,
     id4 int UNIQUE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_alter_constraint_referenced", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id1_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id1)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id2_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id2)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id3_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id3)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id4_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id4)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_constraint_referenced (id1 pg_catalog.int4 STORAGE PLAIN      , id2 pg_catalog.int4 STORAGE PLAIN      , id3 pg_catalog.int4 STORAGE PLAIN      , id4 pg_catalog.int4 STORAGE PLAIN      , CONSTRAINT test_alter_constraint_referenced_id1_key UNIQUE (id1), CONSTRAINT test_alter_constraint_referenced_id2_key UNIQUE (id2), CONSTRAINT test_alter_constraint_referenced_id3_key UNIQUE (id3), CONSTRAINT test_alter_constraint_referenced_id4_key UNIQUE (id4))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_alter_constraint_referenced", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id1_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id1)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id2_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id2)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id3_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id3)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_referenced_id4_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id4)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_constraint_referenced (id1 pg_catalog.int4 STORAGE PLAIN      , id2 pg_catalog.int4 STORAGE PLAIN      , id3 pg_catalog.int4 STORAGE PLAIN      , id4 pg_catalog.int4 STORAGE PLAIN      , CONSTRAINT test_alter_constraint_referenced_id1_key UNIQUE (id1), CONSTRAINT test_alter_constraint_referenced_id2_key UNIQUE (id2), CONSTRAINT test_alter_constraint_referenced_id3_key UNIQUE (id3), CONSTRAINT test_alter_constraint_referenced_id4_key UNIQUE (id4))     
 CREATE TABLE test_alter_constraint(
     id1 int,
     id2 int,
@@ -397,8 +399,8 @@ CREATE TABLE test_alter_constraint(
     CONSTRAINT alter_cstr3 FOREIGN KEY (id3) REFERENCES test_alter_constraint_referenced (id3) DEFERRABLE INITIALLY DEFERRED,
     CONSTRAINT alter_cstr4 FOREIGN KEY (id4) REFERENCES test_alter_constraint_referenced (id4) DEFERRABLE INITIALLY IMMEDIATE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_alter_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_constraint (id1 pg_catalog.int4 STORAGE PLAIN      , id2 pg_catalog.int4 STORAGE PLAIN      , id3 pg_catalog.int4 STORAGE PLAIN      , id4 pg_catalog.int4 STORAGE PLAIN      , id5 pg_catalog.int4 STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_alter_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_constraint (id1 pg_catalog.int4 STORAGE PLAIN      , id2 pg_catalog.int4 STORAGE PLAIN      , id3 pg_catalog.int4 STORAGE PLAIN      , id4 pg_catalog.int4 STORAGE PLAIN      , id5 pg_catalog.int4 STORAGE PLAIN      )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "alter_cstr1", "type": "add constraint", "definition": "FOREIGN KEY (id1) REFERENCES public.test_alter_constraint_referenced(id1) DEFERRABLE INITIALLY DEFERRED"}, {"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "alter_cstr2", "type": "add constraint", "definition": "FOREIGN KEY (id2) REFERENCES public.test_alter_constraint_referenced(id2)"}, {"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "alter_cstr3", "type": "add constraint", "definition": "FOREIGN KEY (id3) REFERENCES public.test_alter_constraint_referenced(id3) DEFERRABLE INITIALLY DEFERRED"}, {"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "alter_cstr4", "type": "add constraint", "definition": "FOREIGN KEY (id4) REFERENCES public.test_alter_constraint_referenced(id4) DEFERRABLE"}], "identity": {"objname": "test_alter_constraint", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_alter_constraint ADD CONSTRAINT alter_cstr1 FOREIGN KEY (id1) REFERENCES public.test_alter_constraint_referenced(id1) DEFERRABLE INITIALLY DEFERRED, ADD CONSTRAINT alter_cstr2 FOREIGN KEY (id2) REFERENCES public.test_alter_constraint_referenced(id2), ADD CONSTRAINT alter_cstr3 FOREIGN KEY (id3) REFERENCES public.test_alter_constraint_referenced(id3) DEFERRABLE INITIALLY DEFERRED, ADD CONSTRAINT alter_cstr4 FOREIGN KEY (id4) REFERENCES public.test_alter_constraint_referenced(id4) DEFERRABLE
 ALTER TABLE test_alter_constraint ALTER CONSTRAINT alter_cstr1 NOT DEFERRABLE;
@@ -417,8 +419,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_alter_constraint ALTER CONS
 CREATE TABLE test_validate_constraint(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_validate_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_validate_constraint (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_validate_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_validate_constraint (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_validate_constraint ADD CONSTRAINT test_validate_constraint_cstr CHECK (length(name) < 10) NOT VALID;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "test_validate_constraint_cstr", "type": "add constraint", "definition": "CHECK ((pg_catalog.length((name)::pg_catalog.text) OPERATOR(pg_catalog.<) 10)) NOT VALID"}], "identity": {"objname": "test_validate_constraint", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_validate_constraint ADD CONSTRAINT test_validate_constraint_cstr CHECK ((pg_catalog.length((name)::pg_catalog.text) OPERATOR(pg_catalog.<) 10)) NOT VALID
@@ -431,15 +433,15 @@ CREATE TABLE test_drop_constraint(
     CONSTRAINT test_drop_constraint_check CHECK (id < 100),
     CONSTRAINT test_drop_constraint_uniq UNIQUE (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_drop_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.<) 100))"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_uniq", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_constraint (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_drop_constraint_check CHECK ((id OPERATOR(pg_catalog.<) 100)), CONSTRAINT test_drop_constraint_uniq UNIQUE (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_drop_constraint", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.<) 100))"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_uniq", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_constraint (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_drop_constraint_check CHECK ((id OPERATOR(pg_catalog.<) 100)), CONSTRAINT test_drop_constraint_uniq UNIQUE (id))     
 CREATE TABLE test_drop_constraint_reference(
     id int REFERENCES test_drop_constraint (id),
     name varchar,
     CONSTRAINT test_drop_constraint_reference_cstr1 CHECK (length(name) < 10)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_drop_constraint_reference", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_reference_cstr1", "type": "constraint", "contype": "check", "definition": "CHECK ((pg_catalog.length((name)::pg_catalog.text) OPERATOR(pg_catalog.<) 10))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_constraint_reference (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT test_drop_constraint_reference_cstr1 CHECK ((pg_catalog.length((name)::pg_catalog.text) OPERATOR(pg_catalog.<) 10)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_drop_constraint_reference", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_reference_cstr1", "type": "constraint", "contype": "check", "definition": "CHECK ((pg_catalog.length((name)::pg_catalog.text) OPERATOR(pg_catalog.<) 10))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_drop_constraint_reference (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT test_drop_constraint_reference_cstr1 CHECK ((pg_catalog.length((name)::pg_catalog.text) OPERATOR(pg_catalog.<) 10)))     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "test_drop_constraint_reference_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id) REFERENCES public.test_drop_constraint(id)"}], "identity": {"objname": "test_drop_constraint_reference", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_drop_constraint_reference ADD CONSTRAINT test_drop_constraint_reference_id_fkey FOREIGN KEY (id) REFERENCES public.test_drop_constraint(id)
 ALTER TABLE test_drop_constraint_reference DROP CONSTRAINT test_drop_constraint_reference_cstr1;
@@ -452,8 +454,10 @@ ALTER TABLE test_drop_constraint DROP CONSTRAINT IF EXISTS test_drop_constraint_
 NOTICE:  constraint "test_drop_constraint_check" of relation "test_drop_constraint" does not exist, skipping
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "DROP CONSTRAINT %{if_exists}s %{constraint}I %{cascade}s", "type": "drop constraint", "cascade": "", "if_exists": "IF EXISTS", "constraint": "test_drop_constraint_check"}], "identity": {"objname": "test_drop_constraint", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_drop_constraint DROP CONSTRAINT IF EXISTS test_drop_constraint_check 
--- TOFIX
--- ALTER TABLE test_drop_constraint DROP CONSTRAINT test_drop_constraint_uniq CASCADE;
+ALTER TABLE test_drop_constraint DROP CONSTRAINT test_drop_constraint_uniq CASCADE;
+NOTICE:  drop cascades to constraint test_drop_constraint_reference_id_fkey on table test_drop_constraint_reference
+NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "DROP CONSTRAINT %{if_exists}s %{constraint}I %{cascade}s", "type": "drop constraint", "cascade": "CASCADE", "if_exists": "", "constraint": "test_drop_constraint_uniq"}], "identity": {"objname": "test_drop_constraint", "schemaname": "public"}}
+NOTICE:  re-formed command: ALTER TABLE  public.test_drop_constraint DROP CONSTRAINT  test_drop_constraint_uniq CASCADE
 -- TODO: This should be tested with TRIGGER related testing
 -- DISABLE TRIGGER [ trigger_name | ALL | USER ]
 -- ENABLE TRIGGER [ trigger_name | ALL | USER ]
@@ -482,8 +486,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_enable_always_rule ENABLE R
 CREATE TABLE test_disable_row_security(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_disable_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_disable_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_disable_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_disable_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_disable_row_security DISABLE ROW LEVEL SECURITY;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "DISABLE ROW LEVEL SECURITY", "type": "disable row security"}], "identity": {"objname": "test_disable_row_security", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_disable_row_security DISABLE ROW LEVEL SECURITY
@@ -491,8 +495,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_disable_row_security DISABL
 CREATE TABLE test_enable_row_security(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_enable_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_enable_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_enable_row_security ENABLE ROW LEVEL SECURITY;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ENABLE ROW LEVEL SECURITY", "type": "enable row security"}], "identity": {"objname": "test_enable_row_security", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_enable_row_security ENABLE ROW LEVEL SECURITY
@@ -500,8 +504,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_enable_row_security ENABLE
 CREATE TABLE test_force_row_security(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_force_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_force_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_force_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_force_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_force_row_security FORCE ROW LEVEL SECURITY;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "FORCE ROW LEVEL SECURITY"}], "identity": {"objname": "test_force_row_security", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_force_row_security FORCE ROW LEVEL SECURITY
@@ -509,8 +513,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_force_row_security FORCE RO
 CREATE TABLE test_no_force_row_security(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_no_force_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_no_force_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_no_force_row_security", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_no_force_row_security (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_no_force_row_security NO FORCE ROW LEVEL SECURITY;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "NO FORCE ROW LEVEL SECURITY"}], "identity": {"objname": "test_no_force_row_security", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_no_force_row_security NO FORCE ROW LEVEL SECURITY
@@ -519,8 +523,8 @@ CREATE TABLE test_cluster(
     LIKE orders,
     PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_cluster", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_cluster_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_cluster (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_cluster_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_cluster", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_cluster_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_cluster (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_cluster_pkey PRIMARY KEY (id))     
 ALTER TABLE test_cluster CLUSTER ON test_cluster_pkey;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "CLUSTER ON %{index}I", "type": "cluster on", "index": "test_cluster_pkey"}], "identity": {"objname": "test_cluster", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_cluster CLUSTER ON test_cluster_pkey
@@ -529,8 +533,8 @@ CREATE TABLE test_without_cluster(
     LIKE orders,
     PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_without_cluster", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_without_cluster_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_without_cluster (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_without_cluster_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_without_cluster", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_without_cluster_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_without_cluster (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_without_cluster_pkey PRIMARY KEY (id))     
 ALTER TABLE test_without_cluster CLUSTER ON test_without_cluster_pkey;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "CLUSTER ON %{index}I", "type": "cluster on", "index": "test_without_cluster_pkey"}], "identity": {"objname": "test_without_cluster", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_without_cluster CLUSTER ON test_without_cluster_pkey
@@ -541,8 +545,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_without_cluster SET WITHOUT
 CREATE TABLE test_set_without_oids(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_without_oids", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_without_oids (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_without_oids", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_without_oids (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_without_oids SET WITHOUT OIDS;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "SET WITHOUT OIDS", "type": "set without oids"}], "identity": {"objname": "test_set_without_oids", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_without_oids SET WITHOUT OIDS
@@ -550,8 +554,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_without_oids SET WITHOU
 CREATE TABLE test_set_access_method(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_access_method", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_access_method (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_access_method", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_access_method (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_access_method SET ACCESS METHOD heap;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "SET ACCESS METHOD %{access_method}I", "type": "set access method", "access_method": "heap"}], "identity": {"objname": "test_set_access_method", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_access_method SET ACCESS METHOD heap
@@ -559,8 +563,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_access_method SET ACCES
 CREATE TABLE test_set_tablespace(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_tablespace", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_tablespace (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_tablespace", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_tablespace (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_tablespace SET TABLESPACE pg_default;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "SET TABLESPACE %{tablespace}I", "type": "set tablespace", "tablespace": "pg_default"}], "identity": {"objname": "test_set_tablespace", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_tablespace SET TABLESPACE pg_default
@@ -568,16 +572,16 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_tablespace SET TABLESPA
 CREATE TABLE test_set_logged(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_logged", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_logged (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_logged", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_logged (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_logged SET LOGGED;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "SET LOGGED", "type": "set logged"}], "identity": {"objname": "test_set_logged", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_logged SET LOGGED
 CREATE TABLE test_set_unlogged(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_unlogged", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_unlogged (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_unlogged", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_unlogged (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_unlogged SET UNLOGGED;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "SET UNLOGGED", "type": "set unlogged"}], "identity": {"objname": "test_set_unlogged", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_unlogged SET UNLOGGED
@@ -585,16 +589,16 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_unlogged SET UNLOGGED
 CREATE TABLE test_set_storage_params1(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_storage_params1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_storage_params1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_storage_params1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_storage_params1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_storage_params1 SET (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "%{set_reset}s (%{options:, }s)", "options": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}], "set_reset": "SET"}], "identity": {"objname": "test_set_storage_params1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage_params1 SET (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true')
 CREATE TABLE test_set_storage_params2(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_storage_params2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_storage_params2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_storage_params2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_storage_params2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_storage_params2 SET (vacuum_index_cleanup = ON);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "%{set_reset}s (%{options:, }s)", "options": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}], "set_reset": "SET"}], "identity": {"objname": "test_set_storage_params2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage_params2 SET (vacuum_index_cleanup = 'on')
@@ -602,8 +606,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage_params2 SET (va
 CREATE TABLE test_reset_storage_params1(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_reset_storage_params1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_reset_storage_params1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_reset_storage_params1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_reset_storage_params1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_storage_params1 SET (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "%{set_reset}s (%{options:, }s)", "options": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}], "set_reset": "SET"}], "identity": {"objname": "test_set_storage_params1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage_params1 SET (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true')
@@ -613,8 +617,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_reset_storage_params1 RESET
 CREATE TABLE test_reset_storage_params2(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_reset_storage_params2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_reset_storage_params2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_reset_storage_params2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_reset_storage_params2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_storage_params2 SET (vacuum_index_cleanup = ON);
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "%{set_reset}s (%{options:, }s)", "options": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}], "set_reset": "SET"}], "identity": {"objname": "test_set_storage_params2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_set_storage_params2 SET (vacuum_index_cleanup = 'on')
@@ -625,14 +629,14 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_reset_storage_params2 RESET
 CREATE TABLE test_inherit_parent(
     parent_id int
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_inherit_parent", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "parent_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_inherit_parent (parent_id pg_catalog.int4 STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_inherit_parent", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "parent_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_inherit_parent (parent_id pg_catalog.int4 STORAGE PLAIN      )     
 CREATE TABLE test_inherit_child(
     parent_id int,
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_inherit_child", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "parent_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_inherit_child (parent_id pg_catalog.int4 STORAGE PLAIN      , id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_inherit_child", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "parent_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_inherit_child (parent_id pg_catalog.int4 STORAGE PLAIN      , id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_inherit_child INHERIT test_inherit_parent;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "INHERIT %{parent}D", "type": "inherit", "parent": {"objname": "test_inherit_parent", "schemaname": "public"}}], "identity": {"objname": "test_inherit_child", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_inherit_child INHERIT public.test_inherit_parent
@@ -640,13 +644,13 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_inherit_child INHERIT publi
 CREATE TABLE test_no_inherit_parent(
     parent_id int
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_no_inherit_parent", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "parent_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_no_inherit_parent (parent_id pg_catalog.int4 STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_no_inherit_parent", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "parent_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_no_inherit_parent (parent_id pg_catalog.int4 STORAGE PLAIN      )     
 CREATE TABLE test_no_inherit_child(
     LIKE orders
 ) INHERITS (test_no_inherit_parent);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_no_inherit_child", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "test_no_inherit_parent", "schemaname": "public"}]}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_no_inherit_child (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      ) INHERITS (public.test_no_inherit_parent)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_no_inherit_child", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "test_no_inherit_parent", "schemaname": "public"}]}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_no_inherit_child (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      ) INHERITS (public.test_no_inherit_parent)    
 ALTER TABLE test_no_inherit_child NO INHERIT test_no_inherit_parent;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "NO INHERIT %{parent}D", "type": "drop inherit", "parent": {"objname": "test_no_inherit_parent", "schemaname": "public"}}], "identity": {"objname": "test_no_inherit_child", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_no_inherit_child NO INHERIT public.test_no_inherit_parent
@@ -655,15 +659,15 @@ CREATE TABLE test_type(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_type", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_type (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_type", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_type (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 ALTER TABLE test_type OF test_type_product_type;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "OF %{type_of}T", "type": "add of", "type_of": {"typmod": "", "typarray": false, "typename": "test_type_product_type", "schemaname": "public"}}], "identity": {"objname": "test_type", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_type OF public.test_type_product_type
 -- NOT OF
 CREATE TABLE test_type_not_of OF test_type_product_type;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "test_type_product_type", "schemaname": "public"}, "identity": {"objname": "test_type_not_of", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_type_not_of OF public.test_type_product_type      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "test_type_product_type", "schemaname": "public"}, "identity": {"objname": "test_type_not_of", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_type_not_of OF public.test_type_product_type     
 ALTER TABLE test_type_not_of NOT OF;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "NOT OF", "type": "not of"}], "identity": {"objname": "test_type_not_of", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_type_not_of NOT OF
@@ -673,8 +677,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_type_not_of NOT OF
 CREATE TABLE test_replica_identity1(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_replica_identity1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_replica_identity1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_replica_identity1 REPLICA IDENTITY DEFAULT;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "REPLICA IDENTITY %{ident}s", "type": "replica identity", "ident": "DEFAULT"}], "identity": {"objname": "test_replica_identity1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_replica_identity1 REPLICA IDENTITY DEFAULT
@@ -682,24 +686,24 @@ CREATE TABLE test_replica_identity2(
     LIKE orders,
     PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_replica_identity2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_replica_identity2_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_replica_identity2_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_replica_identity2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_replica_identity2_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_replica_identity2_pkey PRIMARY KEY (id))     
 ALTER TABLE test_replica_identity2 REPLICA IDENTITY USING INDEX test_replica_identity2_pkey;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "REPLICA IDENTITY %{ident}s", "type": "replica identity", "ident": {"fmt": "USING INDEX %{index}I", "index": "test_replica_identity2_pkey"}}], "identity": {"objname": "test_replica_identity2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_replica_identity2 REPLICA IDENTITY USING INDEX test_replica_identity2_pkey
 CREATE TABLE test_replica_identity3(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_replica_identity3", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity3 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_replica_identity3", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity3 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_replica_identity3 REPLICA IDENTITY FULL;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "REPLICA IDENTITY %{ident}s", "type": "replica identity", "ident": "FULL"}], "identity": {"objname": "test_replica_identity3", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_replica_identity3 REPLICA IDENTITY FULL
 CREATE TABLE test_replica_identity4(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_replica_identity4", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity4 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_replica_identity4", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_replica_identity4 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_replica_identity4 REPLICA IDENTITY NOTHING;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "REPLICA IDENTITY %{ident}s", "type": "replica identity", "ident": "NOTHING"}], "identity": {"objname": "test_replica_identity4", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_replica_identity4 REPLICA IDENTITY NOTHING
@@ -707,8 +711,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_replica_identity4 REPLICA I
 CREATE TABLE test_alter_col_name(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_alter_col_name", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_col_name (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_alter_col_name", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_col_name (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_alter_col_name RENAME id TO new_id;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{if_exists}s %{identity}D RENAME COLUMN %{colname}I TO %{newname}I", "colname": "id", "newname": "new_id", "objtype": "TABLE", "identity": {"objname": "test_alter_col_name", "schemaname": "public"}, "if_exists": ""}
 NOTICE:  re-formed command: ALTER TABLE  public.test_alter_col_name RENAME COLUMN id TO new_id
@@ -720,8 +724,8 @@ CREATE TABLE test_alter_constraint_name(
     LIKE orders,
     CONSTRAINT test_alter_constraint_name_old CHECK (id > 10)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_alter_constraint_name", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_name_old", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_constraint_name (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_alter_constraint_name_old CHECK ((id OPERATOR(pg_catalog.>) 10)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_alter_constraint_name", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "test_alter_constraint_name_old", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_alter_constraint_name (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      , CONSTRAINT test_alter_constraint_name_old CHECK ((id OPERATOR(pg_catalog.>) 10)))     
 ALTER TABLE test_alter_constraint_name RENAME CONSTRAINT test_alter_constraint_name_old TO test_alter_constraint_name_new;
 NOTICE:  deparsed json: {"fmt": "ALTER TABLE %{only}s %{identity}D RENAME CONSTRAINT %{oldname}I TO %{newname}I", "only": "", "newname": "test_alter_constraint_name_new", "oldname": "test_alter_constraint_name_old", "identity": {"objname": "test_alter_constraint_name", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.test_alter_constraint_name RENAME CONSTRAINT test_alter_constraint_name_old TO test_alter_constraint_name_new
@@ -729,8 +733,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_alter_constraint_name RENAM
 CREATE TABLE test_rename_table(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_rename_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_rename_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_rename_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_rename_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_rename_table RENAME to new_test_rename_table;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{if_exists}s %{identity}D RENAME TO %{newname}I", "newname": "new_test_rename_table", "objtype": "TABLE", "identity": {"objname": "test_rename_table", "schemaname": "public"}, "if_exists": ""}
 NOTICE:  re-formed command: ALTER TABLE  public.test_rename_table RENAME TO new_test_rename_table
@@ -738,8 +742,8 @@ NOTICE:  re-formed command: ALTER TABLE  public.test_rename_table RENAME TO new_
 CREATE TABLE test_set_schema(
     LIKE orders
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_set_schema", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_set_schema (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_set_schema", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_set_schema (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 ALTER TABLE test_set_schema SET SCHEMA new_test_schema;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{identity}s SET SCHEMA %{newschema}I", "objtype": "TABLE", "identity": "public.test_set_schema", "newschema": "new_test_schema"}
 NOTICE:  re-formed command: ALTER TABLE public.test_set_schema SET SCHEMA new_test_schema
@@ -748,55 +752,55 @@ NOTICE:  re-formed command: ALTER TABLE public.test_set_schema SET SCHEMA new_te
 -- TOFIX: can not be caught by ddl_command_end event trigger.
 -- Deparse of T_AlterTableMoveAllStmt is not supported,
 -- TABLESPACE commands (global object commands) are also not supported.
--- ALTER TABLE ALL IN TABLESPACE pg_default SET TABLESPACE pg_default;
--- ALTER TABLE ALL IN TABLESPACE pg_default OWNED BY ddl_testing_role SET TABLESPACE pg_default;
+ALTER TABLE ALL IN TABLESPACE pg_default SET TABLESPACE pg_default;
+ALTER TABLE ALL IN TABLESPACE pg_default OWNED BY ddl_testing_role SET TABLESPACE pg_default;
 -- ATTACH PARTITION partition_name { FOR VALUES partition_bound_spec | DEFAULT }
 CREATE TABLE test_partition_attach_range(
     LIKE orders
 ) PARTITION BY RANGE (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_range", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_range (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY RANGE (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_range", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_range (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY RANGE (id)   
 CREATE TABLE test_partition_attach_range_p_1(
     LIKE test_partition_attach_range
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_range_p_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_range_p_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_range_p_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_range_p_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 -- TOFIX
 -- ALTER TABLE test_partition_attach_range ATTACH PARTITION test_partition_attach_range_p_1 DEFAULT;
 CREATE TABLE test_partition_attach_range_p_2(
     LIKE test_partition_attach_range
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_range_p_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_range_p_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_range_p_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_range_p_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 -- TOFIX
 -- ALTER TABLE test_partition_attach_range ATTACH PARTITION test_partition_attach_range_p_2 FOR VALUES FROM (100) TO (200);
 CREATE TABLE test_partition_attach_hash(
     LIKE orders
 ) PARTITION BY HASH (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_hash", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_hash (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY HASH (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_hash", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_hash (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY HASH (id)   
 CREATE TABLE test_partition_attach_hash_p(
     LIKE test_partition_attach_hash
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_hash_p", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_hash_p (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_hash_p", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_hash_p (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 -- TOFIX
 -- ALTER TABLE test_partition_attach_hash ATTACH PARTITION test_partition_attach_hash_p FOR VALUES WITH (MODULUS 10, REMAINDER 1);
 CREATE TABLE test_partition_attach_list(
     LIKE orders
 ) PARTITION BY LIST (name);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (name)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY LIST (name)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (name)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY LIST (name)   
 CREATE TABLE test_partition_attach_list_p1(
     LIKE test_partition_attach_list
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_list_p1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list_p1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_list_p1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list_p1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 CREATE TABLE test_partition_attach_list_p2(
     LIKE test_partition_attach_list
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_partition_attach_list_p2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list_p2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_partition_attach_list_p2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list_p2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 -- TOFIX
 -- ALTER TABLE test_partition_attach_list ATTACH PARTITION test_partition_attach_list_p1 FOR VALUES IN ('key1');
 -- ALTER TABLE test_partition_attach_list ATTACH PARTITION test_partition_attach_list_p2 FOR VALUES IN ('key2', 'key3');
@@ -804,17 +808,17 @@ NOTICE:  re-formed command: CREATE  TABLE  public.test_partition_attach_list_p2
 CREATE TABLE test_detach_partition(
     LIKE orders
 ) PARTITION BY RANGE (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_detach_partition", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY RANGE (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_detach_partition", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )  PARTITION BY RANGE (id)   
 CREATE TABLE test_detach_partition_p1 PARTITION OF test_detach_partition FOR VALUES FROM (1) TO (100);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_detach_partition_p1", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "test_detach_partition", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (1) TO (100)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition_p1 PARTITION OF public.test_detach_partition  FOR VALUES FROM (1) TO (100)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_detach_partition_p1", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "test_detach_partition", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (1) TO (100)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition_p1 PARTITION OF public.test_detach_partition  FOR VALUES FROM (1) TO (100)    
 CREATE TABLE test_detach_partition_p2 PARTITION OF test_detach_partition FOR VALUES FROM (101) TO (200);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_detach_partition_p2", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "test_detach_partition", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (101) TO (200)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition_p2 PARTITION OF public.test_detach_partition  FOR VALUES FROM (101) TO (200)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_detach_partition_p2", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "test_detach_partition", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (101) TO (200)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition_p2 PARTITION OF public.test_detach_partition  FOR VALUES FROM (101) TO (200)    
 CREATE TABLE test_detach_partition_p3 PARTITION OF test_detach_partition FOR VALUES FROM (201) TO (300);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_detach_partition_p3", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "test_detach_partition", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (201) TO (300)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition_p3 PARTITION OF public.test_detach_partition  FOR VALUES FROM (201) TO (300)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_detach_partition_p3", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "test_detach_partition", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (201) TO (300)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_detach_partition_p3 PARTITION OF public.test_detach_partition  FOR VALUES FROM (201) TO (300)    
 -- TOFIX
 -- ALTER TABLE test_detach_partition DETACH PARTITION test_detach_partition_p1;
 -- ALTER TABLE test_detach_partition DETACH PARTITION test_detach_partition_p2 CONCURRENTLY;
diff --git a/src/test/modules/test_ddl_deparse_regress/expected/constraints.out b/src/test/modules/test_ddl_deparse_regress/expected/constraints.out
index 45058db174..9c24b795d0 100644
--- a/src/test/modules/test_ddl_deparse_regress/expected/constraints.out
+++ b/src/test/modules/test_ddl_deparse_regress/expected/constraints.out
@@ -5,42 +5,42 @@ CREATE TABLE col_cstr_not_null(
     id int CONSTRAINT id_constraint NOT NULL,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_not_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_not_null (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_not_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_not_null (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 --  NULL |
 CREATE TABLE col_cstr_null(
     id int NULL,
     name varchar CONSTRAINT name_constraint NOT NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default" NOT NULL   )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default" NOT NULL   )     
 --  CHECK ( expression ) [ NO INHERIT ] |
 CREATE TABLE col_cstr_check(
     id int CHECK (id > 10),
     name varchar NOT NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_check", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_check_id_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_check (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default" NOT NULL   , CONSTRAINT col_cstr_check_id_check CHECK ((id OPERATOR(pg_catalog.>) 10)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_check", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_check_id_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_check (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default" NOT NULL   , CONSTRAINT col_cstr_check_id_check CHECK ((id OPERATOR(pg_catalog.>) 10)))     
 CREATE TABLE col_cstr_check_no_inherit(
     id int CHECK (id > 10) NO INHERIT,
     name varchar NOT NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_check_no_inherit", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_check_no_inherit_id_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_check_no_inherit (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default" NOT NULL   , CONSTRAINT col_cstr_check_no_inherit_id_check CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_check_no_inherit", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_check_no_inherit_id_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_check_no_inherit (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default" NOT NULL   , CONSTRAINT col_cstr_check_no_inherit_id_check CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT)     
 --  DEFAULT default_expr |
 CREATE TABLE col_cstr_default(
     id int NOT NULL,
     name varchar DEFAULT 'foo'
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_default (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"  DEFAULT 'foo'::character varying  )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_default (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"  DEFAULT 'foo'::character varying  )     
 --  GENERATED ALWAYS AS ( generation_expr ) STORED |
 CREATE TABLE col_cstr_generated_always_as(
     id int NOT NULL,
     id_generated int GENERATED ALWAYS AS ( id * 10 ) STORED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_generated_always_as", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr": "(id OPERATOR(pg_catalog.*) 10)"}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_generated_always_as (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , id_generated pg_catalog.int4 STORAGE PLAIN      GENERATED ALWAYS AS ((id OPERATOR(pg_catalog.*) 10)) STORED)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_generated_always_as", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr": "(id OPERATOR(pg_catalog.*) 10)"}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_generated_always_as (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , id_generated pg_catalog.int4 STORAGE PLAIN      GENERATED ALWAYS AS ((id OPERATOR(pg_catalog.*) 10)) STORED)     
 --  GENERATED { ALWAYS | BY DEFAULT } AS IDENTITY [ ( sequence_options ) ] |
 CREATE TABLE col_cstr_generated_always_as_identity(
     id int NOT NULL,
@@ -48,8 +48,8 @@ CREATE TABLE col_cstr_generated_always_as_identity(
 );
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_generated_always_as_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_generated_always_as_identity (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , id_generated pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_generated_always_as_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "ALWAYS"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_generated_always_as_identity (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , id_generated pg_catalog.int4 STORAGE PLAIN     GENERATED ALWAYS AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )     
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
 CREATE TABLE col_cstr_generated_by_default_as_identity_with_options(
@@ -58,8 +58,8 @@ CREATE TABLE col_cstr_generated_by_default_as_identity_with_options(
 );
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_generated_by_default_as_identity_with_options", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "10", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_generated_by_default_as_identity_with_options (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , id_generated pg_catalog.int4 STORAGE PLAIN     GENERATED BY DEFAULT AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 10 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_generated_by_default_as_identity_with_options", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id_generated", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_type}s ( %{seq_definition: }s )", "identity_type": {"fmt": "GENERATED %{option}s AS IDENTITY", "option": "BY DEFAULT"}, "seq_definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "10", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}]}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_generated_by_default_as_identity_with_options (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , id_generated pg_catalog.int4 STORAGE PLAIN     GENERATED BY DEFAULT AS IDENTITY ( CACHE 1 NO CYCLE INCREMENT BY 10 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 ) )     
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
 --  UNIQUE [ NULLS [ NOT ] DISTINCT ] |
@@ -67,43 +67,43 @@ CREATE TABLE col_cstr_unique(
     id int NOT NULL,
     name varchar UNIQUE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_unique", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_unique_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_unique (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_unique_name_key UNIQUE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_unique", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_unique_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_unique (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_unique_name_key UNIQUE (name))     
 CREATE TABLE col_cstr_unique_nulls_distinct(
     id int NOT NULL,
     name varchar UNIQUE NULLS DISTINCT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_unique_nulls_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_unique_nulls_distinct_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_unique_nulls_distinct (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_unique_nulls_distinct_name_key UNIQUE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_unique_nulls_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_unique_nulls_distinct_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_unique_nulls_distinct (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_unique_nulls_distinct_name_key UNIQUE (name))     
 CREATE TABLE col_cstr_unique_nulls_not_distinct(
     id int NOT NULL,
     name varchar UNIQUE NULLS NOT DISTINCT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_unique_nulls_not_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_unique_nulls_not_distinct_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE NULLS NOT DISTINCT (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_unique_nulls_not_distinct (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_unique_nulls_not_distinct_name_key UNIQUE NULLS NOT DISTINCT (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_unique_nulls_not_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_unique_nulls_not_distinct_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE NULLS NOT DISTINCT (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_unique_nulls_not_distinct (id pg_catalog.int4 STORAGE PLAIN   NOT NULL   , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_unique_nulls_not_distinct_name_key UNIQUE NULLS NOT DISTINCT (name))     
 --  PRIMARY KEY |
 CREATE TABLE col_cstr_primary_key(
     id int PRIMARY KEY,
     name varchar UNIQUE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_primary_key", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_primary_key_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_primary_key_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_primary_key (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_primary_key_name_key UNIQUE (name), CONSTRAINT col_cstr_primary_key_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_primary_key", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_primary_key_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_primary_key_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_primary_key (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_primary_key_name_key UNIQUE (name), CONSTRAINT col_cstr_primary_key_pkey PRIMARY KEY (id))     
 --  REFERENCES reftable [ ( refcolumn ) ] [ MATCH FULL | MATCH PARTIAL | MATCH SIMPLE ]
 --    [ ON DELETE referential_action ] [ ON UPDATE referential_action ] }
 CREATE TABLE col_cstr_reference_table_default(
     id int REFERENCES col_cstr_primary_key,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_default_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id) REFERENCES public.col_cstr_primary_key(id)"}], "identity": {"objname": "col_cstr_reference_table_default", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_default ADD CONSTRAINT col_cstr_reference_table_default_id_fkey FOREIGN KEY (id) REFERENCES public.col_cstr_primary_key(id)
 CREATE TABLE col_cstr_reference_table_column(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)"}], "identity": {"objname": "col_cstr_reference_table_column", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column ADD CONSTRAINT col_cstr_reference_table_column_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)
 -- [ MATCH FULL | MATCH PARTIAL | MATCH SIMPLE ]
@@ -113,16 +113,16 @@ CREATE TABLE col_cstr_reference_table_column_match_full(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) MATCH FULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_match_full", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_match_full (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_match_full", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_match_full (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_match_full_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) MATCH FULL"}], "identity": {"objname": "col_cstr_reference_table_column_match_full", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_match_full ADD CONSTRAINT col_cstr_reference_table_column_match_full_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) MATCH FULL
 CREATE TABLE col_cstr_reference_table_column_match_simple(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) MATCH SIMPLE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_match_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_match_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_match_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_match_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_match_simple_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)"}], "identity": {"objname": "col_cstr_reference_table_column_match_simple", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_match_simple ADD CONSTRAINT col_cstr_reference_table_column_match_simple_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)
 -- [ ON DELETE referential_action ]
@@ -130,32 +130,32 @@ CREATE TABLE col_cstr_reference_table_column_on_delete_no_action(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE NO ACTION
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_no_action", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_no_action (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_no_action", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_no_action (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_no_action_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_no_action", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_no_action ADD CONSTRAINT col_cstr_reference_table_column_on_delete_no_action_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)
 CREATE TABLE col_cstr_reference_table_column_on_delete_restrict(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE RESTRICT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_restrict", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_restrict (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_restrict", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_restrict (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_restrict_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE RESTRICT"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_restrict", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_restrict ADD CONSTRAINT col_cstr_reference_table_column_on_delete_restrict_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE RESTRICT
 CREATE TABLE col_cstr_reference_table_column_on_delete_cascade(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE CASCADE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_cascade", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_cascade (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_cascade", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_cascade (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_cascade_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE CASCADE"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_cascade", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_cascade ADD CONSTRAINT col_cstr_reference_table_column_on_delete_cascade_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE CASCADE
 CREATE TABLE col_cstr_reference_table_column_on_delete_set_null(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE SET NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_set_null_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET NULL"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_null", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_set_null ADD CONSTRAINT col_cstr_reference_table_column_on_delete_set_null_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET NULL
 CREATE TABLE col_cstr_reference_table_column_on_delete_set_null_with_column(
@@ -163,24 +163,24 @@ CREATE TABLE col_cstr_reference_table_column_on_delete_set_null_with_column(
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE SET NULL (name),
     foo varchar REFERENCES col_cstr_primary_key (name) ON DELETE SET NULL (foo)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_null_with_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "foo", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_null_with_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , foo pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_null_with_column", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "foo", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_null_with_column (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , foo pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_set_null_wi_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET NULL (name)"}, {"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_set_null_wit_foo_fkey", "type": "add constraint", "definition": "FOREIGN KEY (foo) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET NULL (foo)"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_null_with_column", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_set_null_with_column ADD CONSTRAINT col_cstr_reference_table_column_on_delete_set_null_wi_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET NULL (name), ADD CONSTRAINT col_cstr_reference_table_column_on_delete_set_null_wit_foo_fkey FOREIGN KEY (foo) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET NULL (foo)
 CREATE TABLE col_cstr_reference_table_column_on_delete_set_default(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE SET DEFAULT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_set_default_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET DEFAULT"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_default", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_set_default ADD CONSTRAINT col_cstr_reference_table_column_on_delete_set_default_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET DEFAULT
 CREATE TABLE col_cstr_reference_table_column_on_delete_set_default_with_col(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON DELETE SET DEFAULT (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_default_with_col", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_default_with_col (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_default_with_col", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_delete_set_default_with_col (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_delete_set_defaul_name_fkey1", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET DEFAULT (name)"}], "identity": {"objname": "col_cstr_reference_table_column_on_delete_set_default_with_col", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_delete_set_default_with_col ADD CONSTRAINT col_cstr_reference_table_column_on_delete_set_defaul_name_fkey1 FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON DELETE SET DEFAULT (name)
 -- [ ON UPDATE referential_action ]
@@ -188,40 +188,40 @@ CREATE TABLE col_cstr_reference_table_column_on_update_no_action(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON UPDATE NO ACTION
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_no_action", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_no_action (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_no_action", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_no_action (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_update_no_action_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)"}], "identity": {"objname": "col_cstr_reference_table_column_on_update_no_action", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_update_no_action ADD CONSTRAINT col_cstr_reference_table_column_on_update_no_action_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name)
 CREATE TABLE col_cstr_reference_table_column_on_update_restrict(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON UPDATE RESTRICT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_restrict", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_restrict (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_restrict", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_restrict (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_update_restrict_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE RESTRICT"}], "identity": {"objname": "col_cstr_reference_table_column_on_update_restrict", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_update_restrict ADD CONSTRAINT col_cstr_reference_table_column_on_update_restrict_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE RESTRICT
 CREATE TABLE col_cstr_reference_table_column_on_update_cascade(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON UPDATE CASCADE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_cascade", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_cascade (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_cascade", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_cascade (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_update_cascade_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE CASCADE"}], "identity": {"objname": "col_cstr_reference_table_column_on_update_cascade", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_update_cascade ADD CONSTRAINT col_cstr_reference_table_column_on_update_cascade_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE CASCADE
 CREATE TABLE col_cstr_reference_table_column_on_update_set_null(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON UPDATE SET NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_set_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_set_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_set_null", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_set_null (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_update_set_null_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE SET NULL"}], "identity": {"objname": "col_cstr_reference_table_column_on_update_set_null", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_update_set_null ADD CONSTRAINT col_cstr_reference_table_column_on_update_set_null_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE SET NULL
 CREATE TABLE col_cstr_reference_table_column_on_update_set_default(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) ON UPDATE SET DEFAULT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_set_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_set_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_on_update_set_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_on_update_set_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_on_update_set_default_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE SET DEFAULT"}], "identity": {"objname": "col_cstr_reference_table_column_on_update_set_default", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_on_update_set_default ADD CONSTRAINT col_cstr_reference_table_column_on_update_set_default_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) ON UPDATE SET DEFAULT
 -- complex combinations
@@ -229,16 +229,16 @@ CREATE TABLE col_cstr_reference_table_column_complex_combination1(
     id int,
     name varchar REFERENCES col_cstr_primary_key (name) MATCH FULL ON DELETE NO ACTION ON UPDATE NO ACTION
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_complex_combination1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_complex_combination1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_complex_combination1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_complex_combination1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_complex_combination1_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) MATCH FULL"}], "identity": {"objname": "col_cstr_reference_table_column_complex_combination1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_complex_combination1 ADD CONSTRAINT col_cstr_reference_table_column_complex_combination1_name_fkey FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) MATCH FULL
 CREATE TABLE col_cstr_reference_table_column_complex_combination2(
     id int REFERENCES col_cstr_primary_key MATCH FULL ON DELETE SET DEFAULT ON UPDATE SET NULL,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_complex_combination2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_complex_combination2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_reference_table_column_complex_combination2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_reference_table_column_complex_combination2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_reference_table_column_complex_combination2_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id) REFERENCES public.col_cstr_primary_key(id) MATCH FULL ON UPDATE SET NULL ON DELETE SET DEFAULT"}], "identity": {"objname": "col_cstr_reference_table_column_complex_combination2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_reference_table_column_complex_combination2 ADD CONSTRAINT col_cstr_reference_table_column_complex_combination2_id_fkey FOREIGN KEY (id) REFERENCES public.col_cstr_primary_key(id) MATCH FULL ON UPDATE SET NULL ON DELETE SET DEFAULT
 -- [ DEFERRABLE | NOT DEFERRABLE ]
@@ -246,34 +246,34 @@ CREATE TABLE col_cstr_deferable(
     id int,
     name varchar UNIQUE DEFERRABLE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_deferable_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name) DEFERRABLE"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_deferable_name_key UNIQUE (name) DEFERRABLE)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_deferable_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name) DEFERRABLE"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_deferable_name_key UNIQUE (name) DEFERRABLE)     
 CREATE TABLE col_cstr_not_deferable(
     id int PRIMARY KEY NOT DEFERRABLE,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_not_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_not_deferable_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_not_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_not_deferable_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_not_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_not_deferable_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_not_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_not_deferable_pkey PRIMARY KEY (id))     
 -- [ INITIALLY DEFERRED | INITIALLY IMMEDIATE ]
 CREATE TABLE col_cstr_initially_deferred(
     id int PRIMARY KEY INITIALLY DEFERRED,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_initially_deferred", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_initially_deferred_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id) DEFERRABLE INITIALLY DEFERRED"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_initially_deferred (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_initially_deferred_pkey PRIMARY KEY (id) DEFERRABLE INITIALLY DEFERRED)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_initially_deferred", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_initially_deferred_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id) DEFERRABLE INITIALLY DEFERRED"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_initially_deferred (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_initially_deferred_pkey PRIMARY KEY (id) DEFERRABLE INITIALLY DEFERRED)     
 CREATE TABLE col_cstr_initially_immediate(
     id int,
     name varchar UNIQUE INITIALLY IMMEDIATE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_initially_immediate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_initially_immediate_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_initially_immediate (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_initially_immediate_name_key UNIQUE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_initially_immediate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "col_cstr_initially_immediate_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_initially_immediate (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT col_cstr_initially_immediate_name_key UNIQUE (name))     
 -- complex combination
 CREATE TABLE col_cstr_complex_combination(
     id int,
     name varchar CONSTRAINT name_constraint REFERENCES col_cstr_primary_key (name) MATCH FULL ON DELETE SET DEFAULT ON UPDATE SET NULL NOT DEFERRABLE INITIALLY IMMEDIATE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "col_cstr_complex_combination", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_complex_combination (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "col_cstr_complex_combination", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.col_cstr_complex_combination (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "name_constraint", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) MATCH FULL ON UPDATE SET NULL ON DELETE SET DEFAULT"}], "identity": {"objname": "col_cstr_complex_combination", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.col_cstr_complex_combination ADD CONSTRAINT name_constraint FOREIGN KEY (name) REFERENCES public.col_cstr_primary_key(name) MATCH FULL ON UPDATE SET NULL ON DELETE SET DEFAULT
 -- part 4: table constraints
@@ -284,180 +284,180 @@ CREATE TABLE tbl_cstr_check_1(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_check_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "id_constraint", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_check_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT id_constraint CHECK ((id OPERATOR(pg_catalog.>) 10)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_check_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "id_constraint", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_check_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT id_constraint CHECK ((id OPERATOR(pg_catalog.>) 10)))     
 CREATE TABLE tbl_cstr_check_2(
     id int,
     name varchar,
     CONSTRAINT table_check CHECK (id > 10) NO INHERIT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_check_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "table_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_check_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT table_check CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_check_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "table_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_check_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT table_check CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT)     
 CREATE TABLE tbl_cstr_check_no_inherit(
     id int,
     name varchar,
     CHECK (id > 10) NO INHERIT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_check_no_inherit", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_check_no_inherit_id_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_check_no_inherit (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_check_no_inherit_id_check CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_check_no_inherit", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_check_no_inherit_id_check", "type": "constraint", "contype": "check", "definition": "CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_check_no_inherit (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_check_no_inherit_id_check CHECK ((id OPERATOR(pg_catalog.>) 10)) NO INHERIT)     
 --   UNIQUE [ NULLS [ NOT ] DISTINCT ] ( column_name [, ... ] ) [ INCLUDE ( column_name [, ...]) ] |
 CREATE TABLE tbl_cstr_unique(
     id int,
     name varchar,
     UNIQUE (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_id_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_id_key UNIQUE (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_id_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_id_key UNIQUE (id))     
 CREATE TABLE tbl_cstr_unique_multicols(
     id int,
     name varchar,
     UNIQUE (id, name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_multicols", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_multicols_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_multicols (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_multicols_id_name_key UNIQUE (id, name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_multicols", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_multicols_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_multicols (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_multicols_id_name_key UNIQUE (id, name))     
 CREATE TABLE tbl_cstr_unique_nulls_distinct(
     id int,
     name varchar,
     UNIQUE NULLS DISTINCT (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_distinct_id_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_distinct (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_distinct_id_key UNIQUE (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_distinct_id_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_distinct (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_distinct_id_key UNIQUE (id))     
 CREATE TABLE tbl_cstr_unique_nulls_not_distinct(
     id int,
     name varchar,
     UNIQUE NULLS NOT DISTINCT (id, name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_not_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_not_distinct_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE NULLS NOT DISTINCT (id, name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_not_distinct (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_not_distinct_id_name_key UNIQUE NULLS NOT DISTINCT (id, name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_not_distinct", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_not_distinct_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE NULLS NOT DISTINCT (id, name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_not_distinct (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_not_distinct_id_name_key UNIQUE NULLS NOT DISTINCT (id, name))     
 CREATE TABLE tbl_cstr_unique_nulls_distinct_include(
     id int,
     name varchar,
     UNIQUE NULLS DISTINCT (id) INCLUDE (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_distinct_include", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_distinct_include_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id) INCLUDE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_distinct_include (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_distinct_include_id_name_key UNIQUE (id) INCLUDE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_distinct_include", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_distinct_include_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id) INCLUDE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_distinct_include (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_distinct_include_id_name_key UNIQUE (id) INCLUDE (name))     
 CREATE TABLE tbl_cstr_unique_nulls_distinct_include_multi(
     id int,
     name varchar,
     info varchar,
     UNIQUE NULLS DISTINCT (id) INCLUDE (name, info)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_distinct_include_multi", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "info", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_distinct_include_multi_id_name_info_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id) INCLUDE (name, info)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_distinct_include_multi (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , info pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_distinct_include_multi_id_name_info_key UNIQUE (id) INCLUDE (name, info))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_unique_nulls_distinct_include_multi", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "info", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_unique_nulls_distinct_include_multi_id_name_info_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id) INCLUDE (name, info)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_unique_nulls_distinct_include_multi (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , info pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_unique_nulls_distinct_include_multi_id_name_info_key UNIQUE (id) INCLUDE (name, info))     
 -- PRIMARY KEY ( column_name [, ... ] ) [ INCLUDE ( column_name [, ...]) ] |
 CREATE TABLE tbl_cstr_primary_key(
     id int,
     name varchar,
     PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_pkey PRIMARY KEY (id))     
 CREATE TABLE tbl_cstr_primary_key_multicols(
     id int,
     name varchar,
     PRIMARY KEY (id, name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key_multicols", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_multicols_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id, name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key_multicols (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_multicols_pkey PRIMARY KEY (id, name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key_multicols", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_multicols_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id, name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key_multicols (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_multicols_pkey PRIMARY KEY (id, name))     
 CREATE TABLE tbl_cstr_primary_key_include(
     id int,
     name varchar,
     PRIMARY KEY (id) INCLUDE (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key_include", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_include_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id) INCLUDE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key_include (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_include_pkey PRIMARY KEY (id) INCLUDE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key_include", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_include_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id) INCLUDE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key_include (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_include_pkey PRIMARY KEY (id) INCLUDE (name))     
 CREATE TABLE tbl_cstr_primary_key_include_multicols(
     id int,
     name varchar,
     info varchar,
     PRIMARY KEY (id) INCLUDE (name, info)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key_include_multicols", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "info", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_include_multicols_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id) INCLUDE (name, info)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key_include_multicols (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , info pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_include_multicols_pkey PRIMARY KEY (id) INCLUDE (name, info))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_primary_key_include_multicols", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "info", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_primary_key_include_multicols_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id) INCLUDE (name, info)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_primary_key_include_multicols (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , info pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_primary_key_include_multicols_pkey PRIMARY KEY (id) INCLUDE (name, info))     
 --   EXCLUDE [ USING index_method ] ( exclude_element WITH operator [, ... ] ) index_parameters [ WHERE ( predicate ) ] |
 CREATE TABLE tbl_cstr_exclude(
     id int,
     name varchar,
     EXCLUDE (name WITH =)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (name WITH OPERATOR(pg_catalog.=))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_name_excl EXCLUDE USING btree (name WITH OPERATOR(pg_catalog.=)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (name WITH OPERATOR(pg_catalog.=))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_name_excl EXCLUDE USING btree (name WITH OPERATOR(pg_catalog.=)))     
 CREATE TABLE tbl_cstr_exclude_multi(
     id int,
     name varchar,
     EXCLUDE ((id*10) with =, name WITH =)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_multi", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_multi_expr_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_multi (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_multi_expr_name_excl EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_multi", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_multi_expr_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_multi (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_multi_expr_name_excl EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)))     
 CREATE TABLE tbl_cstr_exclude_index_method(
     id int,
     name varchar,
     EXCLUDE USING btree ((id*10) with =, name WITH =)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_index_method", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_index_method_expr_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_index_method (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_index_method_expr_name_excl EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_index_method", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_index_method_expr_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_index_method (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_index_method_expr_name_excl EXCLUDE USING btree (((id OPERATOR(pg_catalog.*) 10)) WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)))     
 -- [ INCLUDE ( column_name [, ... ] ) ]
 CREATE TABLE tbl_cstr_exclude_with_index_params_include_1(
     id int,
     name varchar,
     EXCLUDE (id WITH =) INCLUDE (name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_include_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_include_1_id_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_include_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_include_1_id_name_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_include_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_include_1_id_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_include_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_include_1_id_name_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (name))     
 CREATE TABLE tbl_cstr_exclude_with_index_params_include_2(
     id int,
     name varchar,
     EXCLUDE (id WITH =) INCLUDE (id, name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_include_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_include_2_id_id1_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_include_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_include_2_id_id1_name_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_include_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_include_2_id_id1_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_include_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_include_2_id_id1_name_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name))     
 -- [ WITH ( storage_parameter [= value] [, ... ] ) ]
 CREATE TABLE tbl_cstr_exclude_with_index_params_storage_1(
     id int,
     name varchar,
     EXCLUDE (id WITH =) WITH (fillfactor = 20)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_storage_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_storage_1_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20')"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_storage_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_storage_1_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20'))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_storage_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_storage_1_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20')"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_storage_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_storage_1_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20'))     
 CREATE TABLE tbl_cstr_exclude_with_index_params_storage_2(
     id int,
     name varchar,
     EXCLUDE (id WITH =) WITH (fillfactor = 20, deduplicate_items = false)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_storage_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_storage_2_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20', deduplicate_items='false')"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_storage_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_storage_2_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20', deduplicate_items='false'))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_storage_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_storage_2_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20', deduplicate_items='false')"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_storage_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_storage_2_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WITH (fillfactor='20', deduplicate_items='false'))     
 -- [ USING INDEX TABLESPACE tablespace_name ]
 CREATE TABLE tbl_cstr_exclude_with_index_params_tablespace(
     id int,
     name varchar,
     EXCLUDE (id WITH =) USING INDEX TABLESPACE pg_default
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_tablespace", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_tablespace_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_tablespace (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_tablespace_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_tablespace", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_tablespace_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_tablespace (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_tablespace_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)))     
 -- index_parameters complex combination
 CREATE TABLE tbl_cstr_exclude_with_index_params_complex(
     id int,
     name varchar,
     EXCLUDE (id WITH =) INCLUDE (id, name) WITH (fillfactor = 20, deduplicate_items = false) USING INDEX TABLESPACE pg_default
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_complex", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_complex_id_id1_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false')"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_complex (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_complex_id_id1_name_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false'))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_index_params_complex", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_index_params_complex_id_id1_name_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false')"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_index_params_complex (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_index_params_complex_id_id1_name_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false'))     
 -- [ WHERE ( predicate ) ]
 CREATE TABLE tbl_cstr_exclude_with_predicate(
     id int,
     name varchar,
     EXCLUDE (id WITH =) WHERE (name<>'foo')
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_predicate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_predicate_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_predicate (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_predicate_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_with_predicate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_with_predicate_id_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_with_predicate (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_with_predicate_id_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=)) WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text)))     
 -- complex combination for table constraint clauses
 CREATE TABLE tbl_cstr_exclude_complex_combination(
     id int,
     name varchar,
     EXCLUDE USING btree (id WITH =, name WITH =) INCLUDE (id, name) WITH (fillfactor = 20, deduplicate_items = false) USING INDEX TABLESPACE pg_default WHERE (name<>'foo')
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_complex_combination", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_complex_combination_id_name_id1_name1_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false') WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text))"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_complex_combination (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_complex_combination_id_name_id1_name1_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false') WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text)))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_exclude_complex_combination", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_exclude_complex_combination_id_name_id1_name1_excl", "type": "constraint", "contype": "exclusion", "definition": "EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false') WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text))"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_exclude_complex_combination (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_exclude_complex_combination_id_name_id1_name1_excl EXCLUDE USING btree (id WITH OPERATOR(pg_catalog.=), name WITH OPERATOR(pg_catalog.=)) INCLUDE (id, name) WITH (fillfactor='20', deduplicate_items='false') WHERE (((name)::pg_catalog.text OPERATOR(pg_catalog.<>) 'foo'::pg_catalog.text)))     
 -- FOREIGN KEY ( column_name [, ... ] ) REFERENCES reftable [ ( refcolumn [, ... ] ) ]
 --     [ MATCH FULL | MATCH PARTIAL | MATCH SIMPLE ] [ ON DELETE referential_action ] [ ON UPDATE referential_action ] }
 CREATE TABLE tbl_cstr_foreign_table(
@@ -465,15 +465,15 @@ CREATE TABLE tbl_cstr_foreign_table(
     name varchar UNIQUE,
     UNIQUE (id, name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_table_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_table_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_table_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_foreign_table_id_name_key UNIQUE (id, name), CONSTRAINT tbl_cstr_foreign_table_name_key UNIQUE (name), CONSTRAINT tbl_cstr_foreign_table_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_table_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_table_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_table_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_foreign_table_id_name_key UNIQUE (id, name), CONSTRAINT tbl_cstr_foreign_table_name_key UNIQUE (name), CONSTRAINT tbl_cstr_foreign_table_pkey PRIMARY KEY (id))     
 CREATE TABLE tbl_cstr_foreign_key_simple_1(
     id int,
     name varchar,
     FOREIGN KEY (id) REFERENCES tbl_cstr_foreign_table
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_key_simple_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_key_simple_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_key_simple_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_key_simple_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_key_simple_1_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id) REFERENCES public.tbl_cstr_foreign_table(id)"}], "identity": {"objname": "tbl_cstr_foreign_key_simple_1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.tbl_cstr_foreign_key_simple_1 ADD CONSTRAINT tbl_cstr_foreign_key_simple_1_id_fkey FOREIGN KEY (id) REFERENCES public.tbl_cstr_foreign_table(id)
 CREATE TABLE tbl_cstr_foreign_key_simple_2(
@@ -481,8 +481,8 @@ CREATE TABLE tbl_cstr_foreign_key_simple_2(
     name varchar,
     FOREIGN KEY (id) REFERENCES tbl_cstr_foreign_table(id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_key_simple_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_key_simple_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_key_simple_2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_key_simple_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_key_simple_2_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id) REFERENCES public.tbl_cstr_foreign_table(id)"}], "identity": {"objname": "tbl_cstr_foreign_key_simple_2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.tbl_cstr_foreign_key_simple_2 ADD CONSTRAINT tbl_cstr_foreign_key_simple_2_id_fkey FOREIGN KEY (id) REFERENCES public.tbl_cstr_foreign_table(id)
 CREATE TABLE tbl_cstr_foreign_key_multiple_keys(
@@ -490,8 +490,8 @@ CREATE TABLE tbl_cstr_foreign_key_multiple_keys(
     name varchar,
     FOREIGN KEY (id, name) REFERENCES tbl_cstr_foreign_table (id, name)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_key_multiple_keys", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_key_multiple_keys (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_foreign_key_multiple_keys", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_foreign_key_multiple_keys (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_foreign_key_multiple_keys_id_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (id, name) REFERENCES public.tbl_cstr_foreign_table(id, name)"}], "identity": {"objname": "tbl_cstr_foreign_key_multiple_keys", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.tbl_cstr_foreign_key_multiple_keys ADD CONSTRAINT tbl_cstr_foreign_key_multiple_keys_id_name_fkey FOREIGN KEY (id, name) REFERENCES public.tbl_cstr_foreign_table(id, name)
 -- some combinations from REFERENCES clause, which is already tested in part 3
@@ -500,8 +500,8 @@ CREATE TABLE tbl_cstr_reference_table_complex_combination1(
     name varchar,
     FOREIGN KEY (name) REFERENCES tbl_cstr_foreign_table (name) MATCH SIMPLE ON DELETE CASCADE ON UPDATE SET NULL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_complex_combination1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_complex_combination1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_complex_combination1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_complex_combination1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_complex_combination1_name_fkey", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.tbl_cstr_foreign_table(name) ON UPDATE SET NULL ON DELETE CASCADE"}], "identity": {"objname": "tbl_cstr_reference_table_complex_combination1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.tbl_cstr_reference_table_complex_combination1 ADD CONSTRAINT tbl_cstr_reference_table_complex_combination1_name_fkey FOREIGN KEY (name) REFERENCES public.tbl_cstr_foreign_table(name) ON UPDATE SET NULL ON DELETE CASCADE
 CREATE TABLE tbl_cstr_reference_table_complex_combination2(
@@ -509,8 +509,8 @@ CREATE TABLE tbl_cstr_reference_table_complex_combination2(
     name varchar,
     CONSTRAINT tbl_cstr FOREIGN KEY (id, name) REFERENCES tbl_cstr_foreign_table (id, name) ON DELETE SET NULL (id, name) ON UPDATE SET DEFAULT
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_complex_combination2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_complex_combination2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_complex_combination2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_complex_combination2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr", "type": "add constraint", "definition": "FOREIGN KEY (id, name) REFERENCES public.tbl_cstr_foreign_table(id, name) ON UPDATE SET DEFAULT ON DELETE SET NULL (id, name)"}], "identity": {"objname": "tbl_cstr_reference_table_complex_combination2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.tbl_cstr_reference_table_complex_combination2 ADD CONSTRAINT tbl_cstr FOREIGN KEY (id, name) REFERENCES public.tbl_cstr_foreign_table(id, name) ON UPDATE SET DEFAULT ON DELETE SET NULL (id, name)
 -- [ DEFERRABLE | NOT DEFERRABLE ]
@@ -519,38 +519,38 @@ CREATE TABLE tbl_cstr_reference_table_column_deferable(
     name varchar,
     UNIQUE (id, name) DEFERRABLE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_deferable_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name) DEFERRABLE"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_deferable_id_name_key UNIQUE (id, name) DEFERRABLE)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_deferable_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name) DEFERRABLE"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_deferable_id_name_key UNIQUE (id, name) DEFERRABLE)     
 CREATE TABLE tbl_cstr_reference_table_column_not_deferable(
     id int,
     name varchar,
     PRIMARY KEY (id) NOT DEFERRABLE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_not_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_not_deferable_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_not_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_not_deferable_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_not_deferable", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_not_deferable_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_not_deferable (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_not_deferable_pkey PRIMARY KEY (id))     
 -- [ INITIALLY DEFERRED | INITIALLY IMMEDIATE ]
 CREATE TABLE tbl_cstr_reference_table_column_initially_deferred(
     id int,
     name varchar,
     UNIQUE (id, name) INITIALLY DEFERRED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_initially_deferred", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_initially_deferred_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name) DEFERRABLE INITIALLY DEFERRED"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_initially_deferred (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_initially_deferred_id_name_key UNIQUE (id, name) DEFERRABLE INITIALLY DEFERRED)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_initially_deferred", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_initially_deferred_id_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (id, name) DEFERRABLE INITIALLY DEFERRED"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_initially_deferred (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_initially_deferred_id_name_key UNIQUE (id, name) DEFERRABLE INITIALLY DEFERRED)     
 CREATE TABLE tbl_cstr_reference_table_column_initially_immediate(
     id int,
     name varchar,
     PRIMARY KEY (id) INITIALLY IMMEDIATE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_initially_immediate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_initially_immediate_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_initially_immediate (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_initially_immediate_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_initially_immediate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr_reference_table_column_initially_immediate_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_initially_immediate (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr_reference_table_column_initially_immediate_pkey PRIMARY KEY (id))     
 -- complex combinations
 CREATE TABLE tbl_cstr_reference_table_column_complex_combination1(
     id int,
     name varchar,
     CONSTRAINT tbl_cstr FOREIGN KEY (name) REFERENCES tbl_cstr_foreign_table (name) MATCH FULL ON DELETE NO ACTION ON UPDATE NO ACTION DEFERRABLE INITIALLY DEFERRED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_complex_combination1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_complex_combination1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_complex_combination1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_complex_combination1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr", "type": "add constraint", "definition": "FOREIGN KEY (name) REFERENCES public.tbl_cstr_foreign_table(name) MATCH FULL DEFERRABLE INITIALLY DEFERRED"}], "identity": {"objname": "tbl_cstr_reference_table_column_complex_combination1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.tbl_cstr_reference_table_column_complex_combination1 ADD CONSTRAINT tbl_cstr FOREIGN KEY (name) REFERENCES public.tbl_cstr_foreign_table(name) MATCH FULL DEFERRABLE INITIALLY DEFERRED
 CREATE TABLE tbl_cstr_reference_table_column_complex_combination2(
@@ -558,5 +558,5 @@ CREATE TABLE tbl_cstr_reference_table_column_complex_combination2(
     name varchar,
     CONSTRAINT tbl_cstr PRIMARY KEY (id, name) NOT DEFERRABLE INITIALLY IMMEDIATE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_complex_combination2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id, name)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_complex_combination2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr PRIMARY KEY (id, name))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "tbl_cstr_reference_table_column_complex_combination2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "tbl_cstr", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id, name)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.tbl_cstr_reference_table_column_complex_combination2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT tbl_cstr PRIMARY KEY (id, name))     
diff --git a/src/test/modules/test_ddl_deparse_regress/expected/create_index.out b/src/test/modules/test_ddl_deparse_regress/expected/create_index.out
index 490cac9662..f790f92544 100644
--- a/src/test/modules/test_ddl_deparse_regress/expected/create_index.out
+++ b/src/test/modules/test_ddl_deparse_regress/expected/create_index.out
@@ -11,8 +11,8 @@ CREATE TABLE test_add_constraint_using_index(
     id6 int,
     id7 int
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_add_constraint_using_index", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id6", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id7", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_add_constraint_using_index (id1 pg_catalog.int4 STORAGE PLAIN      , id2 pg_catalog.int4 STORAGE PLAIN      , id3 pg_catalog.int4 STORAGE PLAIN      , id4 pg_catalog.int4 STORAGE PLAIN      , id5 pg_catalog.int4 STORAGE PLAIN      , id6 pg_catalog.int4 STORAGE PLAIN      , id7 pg_catalog.int4 STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_add_constraint_using_index", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id3", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id4", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id6", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id7", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_add_constraint_using_index (id1 pg_catalog.int4 STORAGE PLAIN      , id2 pg_catalog.int4 STORAGE PLAIN      , id3 pg_catalog.int4 STORAGE PLAIN      , id4 pg_catalog.int4 STORAGE PLAIN      , id5 pg_catalog.int4 STORAGE PLAIN      , id6 pg_catalog.int4 STORAGE PLAIN      , id7 pg_catalog.int4 STORAGE PLAIN      )     
 CREATE UNIQUE INDEX test_add_constraint_used_index1 ON test_add_constraint_using_index (id1);
 CREATE UNIQUE INDEX test_add_constraint_used_index2 ON test_add_constraint_using_index (id2);
 CREATE UNIQUE INDEX test_add_constraint_used_index3 ON test_add_constraint_using_index (id3);
diff --git a/src/test/modules/test_ddl_deparse_regress/expected/create_rule.out b/src/test/modules/test_ddl_deparse_regress/expected/create_rule.out
index 14c5664292..96d595b7c6 100644
--- a/src/test/modules/test_ddl_deparse_regress/expected/create_rule.out
+++ b/src/test/modules/test_ddl_deparse_regress/expected/create_rule.out
@@ -10,8 +10,8 @@ CREATE TABLE test_disable_rule(
     quantity int,
     purchase_date date
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_disable_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_disable_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_disable_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_disable_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 CREATE RULE sample_rule1 AS
     ON UPDATE TO test_disable_rule
     DO INSTEAD
@@ -20,8 +20,8 @@ CREATE RULE sample_rule1 AS
 CREATE TABLE test_enable_rule(
     LIKE test_disable_rule
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_enable_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_enable_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 CREATE RULE sample_rule2 AS
     ON UPDATE TO test_enable_rule
     DO INSTEAD
@@ -30,8 +30,8 @@ CREATE RULE sample_rule2 AS
 CREATE TABLE test_enable_replica_rule(
     LIKE test_disable_rule
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_enable_replica_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_replica_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_enable_replica_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_replica_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 CREATE RULE sample_rule_enable_replica AS
     ON UPDATE TO test_enable_replica_rule
     DO INSTEAD
@@ -40,8 +40,8 @@ CREATE RULE sample_rule_enable_replica AS
 CREATE TABLE test_enable_always_rule(
     LIKE test_disable_rule
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_enable_always_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_always_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_enable_always_rule", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "description", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "price", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "quantity", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "purchase_date", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_enable_always_rule (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , description pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , price pg_catalog.float4 STORAGE PLAIN      , quantity pg_catalog.int4 STORAGE PLAIN      , purchase_date pg_catalog.date STORAGE PLAIN      )     
 CREATE RULE sample_rule_enable_always AS
     ON UPDATE TO test_enable_always_rule
     DO INSTEAD
diff --git a/src/test/modules/test_ddl_deparse_regress/expected/create_table.out b/src/test/modules/test_ddl_deparse_regress/expected/create_table.out
index 567dcf9c38..688b22dc0b 100644
--- a/src/test/modules/test_ddl_deparse_regress/expected/create_table.out
+++ b/src/test/modules/test_ddl_deparse_regress/expected/create_table.out
@@ -4,20 +4,20 @@ CREATE TABLE part1_simple_table(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_simple_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part1_simple_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_simple_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part1_simple_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TEMPORARY TABLE part1_temp_table0(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_temp_table0", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_temp_table0 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_temp_table0", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_temp_table0 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TEMP TABLE part1_temp_table(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_temp_table", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_temp_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_temp_table", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_temp_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 -- GLOBAL TEMP TATBLE is deprecated, expect warning message and create local temp table
 CREATE GLOBAL TEMP TABLE part1_global_temp_table(
     id int,
@@ -26,20 +26,20 @@ CREATE GLOBAL TEMP TABLE part1_global_temp_table(
 WARNING:  GLOBAL is deprecated in temporary table creation
 LINE 1: CREATE GLOBAL TEMP TABLE part1_global_temp_table(
                ^
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_global_temp_table", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_global_temp_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_global_temp_table", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_global_temp_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE LOCAL TEMP TABLE part1_local_temp_table(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_local_temp_table", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_local_temp_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_local_temp_table", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part1_local_temp_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE UNLOGGED TABLE part1_unlogged_table(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_unlogged_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "UNLOGGED", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE UNLOGGED TABLE  public.part1_unlogged_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_unlogged_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "UNLOGGED", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE UNLOGGED TABLE  public.part1_unlogged_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 -- [ IF NOT EXISTS ]
 CREATE TABLE IF NOT EXISTS part1_simple_table(
     id int,
@@ -50,291 +50,291 @@ CREATE TABLE IF NOT EXISTS part1_local_temp_table_not_exists(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part1_local_temp_table_not_exists", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "IF NOT EXISTS", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE IF NOT EXISTS public.part1_local_temp_table_not_exists (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part1_local_temp_table_not_exists", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "IF NOT EXISTS", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE IF NOT EXISTS public.part1_local_temp_table_not_exists (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 -- part 2: shared suffixes
 -- [ PARTITION BY { RANGE | LIST | HASH } ( { column_name | ( expression ) } [ COLLATE collation ] [ opclass ] [, ... ] ) ]
 CREATE TABLE part2_partition_by_range_simple(
     id int,
     name varchar
 ) PARTITION BY RANGE (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_by_range_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_by_range_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_by_range_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_by_range_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (id)   
 CREATE TABLE part2_partition_by_list_simple(
     id int,
     name varchar
 ) PARTITION BY LIST (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_by_list_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_by_list_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY LIST (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_by_list_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_by_list_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY LIST (id)   
 CREATE TABLE part2_partition_by_hash_simple(
     id int,
     name varchar
 ) PARTITION BY HASH (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_by_hash_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_by_hash_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY HASH (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_by_hash_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_by_hash_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY HASH (id)   
 CREATE TABLE part2_partition_with_expression(
     id int,
     name varchar
 ) PARTITION BY RANGE ((id * 190), name);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_with_expression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (((id OPERATOR(pg_catalog.*) 190)), name)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_expression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (((id OPERATOR(pg_catalog.*) 190)), name)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_with_expression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (((id OPERATOR(pg_catalog.*) 190)), name)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_expression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (((id OPERATOR(pg_catalog.*) 190)), name)   
 CREATE TABLE part2_partition_with_collation(
     id int,
     name varchar
 ) PARTITION BY LIST (name COLLATE "C");
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_with_collation", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (name COLLATE pg_catalog.\"C\")"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_collation (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY LIST (name COLLATE pg_catalog."C")    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_with_collation", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (name COLLATE pg_catalog.\"C\")"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_collation (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY LIST (name COLLATE pg_catalog."C")   
 CREATE TABLE part2_partition_with_opclass(
     id int,
     name varchar
 ) PARTITION BY HASH (id int4_ops, name varchar_ops);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_with_opclass", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id, name pg_catalog.varchar_ops)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_opclass (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY HASH (id, name pg_catalog.varchar_ops)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_with_opclass", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id, name pg_catalog.varchar_ops)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_opclass (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY HASH (id, name pg_catalog.varchar_ops)   
 CREATE TABLE part2_partition_with_collation_opclass(
     id int,
     name varchar
 ) PARTITION BY RANGE ((id * 10) int4_ops, name COLLATE "C" varchar_ops);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_partition_with_collation_opclass", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (((id OPERATOR(pg_catalog.*) 10)), name COLLATE pg_catalog.\"C\" pg_catalog.varchar_ops)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_collation_opclass (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (((id OPERATOR(pg_catalog.*) 10)), name COLLATE pg_catalog."C" pg_catalog.varchar_ops)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_partition_with_collation_opclass", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (((id OPERATOR(pg_catalog.*) 10)), name COLLATE pg_catalog.\"C\" pg_catalog.varchar_ops)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_partition_with_collation_opclass (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (((id OPERATOR(pg_catalog.*) 10)), name COLLATE pg_catalog."C" pg_catalog.varchar_ops)   
 -- [ USING method ]
 -- default method
 CREATE TABLE part2_using_default_access_method(
     id int,
     name varchar
 ) USING heap;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_using_default_access_method", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_using_default_access_method (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )   USING heap   
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_using_default_access_method", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_using_default_access_method (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )   USING heap  
 -- [ WITH ( storage_parameter [= value] [, ... ] ) | WITHOUT OIDS ]
 CREATE TABLE part2_without_oids(
     id int,
     name varchar
 ) WITHOUT OIDS;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_without_oids", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_without_oids (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_without_oids", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_without_oids (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part2_with_one_storage_param(
     id int,
     name varchar
 ) WITH (fillfactor = 20);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_with_one_storage_param", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "fillfactor"}, "value": "20"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_with_one_storage_param (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )    WITH (fillfactor = '20')  
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_with_one_storage_param", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "fillfactor"}, "value": "20"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_with_one_storage_param (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )    WITH (fillfactor = '20') 
 CREATE TABLE part2_with_multiple_storage_params(
     id int,
     name varchar
 ) WITH (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_with_multiple_storage_params", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_with_multiple_storage_params (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )    WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true')  
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_with_multiple_storage_params", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_with_multiple_storage_params (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )    WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') 
 -- [ ON COMMIT { PRESERVE ROWS | DELETE ROWS | DROP } ]
 CREATE TEMP TABLE part2_on_commit_preserve_rows(
     id int,
     name varchar
 ) ON COMMIT PRESERVE ROWS;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_on_commit_preserve_rows", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "on_commit_value": "PRESERVE ROWS"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_on_commit_preserve_rows (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     ON COMMIT PRESERVE ROWS 
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_on_commit_preserve_rows", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_on_commit_preserve_rows (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TEMP TABLE part2_on_commit_delete_rows(
     id int,
     name varchar
 ) ON COMMIT DELETE ROWS;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_on_commit_delete_rows", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "on_commit_value": "DELETE ROWS"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_on_commit_delete_rows (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     ON COMMIT DELETE ROWS 
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_on_commit_delete_rows", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_on_commit_delete_rows (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TEMPORARY TABLE part2_on_commit_drop(
     id int,
     name varchar
 ) ON COMMIT DROP;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_on_commit_drop", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "on_commit_value": "DROP"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_on_commit_drop (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     ON COMMIT DROP 
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_on_commit_drop", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_on_commit_drop (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 -- [ TABLESPACE tablespace_name ]
 CREATE TABLE part2_tablespace_pg_default(
     id int,
     name varchar
 ) TABLESPACE pg_default;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_tablespace_pg_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_tablespace_pg_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      TABLESPACE pg_default
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_tablespace_pg_default", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_tablespace_pg_default (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     TABLESPACE pg_default
 -- some complex combinations from the components above
 CREATE TEMPORARY TABLE part2_combination_1(
     id int,
     name varchar
 ) PARTITION BY RANGE (id) ON COMMIT PRESERVE ROWS;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_combination_1", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "on_commit_value": "PRESERVE ROWS"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_combination_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (id)   ON COMMIT PRESERVE ROWS 
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_combination_1", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_combination_1 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (id)   
 CREATE LOCAL TEMP TABLE part2_combination_2(
     id int,
     name varchar
 ) USING heap WITH (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true) ON COMMIT PRESERVE ROWS TABLESPACE pg_default;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_combination_2", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "on_commit_value": "PRESERVE ROWS"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_combination_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )   USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') ON COMMIT PRESERVE ROWS TABLESPACE pg_default
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_combination_2", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part2_combination_2 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )   USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') TABLESPACE pg_default
 CREATE TABLE part2_combination_3(
     id int,
     name varchar
 ) USING heap WITH (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true) TABLESPACE pg_default;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part2_combination_3", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part2_combination_3 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )   USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true')  TABLESPACE pg_default
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part2_combination_3", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part2_combination_3 (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )   USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') TABLESPACE pg_default
 -- part 5: LIKE source_table [ like_option ... ]
 CREATE TABLE part5_source_table(
     id int,
     name varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_source_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_source_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_source_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_source_table (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_source_table2(
     id2 int,
     name2 varchar
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_source_table2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_source_table2 (id2 pg_catalog.int4 STORAGE PLAIN      , name2 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_source_table2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_source_table2 (id2 pg_catalog.int4 STORAGE PLAIN      , name2 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_like_simple(
     LIKE part5_source_table
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_like_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_like_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_like_simple", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_like_simple (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 -- { INCLUDING | EXCLUDING } { COMMENTS | COMPRESSION | CONSTRAINTS | DEFAULTS | GENERATED | IDENTITY | INDEXES | STATISTICS | STORAGE | ALL }
 CREATE TABLE part5_including_all(
     LIKE part5_source_table INCLUDING ALL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_all", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_all (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_all", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_all (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_comments(
     LIKE part5_source_table INCLUDING COMMENTS
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_comments", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_comments (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_comments", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_comments (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_compression(
     LIKE part5_source_table INCLUDING COMPRESSION
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_compression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_compression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_compression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_compression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_defaults(
     LIKE part5_source_table INCLUDING DEFAULTS
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_defaults", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_defaults (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_defaults", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_defaults (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_generated(
     LIKE part5_source_table INCLUDING GENERATED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_generated (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_generated (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_identity(
     LIKE part5_source_table INCLUDING IDENTITY
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_identity (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_identity (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_indexes(
     LIKE part5_source_table INCLUDING INDEXES
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_indexes", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_indexes (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_indexes", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_indexes (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_statistics(
     LIKE part5_source_table INCLUDING STATISTICS
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_statistics", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_statistics (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_statistics", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_statistics (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_including_storage(
     LIKE part5_source_table INCLUDING STORAGE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_including_storage", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_storage (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_including_storage", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_including_storage (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_all(
     LIKE part5_source_table EXCLUDING ALL
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_all", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_all (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_all", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_all (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_comments(
     LIKE part5_source_table EXCLUDING COMMENTS
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_comments", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_comments (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_comments", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_comments (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_compression(
     LIKE part5_source_table EXCLUDING COMPRESSION
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_compression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_compression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_compression", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_compression (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_defaults(
     LIKE part5_source_table EXCLUDING DEFAULTS
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_defaults", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_defaults (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_defaults", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_defaults (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_generated(
     LIKE part5_source_table EXCLUDING GENERATED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_generated (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_generated", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_generated (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_identity(
     LIKE part5_source_table EXCLUDING IDENTITY
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_identity (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_identity", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_identity (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_indexes(
     LIKE part5_source_table EXCLUDING INDEXES
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_indexes", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_indexes (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_indexes", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_indexes (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_statistics(
     LIKE part5_source_table EXCLUDING STATISTICS
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_statistics", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_statistics (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_statistics", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_statistics (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_excluding_storage(
     LIKE part5_source_table EXCLUDING STORAGE
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_excluding_storage", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_storage (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_excluding_storage", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_excluding_storage (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )     
 CREATE TABLE part5_like_list(
     LIKE part5_source_table,
     info text,
     LIKE part5_source_table2 INCLUDING ALL,
     CONSTRAINT primary_key_constraint PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part5_like_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "info", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "primary_key_constraint", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part5_like_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , info pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , id2 pg_catalog.int4 STORAGE PLAIN      , name2 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT primary_key_constraint PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part5_like_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "info", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "primary_key_constraint", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part5_like_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , info pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , id2 pg_catalog.int4 STORAGE PLAIN      , name2 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT primary_key_constraint PRIMARY KEY (id))     
 -- part 6: partition specification
 -- PARTITION OF parent_table { FOR VALUES partition_bound_spec | DEFAULT }
 CREATE TABLE part6_parent_table_range(
     id int,
     name varchar
 ) PARTITION BY RANGE (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_parent_table_range (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_parent_table_range (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY RANGE (id)   
 CREATE TABLE part6_parent_table_list(
     id int,
     name varchar
 ) PARTITION BY LIST (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_parent_table_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_parent_table_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY LIST (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_parent_table_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_parent_table_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY LIST (id)   
 CREATE TABLE part6_parent_table_hash(
     id int,
     name varchar
 ) PARTITION BY HASH (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_parent_table_hash", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_parent_table_hash (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY HASH (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_parent_table_hash", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_parent_table_hash (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    )  PARTITION BY HASH (id)   
 CREATE TABLE part6_partition_default PARTITION OF part6_parent_table_range DEFAULT;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_partition_default", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "partition_bound": "DEFAULT"}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_default PARTITION OF public.part6_parent_table_range  DEFAULT     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_partition_default", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "partition_bound": "DEFAULT"}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_default PARTITION OF public.part6_parent_table_range  DEFAULT    
 -- FROM ( { partition_bound_expr | MINVALUE | MAXVALUE } [, ...] )
 --  TO ( { partition_bound_expr | MINVALUE | MAXVALUE } [, ...] ) |
 CREATE TABLE part6_partition_spec_range1 PARTITION OF part6_parent_table_range
 FOR VALUES FROM (MINVALUE) TO (2);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_range1", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (MINVALUE) TO (2)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_range1 PARTITION OF public.part6_parent_table_range  FOR VALUES FROM (MINVALUE) TO (2)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_range1", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (MINVALUE) TO (2)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_range1 PARTITION OF public.part6_parent_table_range  FOR VALUES FROM (MINVALUE) TO (2)    
 CREATE TABLE part6_partition_spec_range2 PARTITION OF part6_parent_table_range
 FOR VALUES FROM (3) TO (MAXVALUE);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_range2", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (3) TO (MAXVALUE)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_range2 PARTITION OF public.part6_parent_table_range  FOR VALUES FROM (3) TO (MAXVALUE)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_range2", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_range", "schemaname": "public"}, "partition_bound": "FOR VALUES FROM (3) TO (MAXVALUE)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_range2 PARTITION OF public.part6_parent_table_range  FOR VALUES FROM (3) TO (MAXVALUE)    
 -- IN ( partition_bound_expr [, ...] ) |
 CREATE TABLE part6_partition_spec_list PARTITION OF part6_parent_table_list
 FOR VALUES IN (1, (1+2), (4+5));
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_list", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_list", "schemaname": "public"}, "partition_bound": "FOR VALUES IN (1, 3, 9)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_list PARTITION OF public.part6_parent_table_list  FOR VALUES IN (1, 3, 9)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_list", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_list", "schemaname": "public"}, "partition_bound": "FOR VALUES IN (1, 3, 9)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_list PARTITION OF public.part6_parent_table_list  FOR VALUES IN (1, 3, 9)    
 -- WITH ( MODULUS numeric_literal, REMAINDER numeric_literal )
 CREATE TABLE part6_partition_spec_hash PARTITION OF part6_parent_table_hash
 FOR VALUES WITH (MODULUS 10, REMAINDER 2);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_hash", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_hash", "schemaname": "public"}, "partition_bound": "FOR VALUES WITH (modulus 10, remainder 2)"}
-NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_hash PARTITION OF public.part6_parent_table_hash  FOR VALUES WITH (modulus 10, remainder 2)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D PARTITION OF %{parent_identity}D %{table_elements}s %{partition_bound}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part6_partition_spec_hash", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}, "parent_identity": {"objname": "part6_parent_table_hash", "schemaname": "public"}, "partition_bound": "FOR VALUES WITH (modulus 10, remainder 2)"}
+NOTICE:  re-formed command: CREATE  TABLE  public.part6_partition_spec_hash PARTITION OF public.part6_parent_table_hash  FOR VALUES WITH (modulus 10, remainder 2)    
 -- part7: create table
 -- all data types
 CREATE TABLE part7_source_table(
     src_id int
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part7_source_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "src_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part7_source_table (src_id pg_catalog.int4 STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part7_source_table", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "src_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part7_source_table (src_id pg_catalog.int4 STORAGE PLAIN      )     
 CREATE TABLE part7_data_types(
     var1 int8,
     var2 serial8,
@@ -395,8 +395,8 @@ NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s SEQUENCE %{if_not_exists
 NOTICE:  re-formed command: CREATE  SEQUENCE  public.part7_data_types_var37_seq CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 32767 START WITH 1 RESTART 1 AS pg_catalog.int2
 NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s SEQUENCE %{if_not_exists}s %{identity}D %{definition: }s", "identity": {"objname": "part7_data_types_var38_seq", "schemaname": "public"}, "definition": [{"fmt": "CACHE %{value}s", "value": "1", "clause": "cache"}, {"no": "NO", "fmt": "%{no}s CYCLE", "clause": "cycle"}, {"fmt": "INCREMENT BY %{value}s", "value": "1", "clause": "seqincrement"}, {"fmt": "MINVALUE %{value}s", "value": "1", "clause": "minvalue"}, {"fmt": "MAXVALUE %{value}s", "value": "2147483647", "clause": "maxvalue"}, {"fmt": "START WITH %{value}s", "value": "1", "clause": "start"}, {"fmt": "RESTART %{value}s", "value": "1", "clause": "restart"}, {"fmt": "AS %{seqtype}T", "seqtype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}}], "persistence": "", "if_not_exists": ""}
 NOTICE:  re-formed command: CREATE  SEQUENCE  public.part7_data_types_var38_seq CACHE 1 NO CYCLE INCREMENT BY 1 MINVALUE 1 MAXVALUE 2147483647 START WITH 1 RESTART 1 AS pg_catalog.int4
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part7_data_types", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int8", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int8", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "pg_catalog.nextval('public.part7_data_types_var2_seq'::pg_catalog.regclass)"}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var3", "type": "column", "coltype": {"typmod": "(1)", "typarray": false, "typename": "bit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var4", "type": "column", "coltype": {"typmod": "(1)", "typarray": true, "typename": "bit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varbit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var6", "type": "column", "coltype": {"typmod": "", "typarray": true, "typename": "varbit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var7", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "bool", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var8", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "box", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var9", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "bytea", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var10", "type": "column", "coltype": {"typmod": "(1)", "typarray": false, "typename": "bpchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var11", "type": "column", "coltype": {"typmod": "(1)", "typarray": true, "typename": "bpchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var12", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var13", "type": "column", "coltype": {"typmod": "", "typarray": true, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var14", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "cidr", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var15", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "circle", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var16", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var17", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float8", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var18", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "inet", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var19", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var20", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var21", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "INTERVAL", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var22", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "json", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var23", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "jsonb", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var24", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "line", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var25", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "lseg", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var26", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "macaddr", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var27", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "money", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var28", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "numeric", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var29", "type": "column", "coltype": {"typmod": "(3,1)", "typarray": false, "typename": "numeric", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var30", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "path", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var31", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "pg_lsn", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var32", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "pg_snapshot", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var33", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "point", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var34", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "polygon", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var35", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var36", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int2", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var37", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int2", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "pg_catalog.nextval('public.part7_data_types_var37_seq'::pg_catalog.regclass)"}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var38", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "pg_catalog.nextval('public.part7_data_types_var38_seq'::pg_catalog.regclass)"}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var39", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var40", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIME", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var41", "type": "column", "coltype": {"typmod": "(3) without time zone", "typarray": false, "typename": "TIME", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var42", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIME WITH TIME ZONE", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var43", "type": "column", "coltype": {"typmod": "(3) with time zone", "typarray": false, "typename": "TIME", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var44", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIMESTAMP", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var45", "type": "column", "coltype": {"typmod": "(3) without time zone", "typarray": false, "typename": "TIMESTAMP", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var46", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIMESTAMP WITH TIME ZONE", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var47", "type": "column", "coltype": {"typmod": "(3) with time zone", "typarray": false, "typename": "TIMESTAMP", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var48", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "tsquery", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var49", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "tsvector", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var50", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "txid_snapshot", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var51", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "uuid", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var52", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "xml", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part7_data_types (var1 pg_catalog.int8 STORAGE PLAIN      , var2 pg_catalog.int8 STORAGE PLAIN   NOT NULL DEFAULT pg_catalog.nextval('public.part7_data_types_var2_seq'::pg_catalog.regclass)  , var3 pg_catalog."bit"(1) STORAGE EXTENDED      , var4 pg_catalog."bit"(1)[] STORAGE EXTENDED      , var5 pg_catalog.varbit STORAGE EXTENDED      , var6 pg_catalog.varbit[] STORAGE EXTENDED      , var7 pg_catalog.bool STORAGE PLAIN      , var8 pg_catalog.box STORAGE PLAIN      , var9 pg_catalog.bytea STORAGE EXTENDED      , var10 pg_catalog.bpchar(1) STORAGE EXTENDED  COLLATE pg_catalog."default"    , var11 pg_catalog.bpchar(1)[] STORAGE EXTENDED  COLLATE pg_catalog."default"    , var12 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , var13 pg_catalog."varchar"[] STORAGE EXTENDED  COLLATE pg_catalog."default"    , var14 pg_catalog.cidr STORAGE MAIN      , var15 pg_catalog.circle STORAGE PLAIN      , var16 pg_catalog.date STORAGE PLAIN      , var17 pg_catalog.float8 STORAGE PLAIN      , var18 pg_catalog.inet STORAGE MAIN      , var19 pg_catalog.int4 STORAGE PLAIN      , var20 pg_catalog.int4 STORAGE PLAIN      , var21 INTERVAL STORAGE PLAIN      , var22 pg_catalog.json STORAGE EXTENDED      , var23 pg_catalog.jsonb STORAGE EXTENDED      , var24 pg_catalog.line STORAGE PLAIN      , var25 pg_catalog.lseg STORAGE PLAIN      , var26 pg_catalog.macaddr STORAGE PLAIN      , var27 pg_catalog.money STORAGE PLAIN      , var28 pg_catalog."numeric" STORAGE MAIN      , var29 pg_catalog."numeric"(3,1) STORAGE MAIN      , var30 pg_catalog.path STORAGE EXTENDED      , var31 pg_catalog.pg_lsn STORAGE PLAIN      , var32 pg_catalog.pg_snapshot STORAGE EXTENDED      , var33 pg_catalog.point STORAGE PLAIN      , var34 pg_catalog.polygon STORAGE EXTENDED      , var35 pg_catalog.float4 STORAGE PLAIN      , var36 pg_catalog.int2 STORAGE PLAIN      , var37 pg_catalog.int2 STORAGE PLAIN   NOT NULL DEFAULT pg_catalog.nextval('public.part7_data_types_var37_seq'::pg_catalog.regclass)  , var38 pg_catalog.int4 STORAGE PLAIN   NOT NULL DEFAULT pg_catalog.nextval('public.part7_data_types_var38_seq'::pg_catalog.regclass)  , var39 pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , var40 TIME STORAGE PLAIN      , var41 TIME(3) without time zone STORAGE PLAIN      , var42 TIME WITH TIME ZONE STORAGE PLAIN      , var43 TIME(3) with time zone STORAGE PLAIN      , var44 TIMESTAMP STORAGE PLAIN      , var45 TIMESTAMP(3) without time zone STORAGE PLAIN      , var46 TIMESTAMP WITH TIME ZONE STORAGE PLAIN      , var47 TIMESTAMP(3) with time zone STORAGE PLAIN      , var48 pg_catalog.tsquery STORAGE PLAIN      , var49 pg_catalog.tsvector STORAGE EXTENDED      , var50 pg_catalog.txid_snapshot STORAGE EXTENDED      , var51 pg_catalog.uuid STORAGE PLAIN      , var52 pg_catalog.xml STORAGE EXTENDED      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part7_data_types", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int8", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int8", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "pg_catalog.nextval('public.part7_data_types_var2_seq'::pg_catalog.regclass)"}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var3", "type": "column", "coltype": {"typmod": "(1)", "typarray": false, "typename": "bit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var4", "type": "column", "coltype": {"typmod": "(1)", "typarray": true, "typename": "bit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var5", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varbit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var6", "type": "column", "coltype": {"typmod": "", "typarray": true, "typename": "varbit", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var7", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "bool", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var8", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "box", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var9", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "bytea", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var10", "type": "column", "coltype": {"typmod": "(1)", "typarray": false, "typename": "bpchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var11", "type": "column", "coltype": {"typmod": "(1)", "typarray": true, "typename": "bpchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var12", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var13", "type": "column", "coltype": {"typmod": "", "typarray": true, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var14", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "cidr", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var15", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "circle", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var16", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "date", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var17", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float8", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var18", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "inet", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var19", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var20", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var21", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "INTERVAL", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var22", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "json", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var23", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "jsonb", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var24", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "line", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var25", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "lseg", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var26", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "macaddr", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var27", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "money", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var28", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "numeric", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var29", "type": "column", "coltype": {"typmod": "(3,1)", "typarray": false, "typename": "numeric", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var30", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "path", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var31", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "pg_lsn", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var32", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "pg_snapshot", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var33", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "point", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var34", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "polygon", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var35", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var36", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int2", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var37", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int2", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "pg_catalog.nextval('public.part7_data_types_var37_seq'::pg_catalog.regclass)"}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var38", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "pg_catalog.nextval('public.part7_data_types_var38_seq'::pg_catalog.regclass)"}, "not_null": "NOT NULL", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var39", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var40", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIME", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var41", "type": "column", "coltype": {"typmod": "(3) without time zone", "typarray": false, "typename": "TIME", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var42", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIME WITH TIME ZONE", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var43", "type": "column", "coltype": {"typmod": "(3) with time zone", "typarray": false, "typename": "TIME", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var44", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIMESTAMP", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var45", "type": "column", "coltype": {"typmod": "(3) without time zone", "typarray": false, "typename": "TIMESTAMP", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var46", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "TIMESTAMP WITH TIME ZONE", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var47", "type": "column", "coltype": {"typmod": "(3) with time zone", "typarray": false, "typename": "TIMESTAMP", "schemaname": ""}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var48", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "tsquery", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var49", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "tsvector", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var50", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "txid_snapshot", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var51", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "uuid", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "var52", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "xml", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part7_data_types (var1 pg_catalog.int8 STORAGE PLAIN      , var2 pg_catalog.int8 STORAGE PLAIN   NOT NULL DEFAULT pg_catalog.nextval('public.part7_data_types_var2_seq'::pg_catalog.regclass)  , var3 pg_catalog."bit"(1) STORAGE EXTENDED      , var4 pg_catalog."bit"(1)[] STORAGE EXTENDED      , var5 pg_catalog.varbit STORAGE EXTENDED      , var6 pg_catalog.varbit[] STORAGE EXTENDED      , var7 pg_catalog.bool STORAGE PLAIN      , var8 pg_catalog.box STORAGE PLAIN      , var9 pg_catalog.bytea STORAGE EXTENDED      , var10 pg_catalog.bpchar(1) STORAGE EXTENDED  COLLATE pg_catalog."default"    , var11 pg_catalog.bpchar(1)[] STORAGE EXTENDED  COLLATE pg_catalog."default"    , var12 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , var13 pg_catalog."varchar"[] STORAGE EXTENDED  COLLATE pg_catalog."default"    , var14 pg_catalog.cidr STORAGE MAIN      , var15 pg_catalog.circle STORAGE PLAIN      , var16 pg_catalog.date STORAGE PLAIN      , var17 pg_catalog.float8 STORAGE PLAIN      , var18 pg_catalog.inet STORAGE MAIN      , var19 pg_catalog.int4 STORAGE PLAIN      , var20 pg_catalog.int4 STORAGE PLAIN      , var21 INTERVAL STORAGE PLAIN      , var22 pg_catalog.json STORAGE EXTENDED      , var23 pg_catalog.jsonb STORAGE EXTENDED      , var24 pg_catalog.line STORAGE PLAIN      , var25 pg_catalog.lseg STORAGE PLAIN      , var26 pg_catalog.macaddr STORAGE PLAIN      , var27 pg_catalog.money STORAGE PLAIN      , var28 pg_catalog."numeric" STORAGE MAIN      , var29 pg_catalog."numeric"(3,1) STORAGE MAIN      , var30 pg_catalog.path STORAGE EXTENDED      , var31 pg_catalog.pg_lsn STORAGE PLAIN      , var32 pg_catalog.pg_snapshot STORAGE EXTENDED      , var33 pg_catalog.point STORAGE PLAIN      , var34 pg_catalog.polygon STORAGE EXTENDED      , var35 pg_catalog.float4 STORAGE PLAIN      , var36 pg_catalog.int2 STORAGE PLAIN      , var37 pg_catalog.int2 STORAGE PLAIN   NOT NULL DEFAULT pg_catalog.nextval('public.part7_data_types_var37_seq'::pg_catalog.regclass)  , var38 pg_catalog.int4 STORAGE PLAIN   NOT NULL DEFAULT pg_catalog.nextval('public.part7_data_types_var38_seq'::pg_catalog.regclass)  , var39 pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , var40 TIME STORAGE PLAIN      , var41 TIME(3) without time zone STORAGE PLAIN      , var42 TIME WITH TIME ZONE STORAGE PLAIN      , var43 TIME(3) with time zone STORAGE PLAIN      , var44 TIMESTAMP STORAGE PLAIN      , var45 TIMESTAMP(3) without time zone STORAGE PLAIN      , var46 TIMESTAMP WITH TIME ZONE STORAGE PLAIN      , var47 TIMESTAMP(3) with time zone STORAGE PLAIN      , var48 pg_catalog.tsquery STORAGE PLAIN      , var49 pg_catalog.tsvector STORAGE EXTENDED      , var50 pg_catalog.txid_snapshot STORAGE EXTENDED      , var51 pg_catalog.uuid STORAGE PLAIN      , var52 pg_catalog.xml STORAGE EXTENDED      )     
 NOTICE:  deparsed json: {"fmt": "ALTER SEQUENCE %{identity}D %{definition: }s", "identity": {"objname": "part7_data_types_var2_seq", "schemaname": "public"}, "definition": [{"fmt": "OWNED BY %{owner}D", "owner": {"objname": "part7_data_types", "attrname": "var2", "schemaname": "public"}, "clause": "owned"}]}
 NOTICE:  re-formed command: ALTER SEQUENCE public.part7_data_types_var2_seq OWNED BY public.part7_data_types.var2
 NOTICE:  deparsed json: {"fmt": "ALTER SEQUENCE %{identity}D %{definition: }s", "identity": {"objname": "part7_data_types_var37_seq", "schemaname": "public"}, "definition": [{"fmt": "OWNED BY %{owner}D", "owner": {"objname": "part7_data_types", "attrname": "var37", "schemaname": "public"}, "clause": "owned"}]}
@@ -407,15 +407,15 @@ CREATE TABLE part7_compression_collate(
     str1 varchar COMPRESSION "pglz",
     str2 varchar COLLATE "C"
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part7_compression_collate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "str1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "compression_method": "pglz"}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "str2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "C", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part7_compression_collate (str1 pg_catalog."varchar" STORAGE EXTENDED COMPRESSION pglz COLLATE pg_catalog."default"    , str2 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."C"    )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part7_compression_collate", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "str1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "compression_method": "pglz"}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "str2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "C", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part7_compression_collate (str1 pg_catalog."varchar" STORAGE EXTENDED COMPRESSION pglz COLLATE pg_catalog."default"    , str2 pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."C"    )     
 CREATE TABLE part7_inherits_parent(
     id int,
     name varchar
 )
 INHERITS (part7_data_types, part7_compression_collate);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part7_inherits_parent", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "part7_data_types", "schemaname": "public"}, {"objname": "part7_compression_collate", "schemaname": "public"}]}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part7_inherits_parent (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    ) INHERITS (public.part7_data_types, public.part7_compression_collate)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part7_inherits_parent", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "part7_data_types", "schemaname": "public"}, {"objname": "part7_compression_collate", "schemaname": "public"}]}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part7_inherits_parent (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    ) INHERITS (public.part7_data_types, public.part7_compression_collate)    
 CREATE TABLE part7_combine_all_clauses(
     id varchar(5) COMPRESSION "pglz" COLLATE "C" CONSTRAINT id_constraint DEFAULT 'foo',
     PRIMARY KEY (id),
@@ -426,8 +426,8 @@ INHERITS (part7_data_types, part7_compression_collate)
 USING heap
 WITH (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true)
 TABLESPACE pg_default;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part7_combine_all_clauses", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "part7_data_types", "schemaname": "public"}, {"objname": "part7_compression_collate", "schemaname": "public"}]}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "(5)", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "C", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "compression_method": "pglz"}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "src_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part7_combine_all_clauses_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part7_combine_all_clauses (id pg_catalog."varchar"(5) STORAGE EXTENDED COMPRESSION pglz COLLATE pg_catalog."C"  DEFAULT 'foo'::character varying  , src_id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT part7_combine_all_clauses_pkey PRIMARY KEY (id)) INHERITS (public.part7_data_types, public.part7_compression_collate)  USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true')  TABLESPACE pg_default
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part7_combine_all_clauses", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "part7_data_types", "schemaname": "public"}, {"objname": "part7_compression_collate", "schemaname": "public"}]}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "(5)", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "C", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "compression_method": "pglz"}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "src_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part7_combine_all_clauses_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part7_combine_all_clauses (id pg_catalog."varchar"(5) STORAGE EXTENDED COMPRESSION pglz COLLATE pg_catalog."C"  DEFAULT 'foo'::character varying  , src_id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT part7_combine_all_clauses_pkey PRIMARY KEY (id)) INHERITS (public.part7_data_types, public.part7_compression_collate)  USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') TABLESPACE pg_default
 CREATE TEMP TABLE part7_combine_all_clauses_temp(
     id varchar(5) COMPRESSION "pglz" COLLATE "C" CONSTRAINT id_constraint DEFAULT 'foo',
     PRIMARY KEY (id),
@@ -439,22 +439,22 @@ USING heap
 WITH (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true)
 ON COMMIT DELETE ROWS
 TABLESPACE pg_default;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part7_combine_all_clauses_temp", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "part7_data_types", "schemaname": "public"}, {"objname": "part7_compression_collate", "schemaname": "public"}]}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "on_commit_value": "DELETE ROWS"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "(5)", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "C", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "compression_method": "pglz"}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "src_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part7_combine_all_clauses_temp_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part7_combine_all_clauses_temp (id pg_catalog."varchar"(5) STORAGE EXTENDED COMPRESSION pglz COLLATE pg_catalog."C"  DEFAULT 'foo'::character varying  , src_id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT part7_combine_all_clauses_temp_pkey PRIMARY KEY (id)) INHERITS (public.part7_data_types, public.part7_compression_collate)  USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') ON COMMIT DELETE ROWS TABLESPACE pg_default
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part7_combine_all_clauses_temp", "schemaname": "pg_temp"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "part7_data_types", "schemaname": "public"}, {"objname": "part7_compression_collate", "schemaname": "public"}]}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "TEMPORARY", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "(5)", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "default": "'foo'::character varying"}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "C", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "compression_method": "pglz"}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "src_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part7_combine_all_clauses_temp_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE TEMPORARY TABLE  pg_temp.part7_combine_all_clauses_temp (id pg_catalog."varchar"(5) STORAGE EXTENDED COMPRESSION pglz COLLATE pg_catalog."C"  DEFAULT 'foo'::character varying  , src_id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT part7_combine_all_clauses_temp_pkey PRIMARY KEY (id)) INHERITS (public.part7_data_types, public.part7_compression_collate)  USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') TABLESPACE pg_default
 -- CREATE TABLE ... AS
 CREATE TABLE test_ctas AS SELECT 0 AS col1, 1 AS col2;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "test_ctas", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.test_ctas (col1 pg_catalog.int4 STORAGE PLAIN      , col2 pg_catalog.int4 STORAGE PLAIN      )      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "test_ctas", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col1", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "col2", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.test_ctas (col1 pg_catalog.int4 STORAGE PLAIN      , col2 pg_catalog.int4 STORAGE PLAIN      )     
 -- part8: create typed table
 CREATE TABLE part8_create_typed_table OF part8_people_type;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}}
-NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table OF public.part8_people_type      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "present": false}}
+NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table OF public.part8_people_type     
 CREATE TABLE part8_create_typed_table_simple OF part8_people_type(
     weight,
     PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table_simple", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "elements": [{"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_simple_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}}
-NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table_simple OF public.part8_people_type (CONSTRAINT part8_create_typed_table_simple_pkey PRIMARY KEY (id))     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table_simple", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "elements": [{"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_simple_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}}
+NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table_simple OF public.part8_people_type (CONSTRAINT part8_create_typed_table_simple_pkey PRIMARY KEY (id))    
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET NOT NULL", "type": "set not null", "column": "id"}], "identity": {"objname": "part8_create_typed_table_simple", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.part8_create_typed_table_simple ALTER COLUMN id SET NOT NULL
 CREATE TABLE part8_create_typed_table_with_options_constaints OF part8_people_type(
@@ -462,8 +462,8 @@ CREATE TABLE part8_create_typed_table_with_options_constaints OF part8_people_ty
     name UNIQUE,
     PRIMARY KEY (id)
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table_with_options_constaints", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "elements": [{"fmt": "%{name}I WITH OPTIONS %{not_null}s %{default}s", "name": "weight", "type": "column", "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_with_options_constaints_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_with_options_constaints_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}}
-NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table_with_options_constaints OF public.part8_people_type (weight WITH OPTIONS NOT NULL , CONSTRAINT part8_create_typed_table_with_options_constaints_name_key UNIQUE (name), CONSTRAINT part8_create_typed_table_with_options_constaints_pkey PRIMARY KEY (id))     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table_with_options_constaints", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "elements": [{"fmt": "%{name}I WITH OPTIONS %{not_null}s %{default}s", "name": "weight", "type": "column", "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_with_options_constaints_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_with_options_constaints_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}}
+NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table_with_options_constaints OF public.part8_people_type (weight WITH OPTIONS NOT NULL , CONSTRAINT part8_create_typed_table_with_options_constaints_name_key UNIQUE (name), CONSTRAINT part8_create_typed_table_with_options_constaints_pkey PRIMARY KEY (id))    
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET NOT NULL", "type": "set not null", "column": "id"}], "identity": {"objname": "part8_create_typed_table_with_options_constaints", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.part8_create_typed_table_with_options_constaints ALTER COLUMN id SET NOT NULL
 CREATE TABLE part8_create_typed_table_complex_combinations OF part8_people_type(
@@ -474,8 +474,8 @@ CREATE TABLE part8_create_typed_table_complex_combinations OF part8_people_type(
 USING heap
 WITH (vacuum_index_cleanup = ON, autovacuum_vacuum_scale_factor = 0.2, vacuum_truncate = true)
 TABLESPACE pg_default;
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table_complex_combinations", "schemaname": "public"}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "elements": [{"fmt": "%{name}I WITH OPTIONS %{not_null}s %{default}s", "name": "weight", "type": "column", "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_complex_combinations_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_complex_combinations_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}}
-NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table_complex_combinations OF public.part8_people_type (weight WITH OPTIONS NOT NULL , CONSTRAINT part8_create_typed_table_complex_combinations_name_key UNIQUE (name), CONSTRAINT part8_create_typed_table_complex_combinations_pkey PRIMARY KEY (id))  USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true')  TABLESPACE pg_default
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D OF %{of_type}T %{table_elements}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "of_type": {"typmod": "", "typarray": false, "typename": "part8_people_type", "schemaname": "public"}, "identity": {"objname": "part8_create_typed_table_complex_combinations", "schemaname": "public"}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "tablespace": "pg_default"}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "with": [{"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_index_cleanup"}, "value": "on"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "autovacuum_vacuum_scale_factor"}, "value": "0.2"}, {"fmt": "%{label}s = %{value}L", "label": {"fmt": "%{label}I", "label": "vacuum_truncate"}, "value": "true"}]}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "access_method": "heap"}, "if_not_exists": "", "table_elements": {"fmt": "(%{elements:, }s)", "elements": [{"fmt": "%{name}I WITH OPTIONS %{not_null}s %{default}s", "name": "weight", "type": "column", "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "NOT NULL"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_complex_combinations_name_key", "type": "constraint", "contype": "unique", "definition": "UNIQUE (name)"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "part8_create_typed_table_complex_combinations_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}}
+NOTICE:  re-formed command: CREATE  TABLE  public.part8_create_typed_table_complex_combinations OF public.part8_people_type (weight WITH OPTIONS NOT NULL , CONSTRAINT part8_create_typed_table_complex_combinations_name_key UNIQUE (name), CONSTRAINT part8_create_typed_table_complex_combinations_pkey PRIMARY KEY (id))  USING heap WITH (vacuum_index_cleanup = 'on', autovacuum_vacuum_scale_factor = '0.2', vacuum_truncate = 'true') TABLESPACE pg_default
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET NOT NULL", "type": "set not null", "column": "id"}], "identity": {"objname": "part8_create_typed_table_complex_combinations", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.part8_create_typed_table_complex_combinations ALTER COLUMN id SET NOT NULL
 -- part9: create table as a partition of parent table, FOR VALUES clause is tested in part 6
@@ -485,24 +485,24 @@ CREATE TABLE part9_parent_table_range(
     height float4,
     weight float4
 ) PARTITION BY RANGE (height);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part9_parent_table_range", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (height)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "height", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "weight", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_range (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , height pg_catalog.float4 STORAGE PLAIN      , weight pg_catalog.float4 STORAGE PLAIN      )  PARTITION BY RANGE (height)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part9_parent_table_range", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "RANGE (height)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "height", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "weight", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_range (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , height pg_catalog.float4 STORAGE PLAIN      , weight pg_catalog.float4 STORAGE PLAIN      )  PARTITION BY RANGE (height)   
 CREATE TABLE part9_parent_table_list(
     id int,
     name varchar,
     height float4,
     weight float4
 ) PARTITION BY LIST (name);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part9_parent_table_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (name)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "height", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "weight", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , height pg_catalog.float4 STORAGE PLAIN      , weight pg_catalog.float4 STORAGE PLAIN      )  PARTITION BY LIST (name)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part9_parent_table_list", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "LIST (name)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "height", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "weight", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_list (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , height pg_catalog.float4 STORAGE PLAIN      , weight pg_catalog.float4 STORAGE PLAIN      )  PARTITION BY LIST (name)   
 CREATE TABLE part9_parent_table_hash(
     id int,
     name varchar,
     height float4,
     weight float4
 ) PARTITION BY HASH (id);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "part9_parent_table_hash", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "height", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "weight", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_hash (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , height pg_catalog.float4 STORAGE PLAIN      , weight pg_catalog.float4 STORAGE PLAIN      )  PARTITION BY HASH (id)    
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "part9_parent_table_hash", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "definition": "HASH (id)"}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "varchar", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "height", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "weight", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "float4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_hash (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog."varchar" STORAGE EXTENDED  COLLATE pg_catalog."default"    , height pg_catalog.float4 STORAGE PLAIN      , weight pg_catalog.float4 STORAGE PLAIN      )  PARTITION BY HASH (id)   
 -- TOFIX
 -- CREATE TABLE part9_partition_with_options_constraintscd
 -- PARTITION OF part9_parent_table_range (
@@ -533,8 +533,8 @@ NOTICE:  re-formed command: CREATE  TABLE  public.part9_parent_table_hash (id pg
 -- copied from old create_table.sql
 -- Test TableLikeClause is handled properly
 CREATE TABLE ctlt1 (a text CHECK (length(a) > 2) PRIMARY KEY, b text);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "ctlt1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "a", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "b", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_a_check", "type": "constraint", "contype": "check", "definition": "CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2))"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (a)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.ctlt1 (a pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , b pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT ctlt1_a_check CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2)), CONSTRAINT ctlt1_pkey PRIMARY KEY (a))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "ctlt1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "a", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "b", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_a_check", "type": "constraint", "contype": "check", "definition": "CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2))"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (a)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.ctlt1 (a pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , b pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT ctlt1_a_check CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2)), CONSTRAINT ctlt1_pkey PRIMARY KEY (a))     
 ALTER TABLE ctlt1 ALTER COLUMN a SET STORAGE MAIN;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET STORAGE %{storage}s", "type": "set storage", "column": "a", "storage": "main"}], "identity": {"objname": "ctlt1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.ctlt1 ALTER COLUMN a SET STORAGE main
@@ -542,18 +542,18 @@ ALTER TABLE ctlt1 ALTER COLUMN b SET STORAGE EXTERNAL;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I SET STORAGE %{storage}s", "type": "set storage", "column": "b", "storage": "external"}], "identity": {"objname": "ctlt1", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.ctlt1 ALTER COLUMN b SET STORAGE external
 CREATE TABLE ctlt1_like (LIKE ctlt1 INCLUDING ALL);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "ctlt1_like", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "a", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "b", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTERNAL", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_a_check", "type": "constraint", "contype": "check", "definition": "CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2))"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_like_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (a)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.ctlt1_like (a pg_catalog.text STORAGE MAIN  COLLATE pg_catalog."default"    , b pg_catalog.text STORAGE EXTERNAL  COLLATE pg_catalog."default"    , CONSTRAINT ctlt1_a_check CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2)), CONSTRAINT ctlt1_like_pkey PRIMARY KEY (a))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "ctlt1_like", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "a", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "MAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "b", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTERNAL", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_a_check", "type": "constraint", "contype": "check", "definition": "CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2))"}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "ctlt1_like_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (a)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.ctlt1_like (a pg_catalog.text STORAGE MAIN  COLLATE pg_catalog."default"    , b pg_catalog.text STORAGE EXTERNAL  COLLATE pg_catalog."default"    , CONSTRAINT ctlt1_a_check CHECK ((pg_catalog.length(a) OPERATOR(pg_catalog.>) 2)), CONSTRAINT ctlt1_like_pkey PRIMARY KEY (a))     
 NOTICE:  deparsed json: <NULL>
 NOTICE:  re-formed command: <NULL>
 -- Test foreign key constraint is handled in a following ALTER TABLE ADD CONSTRAINT FOREIGN KEY REFERENCES subcommand
 CREATE TABLE product (id int PRIMARY KEY, name text);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "product", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "product_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.product (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT product_pkey PRIMARY KEY (id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "product", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "name", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "text", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "collation_name": {"objname": "default", "schemaname": "pg_catalog"}}, "colstorage": "EXTENDED", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "product_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.product (id pg_catalog.int4 STORAGE PLAIN      , name pg_catalog.text STORAGE EXTENDED  COLLATE pg_catalog."default"    , CONSTRAINT product_pkey PRIMARY KEY (id))     
 CREATE TABLE orders2 (order_id int PRIMARY KEY, product_id int
 REFERENCES product (id));
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "orders2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "order_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "product_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "orders2_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (order_id)"}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.orders2 (order_id pg_catalog.int4 STORAGE PLAIN      , product_id pg_catalog.int4 STORAGE PLAIN      , CONSTRAINT orders2_pkey PRIMARY KEY (order_id))      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "orders2", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "order_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "product_id", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "CONSTRAINT %{name}I %{definition}s", "name": "orders2_pkey", "type": "constraint", "contype": "primary key", "definition": "PRIMARY KEY (order_id)"}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.orders2 (order_id pg_catalog.int4 STORAGE PLAIN      , product_id pg_catalog.int4 STORAGE PLAIN      , CONSTRAINT orders2_pkey PRIMARY KEY (order_id))     
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ADD CONSTRAINT %{name}I %{definition}s", "name": "orders2_product_id_fkey", "type": "add constraint", "definition": "FOREIGN KEY (product_id) REFERENCES public.product(id)"}], "identity": {"objname": "orders2", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.orders2 ADD CONSTRAINT orders2_product_id_fkey FOREIGN KEY (product_id) REFERENCES public.product(id)
 -- Test CREATE and ALTER inherited table
@@ -561,11 +561,11 @@ CREATE TABLE gtest30 (
 a int,
 b int GENERATED ALWAYS AS (a * 2) STORED
 );
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "gtest30", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "a", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "b", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr": "(a OPERATOR(pg_catalog.*) 2)"}}]}
-NOTICE:  re-formed command: CREATE  TABLE  public.gtest30 (a pg_catalog.int4 STORAGE PLAIN      , b pg_catalog.int4 STORAGE PLAIN      GENERATED ALWAYS AS ((a OPERATOR(pg_catalog.*) 2)) STORED)      
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D (%{table_elements:, }s) %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "gtest30", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": "", "table_elements": [{"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "a", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "present": false}}, {"fmt": "%{name}I %{coltype}T STORAGE %{colstorage}s %{compression}s %{collation}s %{not_null}s %{default}s %{identity_column}s %{generated_column}s", "name": "b", "type": "column", "coltype": {"typmod": "", "typarray": false, "typename": "int4", "schemaname": "pg_catalog"}, "default": {"fmt": "DEFAULT %{default}s", "present": false}, "not_null": "", "collation": {"fmt": "COLLATE %{collation_name}D", "present": false}, "colstorage": "PLAIN", "compression": {"fmt": "COMPRESSION %{compression_method}I", "present": false}, "identity_column": {"fmt": "%{identity_column}s", "present": false}, "generated_column": {"fmt": "GENERATED ALWAYS AS (%{generation_expr}s) STORED", "generation_expr": "(a OPERATOR(pg_catalog.*) 2)"}}]}
+NOTICE:  re-formed command: CREATE  TABLE  public.gtest30 (a pg_catalog.int4 STORAGE PLAIN      , b pg_catalog.int4 STORAGE PLAIN      GENERATED ALWAYS AS ((a OPERATOR(pg_catalog.*) 2)) STORED)     
 CREATE TABLE gtest30_1 () INHERITS (gtest30);
-NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D () %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{on_commit}s %{tablespace}s", "identity": {"objname": "gtest30_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "gtest30", "schemaname": "public"}]}, "on_commit": {"fmt": "ON COMMIT %{on_commit_value}s", "present": false}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": ""}
-NOTICE:  re-formed command: CREATE  TABLE  public.gtest30_1 () INHERITS (public.gtest30)     
+NOTICE:  deparsed json: {"fmt": "CREATE %{persistence}s TABLE %{if_not_exists}s %{identity}D () %{inherits}s %{partition_by}s %{access_method}s %{with_clause}s %{tablespace}s", "identity": {"objname": "gtest30_1", "schemaname": "public"}, "inherits": {"fmt": "INHERITS (%{parents:, }D)", "parents": [{"objname": "gtest30", "schemaname": "public"}]}, "tablespace": {"fmt": "TABLESPACE %{tablespace}I", "present": false}, "persistence": "", "with_clause": {"fmt": "WITH (%{with:, }s)", "present": false}, "partition_by": {"fmt": "PARTITION BY %{definition}s", "present": false}, "access_method": {"fmt": "USING %{access_method}I", "present": false}, "if_not_exists": ""}
+NOTICE:  re-formed command: CREATE  TABLE  public.gtest30_1 () INHERITS (public.gtest30)    
 ALTER TABLE gtest30 ALTER COLUMN b DROP EXPRESSION;
 NOTICE:  deparsed json: {"fmt": "ALTER %{objtype}s %{only}s %{identity}D %{subcmds:, }s", "only": "", "objtype": "TABLE", "subcmds": [{"fmt": "ALTER COLUMN %{column}I DROP EXPRESSION %{if_exists}s", "type": "drop expression", "column": "b", "if_exists": ""}], "identity": {"objname": "gtest30", "schemaname": "public"}}
 NOTICE:  re-formed command: ALTER TABLE  public.gtest30 ALTER COLUMN b DROP EXPRESSION 
diff --git a/src/test/modules/test_ddl_deparse_regress/sql/alter_table.sql b/src/test/modules/test_ddl_deparse_regress/sql/alter_table.sql
index 0141a7e293..49d074ced1 100644
--- a/src/test/modules/test_ddl_deparse_regress/sql/alter_table.sql
+++ b/src/test/modules/test_ddl_deparse_regress/sql/alter_table.sql
@@ -45,8 +45,8 @@ ALTER TABLE test_drop_column DROP price;
 ALTER TABLE test_drop_column DROP COLUMN quantity;
 
 ALTER TABLE test_drop_column DROP IF EXISTS description RESTRICT;
--- TOFIX
--- ALTER TABLE test_drop_column DROP IF EXISTS name CASCADE;
+
+ALTER TABLE test_drop_column DROP IF EXISTS name CASCADE;
 
 -- ALTER [ COLUMN ] column_name [ SET DATA ] TYPE data_type [ COLLATE collation ] [ USING expression ]
 CREATE TABLE test_alter_type(
@@ -226,8 +226,7 @@ CREATE TABLE test_drop_constraint_reference(
 ALTER TABLE test_drop_constraint_reference DROP CONSTRAINT test_drop_constraint_reference_cstr1;
 ALTER TABLE test_drop_constraint DROP CONSTRAINT test_drop_constraint_check RESTRICT;
 ALTER TABLE test_drop_constraint DROP CONSTRAINT IF EXISTS test_drop_constraint_check RESTRICT;
--- TOFIX
--- ALTER TABLE test_drop_constraint DROP CONSTRAINT test_drop_constraint_uniq CASCADE;
+ALTER TABLE test_drop_constraint DROP CONSTRAINT test_drop_constraint_uniq CASCADE;
 
 -- TODO: This should be tested with TRIGGER related testing
 -- DISABLE TRIGGER [ trigger_name | ALL | USER ]
@@ -420,8 +419,8 @@ ALTER TABLE test_set_schema SET SCHEMA new_test_schema;
 -- TOFIX: can not be caught by ddl_command_end event trigger.
 -- Deparse of T_AlterTableMoveAllStmt is not supported,
 -- TABLESPACE commands (global object commands) are also not supported.
--- ALTER TABLE ALL IN TABLESPACE pg_default SET TABLESPACE pg_default;
--- ALTER TABLE ALL IN TABLESPACE pg_default OWNED BY ddl_testing_role SET TABLESPACE pg_default;
+ALTER TABLE ALL IN TABLESPACE pg_default SET TABLESPACE pg_default;
+ALTER TABLE ALL IN TABLESPACE pg_default OWNED BY ddl_testing_role SET TABLESPACE pg_default;
 
 -- ATTACH PARTITION partition_name { FOR VALUES partition_bound_spec | DEFAULT }
 CREATE TABLE test_partition_attach_range(
diff --git a/src/test/modules/test_ddl_deparse_regress/t/001_compare_dumped_results.pl b/src/test/modules/test_ddl_deparse_regress/t/001_compare_dumped_results.pl
index d6c27958c1..071afcab66 100644
--- a/src/test/modules/test_ddl_deparse_regress/t/001_compare_dumped_results.pl
+++ b/src/test/modules/test_ddl_deparse_regress/t/001_compare_dumped_results.pl
@@ -144,6 +144,8 @@ sub create_deparse_testing_resources_on_pub_node {
             r record;
         begin
             for r in select * from pg_event_trigger_dropped_objects()
+		        -- Deparse only the TABLE related commands, skip the internally generated triggers, indexes etc.
+		        WHERE object_type in ('TABLE')
             loop
                 insert into deparsed_ddls(tag, object_identity, ddl) values (r.object_type, r.object_identity, public.deparse_drop_ddl(r.object_identity, r.object_type));
             end loop;
diff --git a/src/test/modules/test_ddl_deparse_regress/test_ddl_deparse_regress.c b/src/test/modules/test_ddl_deparse_regress/test_ddl_deparse_regress.c
index 04288c68e0..79036a197f 100644
--- a/src/test/modules/test_ddl_deparse_regress/test_ddl_deparse_regress.c
+++ b/src/test/modules/test_ddl_deparse_regress/test_ddl_deparse_regress.c
@@ -58,10 +58,10 @@ deparse_drop_ddl(PG_FUNCTION_ARGS)
 		PG_RETURN_NULL();
 	}
 
-	command = deparse_drop_command(objidentity_str, objecttype_str, (Node *)&fake_node);
-
+	command = deparse_drop_table(objidentity_str, objecttype_str,
+											(Node *)&fake_node);
 	if (command)
 		PG_RETURN_TEXT_P(cstring_to_text(command));
 
 	PG_RETURN_NULL();
-}
\ No newline at end of file
+}
-- 
2.34.1

